<!DOCTYPE html>
<html lang="en">

<head>
	<meta charset="UTF-8">
	<meta name="viewport" content="width=device-width, initial-scale=1.0">
	<title>Attendance Report</title>

	<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">

	<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/flatpickr/dist/flatpickr.min.css">

	<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css">

	<style>
		@font-face {
			font-family: 'bengali';
			src: url('../fonts/siliguri_semibold.ttf') format('truetype');
			font-weight: normal;
			font-style: normal;
		}

		*,
		*::before,
		*::after {
			box-sizing: inherit;
			font-family: 'bengali', sans-serif;
			margin: 0;
			padding: 0;
		}

		html {
			box-sizing: border-box;
		}

		:root {
			--primary-color: #4361ee;
			--secondary-color: #3f37c9;
			--success-color: #4cc9f0;
			--danger-color: #f72585;
			--light-color: #f8f9fa;
			--dark-color: #212529;
			--time-slot-bg: #ffffff;
			--time-slot-shadow: 0 2px 8px rgba(0, 0, 0, 0.08);
		}

		body {
			background-color: #f5f7fa;
			color: #333;
		}

		.report-container {
			max-width: 1400px;
			margin: 30px 30px auto;
			background: white;
			border-radius: 12px;
			box-shadow: 0 4px 20px rgba(0, 0, 0, 0.08);
			padding: 30px;
		}

		.report-header {
			display: flex;
			justify-content: space-between;
			align-items: center;
			margin-bottom: 30px;
			padding-bottom: 20px;
			border-bottom: 1px solid #e0e0e0;
		}

		.filter-section {
			background: #f8f9fa;
			border-radius: 8px;
			padding: 20px;
			margin-bottom: 30px;
		}

		/* Attendance Data Container */
		#attendanceData {
			display: grid;
			grid-template-columns: repeat(3, 1fr);
			gap: 20px;
		}

		/* Year Group Styles */
		/* Year Group Modern Styles */
		.year-group {
			margin-bottom: 25px;
			position: relative;
		}

		.year-header {
			background: linear-gradient(135deg, #4361ee 0%, #3f37c9 100%);
			color: white;
			padding: 18px 25px;
			font-weight: 600;
			border-radius: 12px;
			display: flex;
			justify-content: space-between;
			align-items: center;
			cursor: pointer;
			transition: all 0.3s ease;
			box-shadow: 0 4px 15px rgba(67, 97, 238, 0.2);
			border: none;
			position: relative;
			overflow: hidden;
			z-index: 1;
		}

		.year-header::before {
			content: '';
			position: absolute;
			top: 0;
			left: 0;
			width: 100%;
			height: 100%;
			background: linear-gradient(135deg, #3f37c9 0%, #4361ee 100%);
			opacity: 0;
			transition: opacity 0.3s ease;
			z-index: -1;
		}

		.year-header:hover {
			transform: translateY(-2px);
			box-shadow: 0 6px 20px rgba(67, 97, 238, 0.3);
		}

		.year-header:hover::before {
			opacity: 1;
		}

		.year-badge {
			background-color: rgba(255, 255, 255, 0.15);
			padding: 6px 12px;
			border-radius: 20px;
			font-size: 0.85rem;
			display: flex;
			align-items: center;
			gap: 8px;
			transition: all 0.3s ease;
			backdrop-filter: blur(5px);
			border: 1px solid rgba(255, 255, 255, 0.1);
		}

		.year-header:hover .year-badge {
			background-color: rgba(255, 255, 255, 0.25);
		}

		.year-badge i {
			transition: transform 0.3s ease;
		}

		.month-tooltip:hover .year-badge i {
			transform: rotate(180deg);
		}

		/* Modern Tooltip Styles */
		.month-tooltip {
			position: relative;
			display: inline-block;
			width: 100%;
		}

		.month-tooltip-content {
			visibility: hidden;
			width: 100%;
			background-color: white;
			color: #333;
			text-align: left;
			border-radius: 12px;
			padding: 0;
			position: absolute;
			z-index: 1000;
			bottom: auto;
			top: calc(100% + 10px);
			left: 0;
			box-shadow: 0 10px 30px rgba(0, 0, 0, 0.1);
			opacity: 0;
			transition: all 0.3s cubic-bezier(0.68, -0.55, 0.265, 1.55);
			transform: translateY(10px);
			max-height: 0;
			overflow: hidden;
		}

		.month-tooltip:hover .month-tooltip-content {
			visibility: visible;
			opacity: 1;
			transform: translateY(0);
			max-height: 500px;
			padding: 15px;
		}

		.month-tooltip-item {
			background: #f8f9fa;
			border-radius: 8px;
			padding: 12px 15px;
			cursor: pointer;
			transition: all 0.2s ease;
			margin-bottom: 8px;
			display: flex;
			justify-content: space-between;
			align-items: center;
		}

		.month-tooltip-item:last-child {
			margin-bottom: 0;
		}

		.month-tooltip-item:hover {
			background: #e9ecef;
			transform: translateX(5px);
			box-shadow: 0 3px 10px rgba(0, 0, 0, 0.05);
		}

		.month-tooltip-name {
			font-weight: 600;
			color: #243b53;
			font-size: 0.95rem;
		}

		.month-tooltip-count {
			font-size: 0.8rem;
			color: #6b7280;
			background: rgba(0, 0, 0, 0.05);
			padding: 3px 8px;
			border-radius: 12px;
		}



		/* Time Slots Modal */
		.time-slots-modal .modal-dialog {
			max-width: 800px;
		}

		.time-slots-modal .modal-content {
			border-radius: 12px;
			border: none;
			box-shadow: 0 5px 30px rgba(0, 0, 0, 0.2);
		}

		.time-slots-modal .modal-header {
			background-color: var(--primary-color);
			color: white;
			border-radius: 12px 12px 0 0;
			padding: 18px;
			border-bottom: none;
			position: relative;
		}

		.time-slots-modal .modal-body {
			padding: 18px;
		}

		.time-slots-container {
			display: grid;
			grid-template-columns: repeat(auto-fill, minmax(180px, 1fr));
			gap: 12px;
		}

		.time-slot-item {
			background: white;
			border-radius: 8px;
			padding: 12px;
			box-shadow: 0 2px 6px rgba(0, 0, 0, 0.08);
			cursor: pointer;
			transition: all 0.2s ease;
		}

		.time-slot-item:hover {
			background-color: #f0f4f8;
			transform: translateY(-2px);
		}

		.time-slot-time {
			font-weight: 500;
			font-size: 0.95rem;
			margin-bottom: 4px;
		}

		.time-slot-count {
			font-size: 0.8rem;
			color: #6b7280;
		}

		/* Attendance Details Modal */
		.attendance-modal .modal-dialog {
			max-width: 900px;
		}

		.attendance-modal .modal-content {
			border-radius: 12px;
			border: none;
			box-shadow: 0 5px 30px rgba(0, 0, 0, 0.2);
		}

		.attendance-modal .modal-header {
			background-color: var(--primary-color);
			color: white;
			border-radius: 12px 12px 0 0;
			padding: 18px;
			border-bottom: none;
			position: relative;
		}

		.attendance-modal .modal-body {
			padding: 18px;
			background-color: #f8fafc;
		}

		.attendance-list {
			display: grid;
			grid-template-columns: repeat(auto-fill, minmax(220px, 1fr));
			gap: 12px;
			max-height: 60vh;
			overflow-y: auto;
			padding: 3px;
		}

		.attendance-item {
			background: white;
			border-radius: 8px;
			padding: 12px;
			box-shadow: 0 2px 8px rgba(0, 0, 0, 0.08);
			transition: transform 0.2s ease, box-shadow 0.2s ease;
			display: flex;
			flex-direction: column;
			gap: 6px;
		}

		.attendance-item:hover {
			transform: translateY(-2px);
			box-shadow: 0 4px 12px rgba(0, 0, 0, 0.12);
		}

		.student-info {
			display: flex;
			flex-direction: column;
			gap: 4px;
		}

		.student-name {
			font-weight: 600;
			color: #243b53;
			font-size: 0.95rem;
		}

		.form-no {
			font-size: 0.8rem;
			color: #486581;
			display: flex;
			align-items: center;
			gap: 5px;
		}

		.form-no i {
			color: #829ab1;
			font-size: 0.9rem;
		}

		.status-badge {
			padding: 5px 10px;
			border-radius: 20px;
			font-size: 0.8rem;
			font-weight: 500;
			text-align: center;
			margin-top: 4px;
			align-self: flex-start;
		}

		.status-present {
			background-color: #d1fae5;
			color: #065f46;
		}

		.status-absent {
			background-color: #fee2e2;
			color: #b91c1c;
		}

		.status-rukhsat {
			background-color: #dbeafe;
			color: #1e40af;
		}

		.status-bimar {
			background-color: #f3e8ff;
			color: #6b21a8;
		}

		/* Back Button Styles */
		.modal-back-btn {
			position: absolute;
			left: 18px;
			background: none;
			border: none;
			color: white;
			font-size: 0.95rem;
			display: flex;
			align-items: center;
			gap: 5px;
			cursor: pointer;
		}

		.modal-back-btn:hover {
			opacity: 0.8;
		}

		.summary-card {
			background: white;
			border-radius: 8px;
			box-shadow: 0 2px 8px rgba(0, 0, 0, 0.05);
			padding: 12px;
			margin-bottom: 15px;
		}

		.summary-value {
			font-size: 1.4rem;
			font-weight: 700;
			color: var(--primary-color);
		}

		.summary-label {
			font-size: 0.85rem;
			color: #6b7280;
		}

		.no-data {
			text-align: center;
			padding: 40px;
			color: #6b7280;
			grid-column: 1 / -1;
		}

		.no-data i {
			font-size: 2.5rem;
			margin-bottom: 12px;
			color: #d1d5db;
		}




		@media (max-width: 1200px) {
			#attendanceData {
				grid-template-columns: repeat(2, 1fr);
			}
		}

		@media (max-width: 992px) {
			.time-slots-container {
				grid-template-columns: repeat(auto-fill, minmax(150px, 1fr));
			}

			.attendance-list {
				grid-template-columns: repeat(auto-fill, minmax(180px, 1fr));
			}

			.month-tooltip-content {
				width: 240px;
			}
		}

		@media (max-width: 768px) {
			.report-header {
				flex-direction: column;
				align-items: flex-start;
				gap: 12px;
			}

			#attendanceData {
				grid-template-columns: 1fr;
			}

			.time-slots-modal .modal-dialog,
			.attendance-modal .modal-dialog {
				margin: 10px;
			}

			.modal-back-btn {
				position: static;
				margin-bottom: 12px;
				color: white;
				padding: 4px 8px;
				border-radius: 4px;
				background-color: rgba(255, 255, 255, 0.2);
			}

			.filter-section .row {
				flex-wrap: wrap;
			}

			.filter-section .col-md-4,
			.filter-section .col-md-3,
			.filter-section .col-md-2 {
				width: 100%;
				margin-bottom: 12px;
			}


			/* Add these styles to your existing CSS */
			.todays-attendance-toggle .btn {
				border-radius: 8px;
				padding: 10px;
				font-weight: 500;
				transition: all 0.3s ease;
			}

			.todays-attendance-toggle .btn:hover {
				background-color: #4361ee;
				color: white;
			}

			.todays-attendance-container {
				animation: fadeIn 0.3s ease;
			}

			@keyframes fadeIn {
				from {
					opacity: 0;
					transform: translateY(-10px);
				}

				to {
					opacity: 1;
					transform: translateY(0);
				}
			}

			.attendance-card {
				background: white;
				border-radius: 10px;
				padding: 20px;
				box-shadow: 0 3px 10px rgba(0, 0, 0, 0.05);
				transition: all 0.3s ease;
				border-left: 4px solid #4361ee;
				height: 100%;
			}

			.attendance-card:hover {
				transform: translateY(-3px);
				box-shadow: 0 5px 15px rgba(0, 0, 0, 0.1);
			}

			.student-card-header {
				display: flex;
				justify-content: space-between;
				align-items: center;
				margin-bottom: 15px;
				padding-bottom: 15px;
				border-bottom: 1px solid #f0f0f0;
			}

			.student-name {
				font-weight: 600;
				color: #243b53;
				font-size: 1.1rem;
			}

			.form-no {
				font-size: 0.85rem;
				color: #6b7280;
				background: rgba(0, 0, 0, 0.05);
				padding: 3px 8px;
				border-radius: 12px;
			}

			.attendance-status {
				display: flex;
				justify-content: flex-start;
			}

			.time-slot-header {
				background: #065f46;
				color: #4361ee;
				font-size: 1.1rem;
				margin-bottom: 15px;
			}

			.form-no {
				font-size: 0.85rem;
				color: #6b7280;
				background: rgba(0, 0, 0, 0.05);
				padding: 3px 8px;
				border-radius: 12px;
			}

			.attendance-status {
				display: flex;
				justify-content: flex-start;
			}


			@media (max-width: 992px) {
				.attendance-card {
					padding: 15px;
				}

				.student-name {
					font-size: 1rem;
				}
			}

			.month-tooltip-content {
				width: 280px;
				left: 0;
				transform: none;
			}


			/* year-header  শুরু*/
			.year-header {
				padding: 15px 20px;
			}

			.month-tooltip-content {
				position: relative;
				top: 0;
				box-shadow: none;
				margin-top: 10px;
			}

			.month-tooltip:hover .month-tooltip-content {
				padding: 10px;
			}

			/* year-header  শেষ*/

		}

		@media (max-width: 576px) {
			.report-container {
				padding: 20px;
			}

			.time-slots-container {
				grid-template-columns: 1fr;
			}

			.attendance-list {
				grid-template-columns: 1fr;
			}

			.month-tooltip-content {
				width: 260px;
			}

		}
	</style>

</head>


<body>

	<div class="report-container">
		<?php
		if ($_SERVER['REQUEST_METHOD'] === 'POST'):
			$classes_id = $_POST['id'];
			$classes_name = $_POST['name'];
			$email = $_POST['email'];

			include_once '../db/database/conn.php';
			$db = new DBConn();
			$conn = $db->getConnection();
		?>

			<div class="report-header">
				<div>
					<h2>Attendance Report</h2>
					<p class="text-muted mb-0"><?php echo htmlspecialchars($classes_name); ?></p>
				</div>
				<div id="reportSummary" class="d-flex gap-3"></div>
			</div>



			<div class="filter-section">
				<div class="row g-3">

					<div class="col-md-3">
						<label for="dateRange" class="form-label">Date Range</label>
						<input type="text" class="form-control" id="dateRange" placeholder="Select date range">
					</div>
					<div class="col-md-2">
						<label for="statusFilter" class="form-label">Status</label>
						<select class="form-select" id="statusFilter">
							<option value="all">All Status</option>
							<option value="উপস্থিত">Present</option>
							<option value="অনুপস্থিত">Absent</option>
							<option value="রুখসত">Rukhsat</option>
							<option value="বিমার">Bimar</option>
						</select>
					</div>

					<div class="col-md-3">
						<label for="searchStudent" class="form-label">Search Student</label>
						<input type="text" class="form-control" id="searchStudent" placeholder="Student name or form no">
					</div>

					<div class="col-md-2 d-flex align-items-end">
						<a href="../select.php" id="dailyReport" class="btn btn-outline-success w-100">গড় উপস্থিতি</a>
					</div>

					<div class="col-md-2 d-flex align-items-end">
						<button id="resetFilters" class="btn btn-outline-warning w-100">
							<i class="bi bi-arrow-counterclockwise"></i> Reset
						</button>
					</div>


				</div>
			</div>








			<!-- Add this after the filter-section -->
			<div class="todays-attendance-toggle mb-3">
				<button class="btn btn-outline-primary w-100" id="showTodaysAttendanceBtn">
					<i class="bi bi-calendar-check"></i> আজকের হাজিরা দেখুন
				</button>
			</div>

			<div class="todays-attendance-container" id="todaysAttendanceContainer" style="display: none;">
				<div class="card border-0 shadow-sm mb-4">
					<div class="card-body">
						<h5 class="card-title d-flex justify-content-between align-items-center">
							<span>আজকের হাজিরা</span>
							<button class="btn btn-sm btn-outline-secondary" id="hideTodaysAttendanceBtn">
								<i class="bi bi-x-lg"></i> বন্ধ করুন
							</button>
						</h5>
						<div id="todaysAttendanceContent">
							<!-- Content will be loaded dynamically -->
						</div>
					</div>
				</div>
			</div>


			<div id="loadingIndicator" class="text-center py-5">
				<div class="spinner-border text-primary" role="status">
					<span class="visually-hidden">Loading...</span>
				</div>
				<p class="mt-2">Loading attendance data...</p>
			</div>

			<div id="attendanceData"></div>

			<!-- Time Slots Modal -->
			<div class="modal fade time-slots-modal" id="timeSlotsModal" tabindex="-1" aria-hidden="true">
				<div class="modal-dialog modal-dialog-centered">
					<div class="modal-content">
						<div class="modal-header">
							<button type="button" class="modal-back-btn" id="backFromTimeSlots">
								<i class="bi bi-arrow-left"></i> Back
							</button>
							<h5 class="modal-title mx-auto" id="timeSlotsModalTitle">Select Time Slot</h5>
							<button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
						</div>
						<div class="modal-body">
							<div class="time-slots-container" id="timeSlotsContainer">
								<!-- Time slots will be inserted here -->
							</div>
						</div>
						<div class="modal-footer">
							<button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
						</div>
					</div>
				</div>
			</div>

			<!-- Attendance Details Modal -->
			<div class="modal fade attendance-modal" id="attendanceModal" tabindex="-1" aria-hidden="true">
				<div class="modal-dialog modal-dialog-centered">
					<div class="modal-content">
						<div class="modal-header">
							<button type="button" class="modal-back-btn" id="backFromAttendance">
								<i class="bi bi-arrow-left"></i> Back
							</button>
							<h5 class="modal-title mx-auto" id="attendanceModalTitle">Attendance Details</h5>
							<button type="button" class="btn-close btn-close-white" data-bs-dismiss="modal" aria-label="Close"></button>
						</div>
						<div class="modal-body">
							<div class="attendance-list" id="attendanceList">
								<!-- Attendance records will be inserted here -->
							</div>
						</div>
						<div class="modal-footer">
							<button type="button" class="btn btn-primary" data-bs-dismiss="modal">Close</button>
						</div>
					</div>
				</div>
			</div>




		<?php endif; ?>
	</div>

	<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
	<script src="https://cdn.jsdelivr.net/npm/axios/dist/axios.min.js"></script>
	<script src="https://cdn.jsdelivr.net/npm/flatpickr"></script>


	<script>
		// Initialize modals
		const timeSlotsModal = new bootstrap.Modal(document.getElementById('timeSlotsModal'));
		const attendanceModal = new bootstrap.Modal(document.getElementById('attendanceModal'));

		// Global variables
		let attendanceData = {};
		let groupedByYearMonth = {};
		let groupedByDate = {};
		let currentYear = '';
		let currentMonth = '';

		document.addEventListener('DOMContentLoaded', function() {
			// Initialize date picker
			flatpickr("#dateRange", {
				mode: "range",
				dateFormat: "Y-m-d",
				maxDate: "today"
			});

			// Load initial data
			fetchAttendanceData();
			setupTodaysAttendance();

			// Event listeners
			document.getElementById('dateRange').addEventListener('change', fetchAttendanceData);
			document.getElementById('statusFilter').addEventListener('change', fetchAttendanceData);
			document.getElementById('searchStudent').addEventListener('input', fetchAttendanceData);
			document.getElementById('resetFilters').addEventListener('click', resetFilters);
			document.getElementById('backFromTimeSlots').addEventListener('click', () => timeSlotsModal.hide());
			document.getElementById('backFromAttendance').addEventListener('click', () => {
				attendanceModal.hide();
				timeSlotsModal.show();
			});
		});

		// Today's Attendance Functions
		function setupTodaysAttendance() {
    const showBtn = document.getElementById('showTodaysAttendanceBtn');
    const hideBtn = document.getElementById('hideTodaysAttendanceBtn');
    const container = document.getElementById('todaysAttendanceContainer');

    showBtn.addEventListener('click', function() {
        loadTodaysAttendance();
        container.style.display = 'block';
        showBtn.style.display = 'none';
    });

    hideBtn.addEventListener('click', function() {
        container.style.display = 'none';
        showBtn.style.display = 'block';
    });
}

function loadTodaysAttendance() {
    const today = new Date();
    const todayDateStr = today.toISOString().split('T')[0]; // Format: YYYY-MM-DD
    const content = document.getElementById('todaysAttendanceContent');
    const todayFormatted = formatDisplayDate(todayDateStr);

    content.innerHTML = `
        <div class="text-center py-4">
            <div class="spinner-border text-primary" role="status">
                <span class="visually-hidden">Loading...</span>
            </div>
            <p class="mt-2 text-muted">আজকের হাজিরা লোড হচ্ছে...</p>
        </div>
    `;

    // Filter the already loaded data for today's date only
    const todaysRecords = attendanceData.attendance.filter(record => {
        const recordDate = new Date(record.created_at).toISOString().split('T')[0];
        return recordDate === todayDateStr;
    });

    if (todaysRecords.length === 0) {
        content.innerHTML = `
            <div class="no-attendance-message text-center py-5">
                <i class="bi bi-calendar-x" style="font-size: 3rem; color: #dee2e6;"></i>
                <h5 class="mt-3">এখনও আজকের কোন হাজিরা যুক্ত হয়নি</h5>
                <p class="text-muted mb-4">আজকের হাজিরা রেকর্ড করা হলে এখানে দেখানো হবে</p>
                <form action="student_attendance.php" method="POST" style="display: inline;">
    <input type="hidden" name="id" value="<?php echo $classes_id; ?>">
    <input type="hidden" name="name" value="<?php echo htmlspecialchars($classes_name); ?>">
    <input type="hidden" name="email" value="<?php echo $email; ?>">
    <button type="submit" class="btn btn-primary">
        <i class="bi bi-plus-circle"></i> আজকে হাজিরা নিন
    </button>
</form>

            </div>
        `;
        return;
    }

    // Rest of the code remains the same...
    const groupedByTime = {};
    todaysRecords.forEach(record => {
        const time = formatTimeSlot(record.created_at);
        if (!groupedByTime[time]) groupedByTime[time] = [];
        groupedByTime[time].push(record);
    });

    let html = `
        <div class="d-flex justify-content-between align-items-center mb-4">
            <h5 class="mb-0">আজকের হাজিরা তালিকা</h5>
            <div class="text-muted">${todayFormatted}</div>
        </div>
        <div class="row g-4">
    `;

    Object.entries(groupedByTime).forEach(([time, records]) => {
        html += `
            <div class="col-12">
                <div class="time-slot-header bg-light p-3 rounded">
                    <i class="bi bi-clock me-2"></i>
                    <strong>${time}</strong>
                    <span class="badge bg-primary ms-2">${records.length} জন</span>
                </div>
            </div>
        `;

        const chunkSize = window.innerWidth > 992 ? 3 : 1;
        for (let i = 0; i < records.length; i += chunkSize) {
            const chunk = records.slice(i, i + chunkSize);
            html += `<div class="row g-3">`;

            chunk.forEach(record => {
                html += `
                    <div class="col-md-${12/chunkSize}">
                        <div class="attendance-card h-100">
                            <div class="student-card-header">
                                <span class="student-name">${record.student_name}</span>
                                <span class="form-no">ফর্ম: ${record.form_no}</span>
                            </div>
                            <div class="attendance-status mt-3">
                                <span class="status-badge ${getStatusClass(record.attendance_status)}">
                                    ${record.attendance_status}
                                </span>
                            </div>
                        </div>
                    </div>
                `;
            });

            html += `</div>`;
        }
    });

    html += `</div>`;
    content.innerHTML = html;
}





		// Main Attendance Functions
		function fetchAttendanceData() {
			const loadingIndicator = document.getElementById('loadingIndicator');
			const attendanceContainer = document.getElementById('attendanceData');

			loadingIndicator.style.display = 'block';
			attendanceContainer.innerHTML = '';

			const params = new URLSearchParams();
			params.append('classes_id', '<?php echo $classes_id; ?>');
			params.append('email', '<?php echo $email; ?>');

			const dateRange = document.getElementById('dateRange')._flatpickr.selectedDates;
			if (dateRange.length === 2) {
				params.append('start_date', formatDate(dateRange[0]));
				params.append('end_date', formatDate(dateRange[1]));
			}

			const statusFilter = document.getElementById('statusFilter').value;
			if (statusFilter !== 'all') params.append('status', statusFilter);

			const searchQuery = document.getElementById('searchStudent').value;
			if (searchQuery) params.append('search', searchQuery);

			axios.get(`attendance_report_api.php?${params.toString()}`)
				.then(response => {
					attendanceData = response.data;
					processAttendanceData(response.data);
					renderSummary(response.data.summary);
					loadingIndicator.style.display = 'none';
				})
				.catch(error => {
					attendanceContainer.innerHTML = `
                    <div class="no-data">
                        <i class="bi bi-calendar-x"></i>
                        <h4>No attendance records found</h4>
                        <p>Try adjusting your filters</p>
                    </div>
                `;
					loadingIndicator.style.display = 'none';
					console.error('Error:', error);
				});
		}

		function processAttendanceData(data) {
			groupedByYearMonth = {};
			groupedByDate = {};

			data.attendance.forEach(record => {
				const date = new Date(record.created_at);
				const year = date.getFullYear();
				const month = date.toLocaleString('default', {
					month: 'long'
				});
				const dateStr = record.date;
				const time = formatTimeSlot(record.created_at);

				if (!groupedByYearMonth[year]) groupedByYearMonth[year] = {};
				if (!groupedByYearMonth[year][month]) groupedByYearMonth[year][month] = [];
				groupedByYearMonth[year][month].push(record);

				if (!groupedByDate[dateStr]) groupedByDate[dateStr] = {};
				if (!groupedByDate[dateStr][time]) groupedByDate[dateStr][time] = [];
				groupedByDate[dateStr][time].push(record);
			});

			renderYearGroups();
		}

		function renderYearGroups() {
			const container = document.getElementById('attendanceData');

			if (Object.keys(groupedByYearMonth).length === 0) {
				container.innerHTML = `
                <div class="no-data">
                    <i class="bi bi-calendar-x"></i>
                    <h4>No attendance records found</h4>
                    <p>Try adjusting your filters</p>
                </div>
            `;
				return;
			}

			let html = '';
			for (const [year, months] of Object.entries(groupedByYearMonth)) {
				const yearCount = Object.values(months).flat().length;
				let monthTooltipContent = '';

				for (const [month, records] of Object.entries(months)) {
					monthTooltipContent += `
                    <div class="month-tooltip-item" data-year="${year}" data-month="${month}">
                        <div class="month-tooltip-name">${month}</div>
                        <div class="month-tooltip-count">${records.length} records</div>
                    </div>
                `;
				}

				html += `
                <div class="year-group">
                    <div class="month-tooltip">
                        <div class="year-header" data-year="${year}">
                            <span>${year}</span>
                            <span class="year-badge">
                                ${yearCount} ${yearCount > 1 ? 'records' : 'record'}
                                <i class="bi bi-chevron-down"></i>
                            </span>
                        </div>
                        <div class="month-tooltip-content">
                            ${monthTooltipContent}
                        </div>
                    </div>
                </div>
            `;
			}

			container.innerHTML = html;

			document.querySelectorAll('.month-tooltip-item').forEach(item => {
				item.addEventListener('click', function() {
					currentYear = this.getAttribute('data-year');
					currentMonth = this.getAttribute('data-month');
					showTimeSlotsModal(currentYear, currentMonth);
				});
			});
		}

		function showTimeSlotsModal(year, month) {
			const modalTitle = document.getElementById('timeSlotsModalTitle');
			const timeSlotsContainer = document.getElementById('timeSlotsContainer');

			modalTitle.textContent = `Time Slots for ${month} ${year}`;
			timeSlotsContainer.innerHTML = '';

			const datesInMonth = Object.keys(groupedByDate).filter(date => {
				const dateObj = new Date(date);
				return dateObj.getFullYear() == year &&
					dateObj.toLocaleString('default', {
						month: 'long'
					}) === month;
			});

			datesInMonth.forEach(date => {
				const dateObj = new Date(date);
				const formattedDate = dateObj.toLocaleDateString('en-US', {
					weekday: 'short',
					month: 'short',
					day: 'numeric'
				});

				Object.entries(groupedByDate[date]).forEach(([time, records]) => {
					const timeSlotItem = document.createElement('div');
					timeSlotItem.className = 'time-slot-item';
					timeSlotItem.innerHTML = `
                    <div class="time-slot-time">${time}</div>
                    <div class="time-slot-count">${formattedDate} • ${records.length} entries</div>
                `;

					timeSlotItem.addEventListener('click', () => {
						showAttendanceDetailsModal(date, time, records);
						timeSlotsModal.hide();
					});

					timeSlotsContainer.appendChild(timeSlotItem);
				});
			});

			timeSlotsModal.show();
		}

		function showAttendanceDetailsModal(date, time, records) {
			const modalTitle = document.getElementById('attendanceModalTitle');
			const attendanceList = document.getElementById('attendanceList');

			const formattedDate = new Date(date).toLocaleDateString('en-US', {
				weekday: 'long',
				year: 'numeric',
				month: 'long',
				day: 'numeric'
			});
			modalTitle.textContent = `Attendance on ${formattedDate} at ${time}`;

			attendanceList.innerHTML = records.map(record => `
            <div class="attendance-item">
                <div class="student-info">
                    <div class="student-name">${record.student_name}</div>
                    <div class="form-no">
                        <i class="bi bi-card-text"></i>
                        Form: ${record.form_no}
                    </div>
                </div>
                <span class="status-badge ${getStatusClass(record.attendance_status)}">
                    ${record.attendance_status}
                </span>
            </div>
        `).join('');

			attendanceModal.show();
		}

		// Utility Functions
		function resetFilters() {
			document.getElementById('dateRange')._flatpickr.clear();
			document.getElementById('statusFilter').value = 'all';
			document.getElementById('searchStudent').value = '';
			fetchAttendanceData();
		}

		function formatTimeSlot(datetimeString) {
			return new Date(datetimeString).toLocaleTimeString([], {
				hour: '2-digit',
				minute: '2-digit',
				hour12: true
			}).replace(/(\d+):(\d+) (AM|PM)/, (match, h, m, p) => `${h}:${m} ${p}`);
		}

		function formatDate(date) {
			return date.toISOString().split('T')[0];
		}

		function formatDisplayDate(dateString) {
			return new Date(dateString).toLocaleDateString('en-US', {
				year: 'numeric',
				month: 'short',
				day: 'numeric',
				weekday: 'short'
			});
		}

		function getStatusClass(status) {
			const classes = {
				'উপস্থিত': 'status-present',
				'অনুপস্থিত': 'status-absent',
				'রুখসত': 'status-rukhsat',
				'বিমার': 'status-bimar'
			};
			return classes[status] || '';
		}

		function renderSummary(summary) {
			document.getElementById('reportSummary').innerHTML = `
            <div class="summary-card">
                <div class="summary-value">${summary.total_days}</div>
                <div class="summary-label">Days</div>
            </div>
            <div class="summary-card">
                <div class="summary-value">${summary.total_records}</div>
                <div class="summary-label">Records</div>
            </div>
            <div class="summary-card">
                <div class="summary-value">${summary.average_attendance}%</div>
                <div class="summary-label">Avg. Attendance</div>
            </div>
        `;
		}
	</script>


</body>

</html>