<?php
header('Content-Type: application/json');

include_once '../db/database/conn.php';
$db = new DBConn();
$conn = $db->getConnection();

// Get and sanitize POST data
$student_name = $conn->real_escape_string($_POST['name'] ?? '');
$form_no = $conn->real_escape_string($_POST['form_no'] ?? '');
$status = $_POST['status'] ?? '';
$reason = $conn->real_escape_string($_POST['reason'] ?? '');
$classes_id = (int)($_POST['classes_id'] ?? 0);
$classes_name = $conn->real_escape_string($_POST['classes_name'] ?? '');
$email = $conn->real_escape_string($_POST['email'] ?? '');
$time = $conn->real_escape_string($_POST['time'] ?? date('Y-m-d H:i:s'));

// Validate datetime format
if (!DateTime::createFromFormat('Y-m-d H:i:s', $time)) {
    http_response_code(400);
    echo json_encode([
        'success' => false,
        'message' => 'Invalid datetime format'
    ]);
    exit;
}

// Determine attendance status
$attendance_status = 'উপস্থিত';
if ($status === 'Unchecked') {
    $attendance_status = 'অনুপস্থিত';
} elseif ($reason === 'রুখসত') {
    $attendance_status = 'রুখসত';
} elseif ($reason === 'বিমার') {
    $attendance_status = 'বিমার';
}

try {
    // Create table if not exists (with timestamp as part of the unique record)
    $conn->query("
        CREATE TABLE IF NOT EXISTS `student_attendance` (
            `id` INT(11) NOT NULL AUTO_INCREMENT,
            `classes_id` INT(11) NOT NULL,
            `classes_name` VARCHAR(255) NOT NULL,
            `email` VARCHAR(255) NOT NULL,
            `student_name` VARCHAR(255) NOT NULL,
            `form_no` VARCHAR(50) NOT NULL,
            `attendance_status` ENUM('উপস্থিত','অনুপস্থিত','রুখসত','বিমার') NOT NULL,
            `created_at` DATETIME NOT NULL,
            PRIMARY KEY (`id`),
            UNIQUE KEY `unique_attendance` (`classes_id`, `email`, `student_name`, `form_no`, `created_at`),
            INDEX `idx_classes_id` (`classes_id`),
            INDEX `idx_email` (`email`),
            INDEX `idx_created_at` (`created_at`),
            INDEX `idx_student_name` (`student_name`),
            INDEX `idx_form_no` (`form_no`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
    ");

    // Always insert new record (no checking for existing records on same day)
    $insert = $conn->prepare("
        INSERT INTO student_attendance 
        (classes_id, classes_name, email, student_name, form_no, attendance_status, created_at) 
        VALUES (?, ?, ?, ?, ?, ?, ?)
    ");
    $insert->bind_param(
        "issssss",
        $classes_id,
        $classes_name,
        $email,
        $student_name,
        $form_no,
        $attendance_status,
        $time
    );
    $insert->execute();

    echo json_encode([
        'success' => true,
        'message' => 'Attendance recorded successfully',
        'data' => [
            'timestamp' => $time,
            'status' => $attendance_status
        ]
    ]);
} catch (Exception $e) {
    http_response_code(500);
    echo json_encode([
        'success' => false,
        'message' => 'Database error: ' . $e->getMessage(),
        'debug' => [
            'time_value' => $time,
            'query_error' => $conn->error ?? null
        ]
    ]);
}

$conn->close();
?>