<!DOCTYPE html>
<html lang="bn">
<head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
    <title>Attendance Report</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f4f6f8;
            padding: 20px;
        }
        h1 {
            color: #333;
            text-align: center;
        }
        .container {
            max-width: 600px;
            margin: auto;
            background: white;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 0 15px rgba(0,0,0,0.1);
        }
        input[type="month"] {
            padding: 8px;
            width: 100%;
            margin-bottom: 15px;
        }
        button {
            padding: 10px 20px;
            background-color: #3498db;
            color: white;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            width: 100%;
        }
        button:hover {
            background-color: #2980b9;
        }
        pre {
            background: #f9f9f9;
            padding: 15px;
            border-radius: 5px;
            overflow-x: auto;
        }
    </style>
</head>
<body>

    <div class="container">
        <h1>অ্যাটেনডেন্স রিপোর্ট</h1>
        <input type="text" id="monthPicker" />
        <button onclick="fetchReport()">রিপোর্ট দেখুন</button>
        <div id="report"></div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/axios/dist/axios.min.js"></script>
    <script>
        function fetchReport() {
            const month = document.getElementById('monthPicker').value;
            const reportDiv = document.getElementById('report');

            if (!month) {
                reportDiv.innerHTML = '<p style="color: red;">অনুগ্রহ করে মাস নির্বাচন করুন।</p>';
                return;
            }

            reportDiv.innerHTML = '<p>লোড হচ্ছে...</p>';

            axios.post('z_api.php', { month: month })
                .then(function (response) {
                    const res = response.data;
                    if (res.status) {
                        let output = `<h3>মাস: ${res.month}</h3><pre>`;
                        const data = res.data;
                        for (const status in data) {
                            const item = data[status];
                            output += `${status}: ${item.count} (${item.dates.join(', ')})\n`;
                            output += "----------------------\n";
                        }
                        output += '</pre>';
                        reportDiv.innerHTML = output;
                    } else {
                        reportDiv.innerHTML = `<p style="color: red;">${res.message}</p>`;
                    }
                })
                .catch(function (error) {
                    console.error(error);
                    reportDiv.innerHTML = '<p style="color: red;">কোনো সমস্যা হয়েছে। অনুগ্রহ করে পরে আবার চেষ্টা করুন।</p>';
                });
        }
    
    
    
    </script>

</body>
</html>
