<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Exam Results</title>
    <style>
        table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 30px;
            box-shadow: 0px 4px 8px rgba(0, 0, 0, 0.2);
        }

        th,
        td {
            border: 1px solid black;
            padding: 10px;
            text-align: center;
        }

        th {
            background-color: lightgray;
        }

        h2 {
            box-shadow: 0px 4px 8px rgba(0, 0, 0, 0.2);
            padding: 10px;
            background-color: #f8f8f8;
        }

        #emailForm {
            margin-bottom: 20px;
        }

        .delete-button {
            background-color: red;
            color: white;
            padding: 10px 20px;
            cursor: pointer;
            border: none;
            margin-top: 10px;
        }

        /* Custom No Data Modal */
        .modal {
            display: none;
            position: fixed;
            z-index: 1000;
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.5);
        }

        .modal-content {
            background-color: white;
            margin: 20% auto;
            padding: 20px;
            border-radius: 10px;
            width: 40%;
            text-align: center;
            box-shadow: 0px 4px 8px rgba(0, 0, 0, 0.2);
        }

        .modal button {
            background-color: #007bff;
            color: white;
            padding: 10px 20px;
            border: none;
            cursor: pointer;
            margin-top: 10px;
            border-radius: 8px;
        }

        .modal button:hover {
            background-color: #0056b3;
        }
    </style>
</head>

<body>

    <!-- No Data Modal -->
    <div id="noDataModal" class="modal">
        <div class="modal-content">
            <h2>কোন তথ্য পাওয়া যায়নি</h2>
            <p>এই ক্লাসে কোন পরিক্ষার রেজাল্ট পাওয়া যায়নি!</p>
            <button class="btn" onclick="closeModal()">OK</button>
        </div>
    </div>

    <?php if ($_SERVER['REQUEST_METHOD'] === 'POST'): ?>

        <input type="hidden" id="madrashaEmail" value="<?php echo $_POST['email']; ?>">
        <input type="hidden" id="classID" value="<?php echo $_POST['id']; ?>">
        <input type="hidden" id="className" value="<?php echo $_POST['name']; ?>">

        <div id="results"></div>

        <script>
            fetch("display_api.php", {
                    method: "POST",
                    headers: {
                        "Content-Type": "application/x-www-form-urlencoded"
                    },
                    body: new URLSearchParams({
                        email: document.getElementById("madrashaEmail").value,
                        class_id: document.getElementById("classID").value,
                        class_name: document.getElementById("className").value
                    })
                })
                .then(response => response.json())
                .then(data => {
                    const resultsDiv = document.getElementById("results");

                    if (data.length === 0) {
                        // Show No Data Modal
                        document.getElementById("noDataModal").style.display = "block";
                        return;
                    }

                    data.forEach(classData => {
                        let tableHtml = `
                <h2>${classData.email} - ${classData.class_name} - ${classData.exam_name} - ${classData.exam_date}</h2>
                <table>
                    <tr>
                        <th>Form No</th>
                        <th>Student Name</th>
            `;

                        let subjects = new Set();
                        classData.students.forEach(student => {
                            Object.keys(student.subjects).forEach(subject => subjects.add(subject));
                        });

                        subjects.forEach(subject => {
                            tableHtml += `<th>${subject}</th>`;
                        });

                        tableHtml += `
                        <th>Total Marks</th>
                        <th>Obtained Marks</th>
                        <th>Rank</th>
                    </tr>
            `;

                        classData.students.forEach(student => {
                            tableHtml += `
                    <tr>
                        <td>${student.form_no}</td>
                        <td>${student.student_name}</td>
                `;

                            subjects.forEach(subject => {
                                tableHtml += `<td>${student.subjects[subject] || "-"}</td>`;
                            });

                            tableHtml += `
                        <td>${student.total}</td>
                        <td>${student.obtained}</td>
                        <td>${student.rank}</td>
                    </tr>
                `;
                        });

                        tableHtml += `</table>
                <button class="delete-button" onclick="deleteTable('${classData.class_name}', '${classData.exam_name}', '${classData.exam_date}')">Delete Table</button>
            `;
                        resultsDiv.innerHTML += tableHtml;
                    });
                });

            function deleteTable(className, examName, examDate) {
                const confirmation = confirm("Are you sure you want to delete this table?");
                if (confirmation) {
                    fetch("delete_api.php", {
                            method: "POST",
                            headers: {
                                "Content-Type": "application/x-www-form-urlencoded"
                            },
                            body: new URLSearchParams({
                                class_name: className,
                                exam_name: examName,
                                exam_date: examDate
                            })
                        })
                        .then(response => response.text())
                        .then(result => {
                            alert(result); // Show response message from server
                            location.reload(); // Reload the page after deletion
                        });
                }
            }

            function closeModal() {
                document.getElementById("noDataModal").style.display = "none";
                window.history.back(); // আগের পেজে ফিরে যাওয়ার জন্য
            }
        </script>

    <?php endif; ?>

</body>

</html>