<?php
header('Content-Type: application/json');

require_once '../database/conn.php';

$db = new DBConn();
$conn = $db->getConnection();


// Get JSON input
$data = json_decode(file_get_contents('php://input'), true);
$email = $data['email'] ?? '';
$image = $data['image'] ?? '';

if (empty($email)) {
    echo json_encode(['success' => false, 'message' => 'ইমেইল প্রয়োজন']);
    exit;
}

try {
    // Start transaction
    $conn->begin_transaction();
    
    // Delete image file if exists
    if (!empty($image)) {
        $imagePath = '../uploads/' . $image;
        if (file_exists($imagePath)) {
            unlink($imagePath);
        }
    }
    
    // Delete madrasha record
    $stmt = $conn->prepare("DELETE FROM madrashas WHERE email = ?");
    $stmt->bind_param("s", $email);
    $stmt->execute();
    
    if ($stmt->affected_rows > 0) {
        $conn->commit();
        echo json_encode(['success' => true, 'message' => 'মাদরাসা সফলভাবে মুছে ফেলা হয়েছে']);
    } else {
        $conn->rollback();
        echo json_encode(['success' => false, 'message' => 'মাদরাসা খুঁজে পাওয়া যায়নি']);
    }
} catch (Exception $e) {
    $conn->rollback();
    echo json_encode(['success' => false, 'message' => 'ত্রুটি: ' . $e->getMessage()]);
}
?>