<?php
header('Content-Type: application/json');

include_once('../database/conn.php');

$db = new DBConn();
$conn = $db->getConnection();

// Set charset to utf8
$conn->set_charset('utf8');

// Response array
$response = ['success' => false, 'message' => ''];

try {
    // Check if the request method is POST
    if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
        throw new Exception('Invalid request method');
    }

    // Get and validate email
    $email = isset($_POST['email']) ? trim($_POST['email']) : '';
    if (empty($email)) {
        throw new Exception('Email is required');
    }
    
    // Validate email format
    if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        throw new Exception('Invalid email format');
    }

    // Check if email exists in madrashas table
    $checkEmail = $conn->prepare("SELECT email FROM madrashas WHERE email = ?");
    $checkEmail->bind_param('s', $email);
    $checkEmail->execute();
    $checkEmail->store_result();
    
    if ($checkEmail->num_rows === 0) {
        throw new Exception('Email not found in our records');
    }
    $checkEmail->close();

    // Check if image was uploaded
    if (!isset($_FILES['image']) || $_FILES['image']['error'] === UPLOAD_ERR_NO_FILE) {
        throw new Exception('Image is required');
    }

    $image = $_FILES['image'];

    // Check for upload errors
    if ($image['error'] !== UPLOAD_ERR_OK) {
        throw new Exception('File upload error: ' . $image['error']);
    }

    // Validate image file
    $allowedTypes = ['image/jpeg', 'image/png', 'image/gif'];
    $maxFileSize = 5 * 1024 * 1024; // 5MB

    // Check file type
    $finfo = finfo_open(FILEINFO_MIME_TYPE);
    $mime = finfo_file($finfo, $image['tmp_name']);
    finfo_close($finfo);

    if (!in_array($mime, $allowedTypes)) {
        throw new Exception('Only JPEG, PNG, and GIF images are allowed');
    }

    // Check file size
    if ($image['size'] > $maxFileSize) {
        throw new Exception('Image size must be less than 5MB');
    }

    // Create upload directory if it doesn't exist
    $uploadDir = 'uploads/';
    if (!file_exists($uploadDir)) {
        mkdir($uploadDir, 0755, true);
    }

    // Generate unique filename
    $fileExt = pathinfo($image['name'], PATHINFO_EXTENSION);
    $fileName = uniqid('ads_') . '_' . time() . '.' . $fileExt;
    $filePath = $uploadDir . $fileName;

    // Move uploaded file
    if (!move_uploaded_file($image['tmp_name'], $filePath)) {
        throw new Exception('Failed to save uploaded file');
    }

    // Insert into database
    $stmt = $conn->prepare("INSERT INTO advertisements (email, image_path) VALUES (?, ?)");
    $stmt->bind_param('ss', $email, $filePath);

    if ($stmt->execute()) {
        $response = [
            'success' => true,
            'message' => 'Advertisement submitted successfully!'
        ];
    } else {
        // Delete the uploaded file if database insertion fails
        unlink($filePath);
        throw new Exception('Failed to save to database: ' . $stmt->error);
    }

    $stmt->close();
} catch (Exception $e) {
    $response = [
        'success' => false,
        'message' => $e->getMessage()
    ];
} finally {
    $conn->close();
}

echo json_encode($response);
?>