<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Student Admission Information</title>
    <style>
        @font-face {
            font-family: 'bengali';
            src: url('../../fonts/siliguri_semibold.ttf') format('truetype');
            font-weight: normal;
            font-style: normal;
        }

        :root {
            --primary-color: #4361ee;
            --secondary-color: #3a0ca3;
            --accent-color: #f72585;
            --light-color: #f8f9fa;
            --dark-color: #212529;
            --text-light: #f8f9fa;
            --text-dark: #212529;
            --card-bg-light: #ffffff;
            --card-bg-dark: #2b2d42;
            --border-radius: 12px;
            --box-shadow: 0 10px 20px rgba(0, 0, 0, 0.1);
            --transition: all 0.3s cubic-bezier(0.25, 0.8, 0.25, 1);
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: 'bengali', sans-serif;
        }

        body {
            background-color: var(--light-color);
            color: var(--text-dark);
            line-height: 1.7;
            padding: 20px;
            min-height: 100vh;
            transition: background-color 0.5s ease, color 0.5s ease;
        }

        body.dark-mode {
            background-color: #121212;
            color: var(--text-light);
        }

        .container {
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px;
        }

        .header {
            text-align: center;
            margin-bottom: 40px;
            position: relative;
        }

        .header h1 {
            font-size: 2.5rem;
            color: var(--primary-color);
            margin-bottom: 10px;
            font-weight: 700;
        }

        .header p {
            color: #6c757d;
            font-size: 1.1rem;
        }

        body.dark-mode .header p {
            color: #adb5bd;
        }

        .theme-toggle {
            position: fixed;
            top: 20px;
            right: 20px;
            z-index: 100;
            background: var(--primary-color);
            color: white;
            border: none;
            width: 40px;
            height: 40px;
            border-radius: 50%;
            display: flex;
            align-items: center;
            justify-content: center;
            cursor: pointer;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.15);
            transition: var(--transition);
        }

        .theme-toggle:hover {
            transform: scale(1.1);
        }

        .card {
            background-color: var(--card-bg-light);
            border-radius: var(--border-radius);
            box-shadow: var(--box-shadow);
            margin-bottom: 30px;
            overflow: hidden;
            transition: var(--transition);
            transform: translateY(20px);
            opacity: 0;
            animation: fadeInUp 0.6s forwards;
        }

        body.dark-mode .card {
            background-color: var(--card-bg-dark);
            box-shadow: 0 10px 20px rgba(0, 0, 0, 0.3);
        }

        .card-header {
            background: linear-gradient(135deg, var(--primary-color), var(--secondary-color));
            color: white;
            padding: 18px 25px;
            font-size: 1.2rem;
            font-weight: 600;
            display: flex;
            align-items: center;
            transition: var(--transition);
        }

        .card-header i {
            margin-right: 12px;
            font-size: 1.4rem;
        }

        .card-body {
            padding: 25px;
        }

        .info-item {
            display: flex;
            margin-bottom: 15px;
            padding-bottom: 15px;
            border-bottom: 1px solid rgba(0, 0, 0, 0.05);
            animation: fadeIn 0.5s forwards;
        }

        body.dark-mode .info-item {
            border-bottom: 1px solid rgba(255, 255, 255, 0.05);
        }

        .info-item:last-child {
            margin-bottom: 0;
            padding-bottom: 0;
            border-bottom: none;
        }

        .info-label {
            font-weight: 600;
            color: var(--primary-color);
            min-width: 200px;
            flex-shrink: 0;
        }

        body.dark-mode .info-label {
            color: #4cc9f0;
        }

        .info-value {
            flex-grow: 1;
            color: var(--text-dark);
        }

        body.dark-mode .info-value {
            color: var(--text-light);
        }

        /* Fee Section Styles */
        .fee-section {
            margin-bottom: 30px;
        }

        .fee-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            padding: 12px 15px;
            background: linear-gradient(135deg, rgba(67, 97, 238, 0.15), rgba(58, 12, 163, 0.15));
            border-radius: 8px;
            margin-bottom: 15px;
            cursor: pointer;
            transition: var(--transition);
        }

        .fee-header:hover {
            background: linear-gradient(135deg, rgba(67, 97, 238, 0.25), rgba(58, 12, 163, 0.25));
        }

        body.dark-mode .fee-header {
            background: linear-gradient(135deg, rgba(67, 97, 238, 0.25), rgba(58, 12, 163, 0.25));
        }

        body.dark-mode .fee-header:hover {
            background: linear-gradient(135deg, rgba(67, 97, 238, 0.35), rgba(58, 12, 163, 0.35));
        }

        .fee-title {
            font-weight: 600;
            font-size: 1.1rem;
            color: var(--primary-color);
            display: flex;
            align-items: center;
        }

        body.dark-mode .fee-title {
            color: #4cc9f0;
        }

        .fee-title i {
            margin-right: 10px;
            font-size: 1.2rem;
        }

        .fee-header-right {
            display: flex;
            align-items: center;
        }

        .fee-total-amount {
            font-weight: 700;
            font-size: 1.1rem;
            color: var(--secondary-color);
            margin-right: 15px;
        }

        body.dark-mode .fee-total-amount {
            color: #f72585;
        }

        .view-details-btn {
            background: rgba(255, 255, 255, 0.2);
            border: none;
            color: white;
            padding: 5px 12px;
            border-radius: 20px;
            font-size: 0.9rem;
            cursor: pointer;
            transition: var(--transition);
            display: flex;
            align-items: center;
        }

        .view-details-btn i {
            margin-right: 5px;
        }

        .view-details-btn:hover {
            background: rgba(255, 255, 255, 0.3);
        }

        .fee-details {
            display: none;
            padding: 15px;
            background: rgba(0, 0, 0, 0.03);
            border-radius: 8px;
            margin-top: 10px;
        }

        body.dark-mode .fee-details {
            background: rgba(255, 255, 255, 0.05);
        }

        .fee-card {
            background: linear-gradient(135deg, rgba(67, 97, 238, 0.1), rgba(58, 12, 163, 0.1));
            border-radius: var(--border-radius);
            padding: 20px;
            margin-bottom: 15px;
            transition: var(--transition);
        }

        body.dark-mode .fee-card {
            background: linear-gradient(135deg, rgba(67, 97, 238, 0.2), rgba(58, 12, 163, 0.2));
        }

        .fee-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 8px 25px rgba(0, 0, 0, 0.15);
        }

        /* Modal Styles */
        .modal {
            display: none;
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.8);
            z-index: 1000;
            overflow-y: auto;
            padding: 20px;
            box-sizing: border-box;
        }

        .modal-content {
            background: var(--card-bg-light);
            border-radius: var(--border-radius);
            width: 90%;
            max-width: 900px;
            margin: 30px auto;
            padding: 30px;
            box-shadow: 0 10px 30px rgba(0, 0, 0, 0.3);
            position: relative;
            animation: modalFadeIn 0.3s ease-out;
        }

        body.dark-mode .modal-content {
            background: var(--card-bg-dark);
        }

        .modal-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
            padding-bottom: 15px;
            border-bottom: 1px solid rgba(0, 0, 0, 0.1);
        }

        body.dark-mode .modal-header {
            border-bottom: 1px solid rgba(255, 255, 255, 0.1);
        }

        .modal-title {
            font-size: 1.5rem;
            font-weight: 600;
            color: var(--primary-color);
            display: flex;
            align-items: center;
        }

        .modal-title i {
            margin-right: 10px;
        }

        .close-modal {
            background: none;
            border: none;
            font-size: 1.5rem;
            cursor: pointer;
            color: #6c757d;
            transition: var(--transition);
        }

        .close-modal:hover {
            color: var(--accent-color);
        }

        .modal-body {
            max-height: 70vh;
            overflow-y: auto;
            padding-right: 10px;
        }

        .year-section {
            margin-bottom: 25px;
        }

        .year-header {
            font-size: 1.2rem;
            font-weight: 600;
            color: white;
            margin-bottom: 15px;
            padding: 10px 15px;
            border-radius: 8px;
            background: linear-gradient(135deg, #3a0ca3, #4361ee);
            display: flex;
            align-items: center;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            position: relative;
            overflow: hidden;
        }

        .year-header::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            width: 5px;
            height: 100%;
            background: rgba(255, 255, 255, 0.3);
        }

        .year-header i {
            margin-right: 12px;
            font-size: 1.3rem;
            color: rgba(255, 255, 255, 0.9);
        }

        body.dark-mode .year-header {
            background: linear-gradient(135deg, #1a1a2e, #16213e);
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.3);
        }

        .month-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(250px, 1fr));
            gap: 15px;
        }

        .month-card {
            background: linear-gradient(135deg, rgba(67, 97, 238, 0.1), rgba(58, 12, 163, 0.1));
            border-radius: var(--border-radius);
            padding: 15px;
            transition: var(--transition);
        }

        body.dark-mode .month-card {
            background: linear-gradient(135deg, rgba(67, 97, 238, 0.2), rgba(58, 12, 163, 0.2));
        }

        .month-card:hover {
            transform: translateY(-3px);
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.1);
        }

        .month-name {
            font-weight: 600;
            color: var(--primary-color);
            margin-bottom: 10px;
            display: flex;
            align-items: center;
            justify-content: space-between;
        }

        body.dark-mode .month-name {
            color: #4cc9f0;
        }

        .month-amount {
            font-weight: 700;
            color: var(--secondary-color);
        }

        body.dark-mode .month-amount {
            color: #f72585;
        }

        .month-details {
            font-size: 0.9rem;
            color: #6c757d;
        }

        body.dark-mode .month-details {
            color: #adb5bd;
        }

        .loading-spinner {
            display: inline-block;
            width: 20px;
            height: 20px;
            border: 3px solid rgba(255, 255, 255, .3);
            border-radius: 50%;
            border-top-color: #fff;
            animation: spin 1s ease-in-out infinite;
            margin-right: 10px;
        }

        @keyframes spin {
            to {
                transform: rotate(360deg);
            }
        }

        .error-message {
            color: #e74c3c;
            padding: 15px;
            text-align: center;
        }

        .no-data {
            text-align: center;
            padding: 20px;
            color: #7f8c8d;
            font-style: italic;
        }

        /* Animations */
        @keyframes fadeInUp {
            from {
                opacity: 0;
                transform: translateY(20px);
            }

            to {
                opacity: 1;
                transform: translateY(0);
            }
        }

        @keyframes fadeIn {
            from {
                opacity: 0;
            }

            to {
                opacity: 1;
            }
        }

        @keyframes modalFadeIn {
            from {
                opacity: 0;
                transform: translateY(-20px);
            }

            to {
                opacity: 1;
                transform: translateY(0);
            }
        }

        .card:nth-child(1) {
            animation-delay: 0.1s;
        }

        .card:nth-child(2) {
            animation-delay: 0.2s;
        }

        .card:nth-child(3) {
            animation-delay: 0.3s;
        }

        .card:nth-child(4) {
            animation-delay: 0.4s;
        }

        .card:nth-child(5) {
            animation-delay: 0.5s;
        }

        /* Print Styles */
        @media print {
            body {
                background: white !important;
                color: black !important;
                font-size: 12pt;
                padding: 0;
            }

            .container {
                padding: 10px;
                max-width: 100%;
            }

            .card {
                box-shadow: none !important;
                border: 1px solid #ddd !important;
                page-break-inside: avoid;
                margin-bottom: 20px;
                transform: none !important;
                opacity: 1 !important;
            }

            .card-header {
                -webkit-print-color-adjust: exact;
                print-color-adjust: exact;
                background: var(--primary-color) !important;
                color: white !important;
            }

            .theme-toggle,
            .view-details-btn {
                display: none;
            }

            .info-label {
                color: var(--primary-color) !important;
            }

            .fee-details {
                display: block !important;
            }

            .modal {
                display: none !important;
            }
        }

        @media (max-width: 768px) {
            .info-item {
                flex-direction: column;
            }

            .info-label {
                margin-bottom: 5px;
                min-width: 100%;
            }

            .header h1 {
                font-size: 1.8rem;
            }

            .card-header {
                font-size: 1.1rem;
                padding: 15px 20px;
            }

            .card-body {
                padding: 20px 15px;
            }

            .fee-header {
                flex-direction: column;
                align-items: flex-start;
            }

            .fee-header-right {
                margin-top: 10px;
                width: 100%;
                justify-content: space-between;
            }

            .modal-content {
                width: 95%;
                padding: 20px;
            }

            .month-grid {
                grid-template-columns: 1fr;
            }
        }
    </style>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;500;600;700&display=swap" rel="stylesheet">
</head>

<body>
    <button class="theme-toggle" id="themeToggle">
        <i class="fas fa-moon"></i>
    </button>

    <div class="container">
        <div class="header">
            <h1><i class="fas fa-user-graduate"></i> ছাত্র ভর্তির তথ্য</h1>
            <p>সম্পূর্ণ তথ্যবহুল ও বিস্তারিত বিবরণ</p>
        </div>

        <?php
        include_once("../database/conn.php");

        $db = new DBConn();
        $conn = $db->getConnection();

        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $form_no = $_POST['form_no'];

            if (isset($form_no)) {
                $sql = "SELECT 
                    m.name AS madrasha_name,
                    s.*,
                    a.previous_school, a.previous_class, a.current_school, a.current_class,
                    o.annual_exam_result, o.admission_exam_result, o.examiner_name, o.opinion, 
                    o.head_name, o.approval, o.director_name, o.director_approval
                FROM selfstudents s
                JOIN madrashas m ON s.madrasha_email = m.email
                LEFT JOIN admissions a ON s.form_no = a.form_no
                LEFT JOIN officeadmissions o ON s.form_no = o.form_no
                WHERE s.form_no = ?";

                $stmt = $conn->prepare($sql);
                $stmt->bind_param("s", $form_no);
                $stmt->execute();
                $result = $stmt->get_result();

                if ($result->num_rows > 0) {
                    while ($row = $result->fetch_assoc()) {
        ?>
                        <!-- Madrasha Information Card -->
                        <div class="card">
                            <div class="card-header">
                                <i class="fas fa-school"></i> মাদরাসার তথ্য
                            </div>
                            <div class="card-body">
                                <div class="info-item">
                                    <div class="info-label">মাদরাসার নাম:</div>
                                    <div class="info-value"><?php echo $row["madrasha_name"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">ফরম নাম্বার:</div>
                                    <div class="info-value"><?php echo $row["form_no"]; ?></div>
                                </div>
                            </div>
                        </div>

                        <!-- Student Information Card -->
                        <div class="card">
                            <div class="card-header" style="background: linear-gradient(135deg, #4cc9f0, #4895ef);">
                                <i class="fas fa-user"></i> ছাত্রের তথ্য
                            </div>
                            <div class="card-body">
                                <div class="info-item">
                                    <div class="info-label">নাম:</div>
                                    <div class="info-value"><?php echo $row["student_name"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">ভর্তির বছর:</div>
                                    <div class="info-value"><?php echo $row["academic_year"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">ক্লাসের নাম:</div>
                                    <div class="info-value"><?php echo $row["class_name"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">ভর্তির তারিখ:</div>
                                    <div class="info-value"><?php echo $row["admission_date"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">বয়স:</div>
                                    <div class="info-value"><?php echo $row["age"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">জন্ম তারিখ:</div>
                                    <div class="info-value"><?php echo $row["birth_date"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">পিতার নাম:</div>
                                    <div class="info-value"><?php echo $row["father_name"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">পিতার পেশা:</div>
                                    <div class="info-value"><?php echo $row["father_profession"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">স্থায়ী ঠিকানা:</div>
                                    <div class="info-value"><?php echo $row["permanent_address"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">পোষ্ট:</div>
                                    <div class="info-value"><?php echo $row["post"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">থানা/উপজেলা:</div>
                                    <div class="info-value"><?php echo $row["upazila"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">জেলা:</div>
                                    <div class="info-value"><?php echo $row["district"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">বর্তমান ঠিকানা:</div>
                                    <div class="info-value"><?php echo $row["current_address"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">অভিভাবকের নাম:</div>
                                    <div class="info-value"><?php echo $row["guardian_name"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">সম্পর্ক:</div>
                                    <div class="info-value"><?php echo $row["guardian_relation"]; ?></div>
                                </div>
                            </div>
                        </div>

                        <!-- Admission Information Card -->
                        <div class="card">
                            <div class="card-header" style="background: linear-gradient(135deg, #f72585, #b5179e);">
                                <i class="fas fa-book-open"></i> শিক্ষা সংক্রান্ত তথ্য
                            </div>
                            <div class="card-body">
                                <div class="info-item">
                                    <div class="info-label">পূর্বের মাদরাসা:</div>
                                    <div class="info-value"><?php echo $row["previous_school"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">পূর্বের ক্লাস:</div>
                                    <div class="info-value"><?php echo $row["previous_class"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">বর্তমান মাদরাসা:</div>
                                    <div class="info-value"><?php echo $row["current_school"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">বর্তমান ক্লাস:</div>
                                    <div class="info-value"><?php echo $row["current_class"]; ?></div>
                                </div>
                            </div>
                        </div>

                        <!-- Office Information Card -->
                        <div class="card">
                            <div class="card-header" style="background: linear-gradient(135deg, #7209b7, #560bad);">
                                <i class="fas fa-building"></i> অফিসের তথ্য
                            </div>
                            <div class="card-body">
                                <div class="info-item">
                                    <div class="info-label">বার্ষিক পরীক্ষার ফলাফল:</div>
                                    <div class="info-value"><?php echo $row["annual_exam_result"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">ভর্তি পরীক্ষার ফলাফল:</div>
                                    <div class="info-value"><?php echo $row["admission_exam_result"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">পরীক্ষকের নাম:</div>
                                    <div class="info-value"><?php echo $row["examiner_name"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">মতামত:</div>
                                    <div class="info-value"><?php echo $row["opinion"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">শিক্ষা বিভাগ প্রধান:</div>
                                    <div class="info-value"><?php echo $row["head_name"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">অনুমোদন:</div>
                                    <div class="info-value"><?php echo $row["approval"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">পরিচালকের নাম:</div>
                                    <div class="info-value"><?php echo $row["director_name"]; ?></div>
                                </div>
                                <div class="info-item">
                                    <div class="info-label">পরিচালকের অনুমোদন:</div>
                                    <div class="info-value"><?php echo $row["director_approval"]; ?></div>
                                </div>
                            </div>
                        </div>

                        <!-- Fees Information Card -->
                        <div class="card">
                            <div class="card-header" style="background: linear-gradient(135deg, #3a0ca3, #480ca8);">
                                <i class="fas fa-money-bill-wave"></i> ফি সংক্রান্ত তথ্য
                            </div>
                            <div class="card-body">
                                <?php
                                $fees = [
                                    'admissionfee' => ['title' => 'ভর্তি ফি', 'fee_column' => 'admission_fee', 'icon' => 'fas fa-file-signature'],
                                    'boardingfee' => ['title' => 'বোর্ডিং ফি', 'fee_column' => 'boarding_fee', 'icon' => 'fas fa-home'],
                                    'monthlyfee' => ['title' => 'মাসিক বেতন', 'fee_column' => 'monthly_fee', 'icon' => 'fas fa-calendar-alt'],
                                    'examfee' => ['title' => 'পরীক্ষার ফি', 'fee_column' => 'exam_fee', 'icon' => 'fas fa-clipboard-list']
                                ];

                                foreach ($fees as $table => $details) {
                                    $sql = "SELECT id, {$details['fee_column']}, collected FROM {$table} WHERE form_no = ?";
                                    $stmt = $conn->prepare($sql);
                                    $stmt->bind_param("s", $form_no);
                                    $stmt->execute();
                                    $result = $stmt->get_result();

                                    if ($result->num_rows > 0) {
                                        $total_fee = 0;
                                        $fee_items = [];

                                        while ($row_fee = $result->fetch_assoc()) {
                                            $total_fee += $row_fee[$details['fee_column']];
                                            $fee_items[] = $row_fee;
                                        }

                                        echo '<div class="fee-section">';
                                        echo '<div class="fee-header" onclick="toggleFeeDetails(this)">';
                                        echo '<div class="fee-title"><i class="' . $details['icon'] . '"></i> ' . $details['title'] . '</div>';
                                        echo '<div class="fee-header-right">';
                                        echo '<div class="fee-total-amount">মোট: ' . $total_fee . ' টাকা</div>';
                                        echo '<button class="view-details-btn" onclick="showFeeModal(event, \'' . $details['title'] . '\', \'' . $form_no . '\', \'' . $table . '\', \'' . $details['fee_column'] . '\')">';
                                        echo '<i class="fas fa-expand"></i> বিস্তারিত দেখুন';
                                        echo '</button>';
                                        echo '</div>';
                                        echo '</div>';

                                        echo '<div class="fee-details">';
                                        foreach ($fee_items as $item) {
                                            echo '<div class="fee-card">';
                                            echo '<div class="info-item">';
                                            echo '<div class="info-label">পরিমাণ:</div>';
                                            echo '<div class="info-value">' . $item[$details['fee_column']] . ' টাকা</div>';
                                            echo '</div>';
                                            echo '<div class="info-item">';
                                            echo '<div class="info-label">সংগ্রহের তারিখ:</div>';
                                            echo '<div class="info-value">' . $item['collected'] . '</div>';
                                            echo '</div>';
                                            echo '</div>';
                                        }
                                        echo '</div>';
                                        echo '</div>';
                                    } else {
                                        echo '<div class="fee-section">';
                                        echo '<div class="fee-header">';
                                        echo '<div class="fee-title"><i class="' . $details['icon'] . '"></i> ' . $details['title'] . '</div>';
                                        echo '<div class="fee-header-right">';
                                        echo '<div class="fee-total-amount">মোট: ০ টাকা</div>';
                                        echo '</div>';
                                        echo '</div>';
                                        echo '<div class="info-item">';
                                        echo '<div class="info-value">কোন ' . $details['title'] . ' তথ্য পাওয়া যায়নি</div>';
                                        echo '</div>';
                                        echo '</div>';
                                    }

                                    $stmt->close();
                                }
                                ?>
                            </div>
                        </div>

                        <!-- Fee Details Modal -->
                        <div class="modal" id="feeModal">
                            <div class="modal-content">
                                <div class="modal-header">
                                    <div class="modal-title" id="modalTitle">
                                        <i class="fas fa-money-bill-wave"></i>
                                        <span id="modalTitleText">ফি বিস্তারিত তথ্য</span>
                                    </div>
                                    <button class="close-modal" onclick="closeModal()">&times;</button>
                                </div>
                                <div class="modal-body" id="modalBody">
                                    <!-- Content will be loaded dynamically -->
                                </div>
                            </div>
                        </div>
        <?php
                    }
                } else {
                    echo '<div class="card"><div class="card-body">No record found</div></div>';
                }
                // $stmt->close();
            } else {
                echo '<div class="card"><div class="card-body">No form number set</div></div>';
            }

            $conn->close();
        } else {
            echo '<div class="card"><div class="card-body">Invalid Request</div></div>';
        }
        ?>
    </div>

    <script>
        // Dark Mode Toggle
        const themeToggle = document.getElementById('themeToggle');
        const body = document.body;
        const icon = themeToggle.querySelector('i');

        const savedTheme = localStorage.getItem('theme');
        const systemPrefersDark = window.matchMedia('(prefers-color-scheme: dark)').matches;

        if (savedTheme === 'dark' || (!savedTheme && systemPrefersDark)) {
            body.classList.add('dark-mode');
            icon.classList.replace('fa-moon', 'fa-sun');
        }

        themeToggle.addEventListener('click', () => {
            body.classList.toggle('dark-mode');

            if (body.classList.contains('dark-mode')) {
                icon.classList.replace('fa-moon', 'fa-sun');
                localStorage.setItem('theme', 'dark');
            } else {
                icon.classList.replace('fa-sun', 'fa-moon');
                localStorage.setItem('theme', 'light');
            }
        });

        // Animation on scroll
        const cards = document.querySelectorAll('.card');

        const observer = new IntersectionObserver((entries) => {
            entries.forEach(entry => {
                if (entry.isIntersecting) {
                    entry.target.style.opacity = 1;
                    entry.target.style.transform = 'translateY(0)';
                }
            });
        }, {
            threshold: 0.1
        });

        cards.forEach(card => {
            observer.observe(card);
        });

        // Toggle fee details
        function toggleFeeDetails(header) {
            const details = header.nextElementSibling;
            if (details.style.display === 'block') {
                details.style.display = 'none';
            } else {
                details.style.display = 'block';
            }
        }

        // Show fee modal with detailed information from database
        function showFeeModal(event, feeType, formNo, tableName, feeColumn) {
            event.stopPropagation();

            const modal = document.getElementById('feeModal');
            const modalTitle = document.getElementById('modalTitleText');
            const modalBody = document.getElementById('modalBody');

            modalTitle.textContent = feeType + ' বিস্তারিত তথ্য';
            modalBody.innerHTML = `
                <div style="text-align: center; padding: 20px;">
                    <div class="loading-spinner"></div>
                    ডাটা লোড হচ্ছে...
                </div>
            `;

            // Fetch data from server
            fetch('get_fee_details.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                    body: `form_no=${formNo}&table=${tableName}&column=${feeColumn}`
                })
                .then(response => {
                    if (!response.ok) {
                        throw new Error('Network response was not ok');
                    }
                    return response.json();
                })
                .then(data => {
                    if (data.error) {
                        modalBody.innerHTML = `
                        <div class="error-message">
                            <i class="fas fa-exclamation-circle"></i>
                            ${data.error}
                        </div>
                    `;
                        return;
                    }

                    let modalContent = '';

                    // Group data by year
                    const dataByYear = {};
                    data.forEach(item => {
                        const dateParts = item.collected.split('-'); // Assuming YYYY-MM-DD format
                        const year = dateParts[0];
                        const month = parseInt(dateParts[1]) - 1; // JavaScript months are 0-indexed

                        if (!dataByYear[year]) {
                            dataByYear[year] = [];
                        }
                        dataByYear[year].push({
                            ...item,
                            month: month
                        });
                    });

                    

                    // Sort years in descending order
                    const years = Object.keys(dataByYear).sort((a, b) => b - a);

                    // Generate content for each year
                    years.forEach(year => {
                        modalContent += `
                        <div class="year-section">
                            <div class="year-header">
                                <i class="fas fa-calendar-alt"></i>
                                ${year} সাল
                            </div>
                            <div class="month-grid">
                    `;

                        // Sort months in descending order
                        dataByYear[year].sort((a, b) => b.month - a.month);

                        // Create a card for each payment in the year
                        dataByYear[year].forEach(payment => {
                            const months = [
                                'জানুয়ারি', 'ফেব্রুয়ারি', 'মার্চ', 'এপ্রিল',
                                'মে', 'জুন', 'জুলাই', 'আগস্ট',
                                'সেপ্টেম্বর', 'অক্টোবর', 'নভেম্বর', 'ডিসেম্বর'
                            ];
                            const monthName = months[payment.month];
                            const date = new Date(payment.collected);
                            const day = date.getDate();

                            modalContent += `
                            <div class="month-card">
                                <div class="month-name">
                                    ${monthName}
                                    <span class="month-amount">${payment[feeColumn]} টাকা</span>
                                </div>
                                <div class="month-details">
                                    <div><i class="fas fa-calendar-day"></i> তারিখ: ${day}/${payment.month+1}/${year}</div>
                                    <div><i class="fas fa-receipt"></i> রশিদ নং: ${payment.id || 'N/A'}</div>
                                    <div><i class="fas fa-check-circle"></i> স্ট্যাটাস: পরিশোধিত</div>
                                </div>
                            </div>
                        `;
                        });

                        modalContent += `
                            </div>
                        </div>
                    `;
                    });

                    if (years.length === 0) {
                        modalContent = `
                        <div class="no-data">
                            <i class="fas fa-info-circle"></i>
                            কোন বিস্তারিত তথ্য পাওয়া যায়নি
                        </div>
                    `;
                    }

                    modalBody.innerHTML = modalContent;
                })
                .catch(error => {
                    modalBody.innerHTML = `
                    <div class="error-message">
                        <i class="fas fa-exclamation-triangle"></i>
                        ডাটা লোড করতে সমস্যা হয়েছে: ${error.message}
                    </div>
                `;
                });

            modal.style.display = 'block';
            document.body.style.overflow = 'hidden';
        }

        // Close modal
        function closeModal() {
            const modal = document.getElementById('feeModal');
            modal.style.display = 'none';
            document.body.style.overflow = 'auto';
        }

        // Close modal when clicking outside
        window.onclick = function(event) {
            const modal = document.getElementById('feeModal');
            if (event.target == modal) {
                closeModal();
            }
        }
    </script>
</body>

</html>