<?php
require_once '../database/conn.php';

header('Content-Type: text/html; charset=utf-8');

$db = new DBConn();
$conn = $db->getConnection();

// সার্চ টার্ম পাওয়া
$searchTerm = isset($_GET['q']) ? trim($_GET['q']) : '';

try {
    if (!empty($searchTerm)) {
        // SQL query with prepared statement
        $sql = "SELECT 
                c.name AS class_name,
                s.student_name, 
                s.form_no,
                m.name AS madrasha_name
            FROM selfstudents s
            JOIN classes c ON s.class_id = c.classes_id
            JOIN madrashas m ON s.madrasha_email = m.email
            WHERE s.student_name LIKE CONCAT('%', ?, '%')
            OR m.name LIKE CONCAT('%', ?, '%')
            OR c.name LIKE CONCAT('%', ?, '%')
            OR s.form_no LIKE CONCAT('%', ?, '%')
            ORDER BY s.student_name ASC";

        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ssss", $searchTerm, $searchTerm, $searchTerm, $searchTerm);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            while ($row = $result->fetch_assoc()) {
                $initials = getInitials($row['student_name']);
                echo '
                <div class="student-card">
                    <div class="card-header">
                        '.$initials.'
                    </div>
                    <div class="card-body">
                        <h3 class="student-name">'.$row['student_name'].'</h3>
                        <p class="student-class">'.$row['class_name'].'</p>
                        <p class="student-madrasha">'.$row['madrasha_name'].'</p>
                    </div>
                    <div class="card-footer">
                        <form action="details.php" method="POST">
                            <input type="hidden" name="form_no" value="'.$row['form_no'].'">
                            <button type="submit" class="action-button details-button">সম্পূর্ণ প্রোফাইল দেখুন</button>
                        </form>
                        <button class="action-button delete-button" data-id="'.$row['form_no'].'">ছাত্র মুছুন</button>
                    </div>
                </div>';
            }
        } else {
            echo '<div class="no-data">কোন ফলাফল পাওয়া যায়নি: "'.htmlspecialchars($searchTerm).'"</div>';
        }
    } else {
        echo '<div class="no-data">সার্চ টার্ম লিখুন</div>';
    }
} catch (Exception $e) {
    echo '<div class="no-data">সার্চ করতে সমস্যা হয়েছে: '.$e->getMessage().'</div>';
}

function getInitials($name) {
    $words = explode(" ", $name);
    $initials = "";
    foreach ($words as $w) {
        $initials .= mb_substr($w, 0, 1);
        if(mb_strlen($initials) >= 2) break;
    }
    return $initials;
}
?>