<!DOCTYPE html>
<html lang="bn">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>ক্লাস ম্যানেজমেন্ট সিস্টেম</title>

    <link rel="stylesheet" href="../../css/glubal.style.css">

    <style>
        @font-face {
            font-family: 'bengali';
            src: url('../../fonts/siliguri_semibold.ttf') format('truetype');
            font-weight: normal;
            font-style: normal;
        }

        *,
        *::before,
        *::after {
            box-sizing: inherit;
            font-family: 'bengali', sans-serif;
            margin: 0;
            padding: 0;
        }

        html {
            box-sizing: border-box;
        }

        :root {
            --primary-color: #4361ee;
            --secondary-color: #3f37c9;
            --accent-color: #4895ef;
            --danger-color: #f72585;
            --success-color: #4cc9f0;
            --light-color: #f8f9fa;
            --dark-color: #212529;
            --gray-color: #6c757d;
            --card-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
            --transition: all 0.3s cubic-bezier(0.25, 0.8, 0.25, 1);
        }

        [data-theme="dark"] {
            --primary-color: #3a86ff;
            --secondary-color: #8338ec;
            --accent-color: #ff006e;
            --light-color: #1a1a2e;
            --dark-color: #f8f9fa;
            /* টেক্সটের জন্য হালকা কালার */
            --gray-color: #adb5bd;
        }

        body {
            background-color: var(--light-color);
            color: var(--dark-color);
            transition: var(--transition);
            min-height: 100vh;
        }

        /* লেআউট স্টাইল */
        .container {
            max-width: 1400px;
            margin: 0 auto;
            padding: 2rem;
        }

        /* হেডার স্টাইল */
        .header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 2.5rem;
            flex-wrap: wrap;
            gap: 1.5rem;
        }

        .logo {
            font-size: 1.8rem;
            font-weight: 700;
            color: var(--primary-color);
            display: flex;
            align-items: center;
            gap: 0.5rem;
        }

        .logo-icon {
            font-size: 1.8rem;
            color: var(--primary-color);
            margin-right: 10px;
            transition: transform 0.3s ease;
        }

        .logo:hover .logo-icon {
            transform: rotate(15deg);
        }

        /* সার্চ বার স্টাইল */
        .search-container {
            position: relative;
            display: flex;
            gap: 1rem;
            flex-grow: 1;
            max-width: 600px;
        }

        .search-bar {
            flex-grow: 1;
            padding: 0.8rem 1.2rem;
            border: 2px solid #e2e8f0;
            border-radius: 12px;
            font-size: 1rem;
            transition: var(--transition);
            background-color: rgba(255, 255, 255, 0.8);
        }

        .search-bar:focus {
            outline: none;
            border-color: var(--primary-color);
            box-shadow: 0 0 0 3px rgba(67, 97, 238, 0.2);
        }

        .clear-search {
            position: absolute;
            right: 110px;
            top: 50%;
            transform: translateY(-50%);
            background: none;
            border: none;
            color: var(--gray-color);
            cursor: pointer;
            font-size: 1rem;
            opacity: 0;
            visibility: hidden;
            transition: var(--transition);
        }

        .clear-search.visible {
            opacity: 1;
            visibility: visible;
        }

        .search-bar:not(:placeholder-shown)+.clear-search {
            opacity: 1;
            visibility: visible;
        }

        .search-button {
            padding: 0.8rem 1.5rem;
            background-color: var(--primary-color);
            color: white;
            border: none;
            border-radius: 12px;
            font-weight: 600;
            cursor: pointer;
            transition: var(--transition);
        }

        .search-button:hover {
            background-color: var(--secondary-color);
            transform: translateY(-2px);
        }

        /* ডার্ক মোড টগল */
        .theme-toggle {
            display: flex;
            align-items: center;
            gap: 0.5rem;
            background: none;
            border: none;
            cursor: pointer;
            color: var(--dark-color);
            font-weight: 600;
        }

        .toggle-icon {
            width: 40px;
            height: 24px;
            background-color: var(--gray-color);
            border-radius: 12px;
            position: relative;
            transition: var(--transition);
        }

        .toggle-icon::after {
            content: '';
            position: absolute;
            width: 18px;
            height: 18px;
            background-color: white;
            border-radius: 50%;
            top: 3px;
            left: 3px;
            transition: var(--transition);
        }

        [data-theme="dark"] .toggle-icon::after {
            transform: translateX(16px);
        }

        [data-theme="dark"] .student-name {
            color: #000;
            /* ডার্ক মোডেও কালো কালার থাকবে */
        }

        /* স্টুডেন্ট কাউন্ট */
        .student-count {
            background-color: var(--primary-color);
            color: white;
            padding: 0.6rem 1.2rem;
            border-radius: 12px;
            font-weight: 600;
            display: flex;
            align-items: center;
            gap: 0.5rem;
        }

        .count-icon {
            font-size: 1.2rem;
        }

        /* স্টুডেন্ট কার্ড গ্রিড */
        .student-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(320px, 1fr));
            gap: 1.5rem;
        }

        /* স্টুডেন্ট কার্ড */
        .student-card {
            background-color: white;
            border-radius: 16px;
            overflow: hidden;
            box-shadow: var(--card-shadow);
            transition: var(--transition);
            border: 1px solid #e2e8f0;
        }

        .student-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);
        }

        .card-header {
            height: 80px;
            background: linear-gradient(135deg, var(--primary-color), var(--secondary-color));
            display: flex;
            justify-content: center;
            align-items: center;
            color: white;
            font-size: 2.5rem;
        }

        .card-body {
            padding: 1.5rem;
            text-align: center;
        }

        .student-name {
            font-size: 1.4rem;
            font-weight: 700;
            margin-bottom: 0.5rem;
            color: var(--dark-color);
            /* এই লাইনটি যোগ করুন */
        }

        .student-class {
            color: var(--primary-color);
            font-weight: 600;
            margin-bottom: 0.5rem;
        }

        .student-madrasha {
            color: var(--gray-color);
            font-size: 0.9rem;
            margin-bottom: 1.5rem;
        }

        .card-footer {
            display: flex;
            flex-direction: column;
            gap: 0.75rem;
            padding: 0 1.5rem 1.5rem;
        }

        .action-button {
            padding: 0.7rem;
            border-radius: 8px;
            font-weight: 600;
            text-align: center;
            cursor: pointer;
            width: 100%;
            transition: var(--transition);
            border: none;
        }

        .details-button {
            background-color: var(--primary-color);
            color: white;
        }

        .details-button:hover {
            background-color: var(--secondary-color);
        }

        .delete-button {
            background-color: #f8f9fa;
            color: var(--danger-color);
            border: 1px solid #e2e8f0;
        }

        .delete-button:hover {
            background-color: #fff5f7;
        }

        /* নো ডাটা কন্টেইনার */
        .no-data-container {
            grid-column: 1 / -1;
            text-align: center;
            padding: 3rem;
            background-color: white;
            border-radius: 16px;
            box-shadow: var(--card-shadow);
            margin-top: 2rem;
        }

        .no-data-message {
            color: var(--gray-color);
            font-size: 1.5rem;
            margin-bottom: 2rem;
        }

        .add-student-btn {
            padding: 0.8rem 1.5rem;
            background-color: var(--primary-color);
            color: white;
            border: none;
            border-radius: 12px;
            font-size: 1rem;
            font-weight: 600;
            cursor: pointer;
            transition: var(--transition);
            text-decoration: none;
            display: inline-block;
        }

        .add-student-btn:hover {
            background-color: var(--secondary-color);
            transform: translateY(-2px);
        }

        .hidden {
            display: none !important;
        }






        /* মডাল স্টাইল */
        .modal-overlay {
            position: fixed;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: rgba(0, 0, 0, 0.5);
            display: flex;
            justify-content: center;
            align-items: center;
            z-index: 1000;
            opacity: 0;
            visibility: hidden;
            transition: all 0.3s ease;
        }

        .modal-overlay.active {
            opacity: 1;
            visibility: visible;
        }

        .modal-container {
            background-color: white;
            border-radius: 16px;
            box-shadow: 0 10px 25px rgba(0, 0, 0, 0.2);
            width: 90%;
            max-width: 400px;
            transform: translateY(20px);
            transition: all 0.3s ease;
            overflow: hidden;
        }

        .modal-overlay.active .modal-container {
            transform: translateY(0);
        }

        .modal-header {
            padding: 1.5rem;
            background-color: var(--primary-color);
            color: white;
            font-size: 1.3rem;
            font-weight: 600;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .modal-close {
            background: none;
            border: none;
            color: white;
            font-size: 1.5rem;
            cursor: pointer;
        }

/* মডাল বডির টেক্সট কালার ঠিক করুন */
.modal-body {
    padding: 1.5rem;
    color: var(--dark-color); /* এটি ব্যবহার করুন */
}

/* ডার্ক মোডে মডাল বডির ব্যাকগ্রাউন্ড কালার */
[data-theme="dark"] .modal-container {
    background-color: #2d3748; /* গাঢ় ধূসর */
}

/* ডার্ক মোডে মডাল টেক্সট কালার */
[data-theme="dark"] .modal-body {
    color: #f7fafc; /* হালকা সাদা */
}

/* ডার্ক মোডে মডাল হেডার কালার */
[data-theme="dark"] .modal-header {
    background-color: var(--primary-color);
    color: white;
}

/* ডার্ক মোডে কনফার্মেশন মেসেজ কালার */
[data-theme="dark"] #studentNameConfirm {
    color: #fef08a; /* হালকা হলুদ */
    font-weight: bold;
}



/* স্টুডেন্ট নামের জন্য বিশেষ স্টাইল */
.student-name-confirm {
    color: var(--primary-color);
    font-weight: bold;
}

[data-theme="dark"] .student-name-confirm {
    color: #fef08a; /* হালকা হলুদ */
}

/* সাকসেস মেসেজের জন্য স্টাইল */
.success-message {
    color: inherit; /* প্যারেন্টের কালার ইনহেরিট করবে */
}

/* এরর মেসেজের জন্য স্টাইল */
.error-message {
    color: inherit;
}




        .modal-footer {
            padding: 1rem 1.5rem;
            display: flex;
            justify-content: flex-end;
            gap: 1rem;
            border-top: 1px solid #e2e8f0;
        }

        .modal-btn {
            padding: 0.7rem 1.2rem;
            border-radius: 8px;
            font-weight: 600;
            cursor: pointer;
            transition: var(--transition);
            border: none;
        }

        .modal-btn-cancel {
            background-color: #f8f9fa;
            color: var(--gray-color);
        }

        .modal-btn-cancel:hover {
            background-color: #e9ecef;
        }

        .modal-btn-confirm {
            background-color: var(--danger-color);
            color: white;
        }

        .modal-btn-confirm:hover {
            background-color: #e5176e;
        }

        /* লোডিং এনিমেশন */
        .loading-spinner {
            display: inline-block;
            width: 30px;
            height: 30px;
            border: 3px solid rgba(255, 255, 255, .3);
            border-radius: 50%;
            border-top-color: var(--primary-color);
            animation: spin 1s ease-in-out infinite;
        }

        @keyframes spin {
            to {
                transform: rotate(360deg);
            }
        }



        .modal-btn-view {
    background-color: var(--accent-color);
    color: white;
    margin-right: auto; /* বাম দিকে পজিশন করার জন্য */
}

.modal-btn-view:hover {
    background-color: #3a7bd5;
}



        /* রেস্পন্সিভ ডিজাইন */
        @media (max-width: 768px) {
            .header {
                flex-direction: column;
                align-items: stretch;
            }

            .search-container {
                max-width: 100%;
            }

            .student-grid {
                grid-template-columns: 1fr;
            }
        }
    </style>


</head>

<body>
    <div class="container">
        <header class="header">
            <div class="logo">
                <i class="fa-solid fa-chalkboard-user logo-icon"></i>
                <span>স্টুডেন্ট ম্যানেজমেন্ট</span>
            </div>

            <div class="search-container">
                <input type="text" class="search-bar" placeholder="ছাত্র/ছাত্রীর নাম বা আইডি দিয়ে খুঁজুন...">
                <button class="clear-search" id="clear-search" title="খালি করুন">
                    <i class="fa-solid fa-times-circle"></i>
                </button>
                <button class="search-button">খুঁজুন</button>
            </div>

            <button class="theme-toggle">
                <span class="toggle-icon"></span>
                <span id="theme-text">ডার্ক মোড</span>
            </button>

            <div class="student-count">
                <span class="count-icon">👥</span>
                <span>মোট ছাত্র: <strong id="total-students">০</strong></span>
            </div>
        </header>

        <div class="student-grid" id="student-grid">
            <?php
            require_once '../database/conn.php';

            $db = new DBConn();
            $conn = $db->getConnection();
            $total_students = 0;

            if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['id'])) {
                $id = $_POST['id'];
                $email = $_POST['email'];

                if (!empty($id)) {
                    $sql = "SELECT 
                            c.name AS class_name, 
                            s.student_name, s.form_no, 
                            m.name AS madrasha_name
                        FROM selfstudents s
                        JOIN classes c ON s.class_id = c.classes_id
                        JOIN madrashas m ON s.madrasha_email = m.email
                        WHERE s.class_id = ? AND c.madrasha_email = ?";

                    $stmt = $conn->prepare($sql);
                    $stmt->bind_param("is", $id, $email);
                    $stmt->execute();
                    $result = $stmt->get_result();
                    $total_students = $result->num_rows;

                    if ($result->num_rows > 0) {
                        while ($row = $result->fetch_assoc()) {
                            $initials = getInitials($row['student_name']);
                            echo '
                            <div class="student-card">
                                <div class="card-header">
                                    ' . $initials . '
                                </div>
                                <div class="card-body">
                                    <h3 class="student-name">' . $row['student_name'] . '</h3>
                                    <h3 class="student-name">' . $row['form_no'] . '</h3>
                                    <p class="student-class">' . $row['class_name'] . '</p>
                                    <p class="student-madrasha">' . $row['madrasha_name'] . '</p>
                                </div>
                                <div class="card-footer">
                                    <form action="details.php" method="POST">
                                        <input type="hidden" name="form_no" value="' . $row['form_no'] . '">
                                        <button type="submit" class="action-button details-button">সম্পূর্ণ প্রোফাইল দেখুন</button>
                                    </form>
                                    <button class="action-button delete-button" data-id="' . $row['form_no'] . '">ছাত্র মুছুন</button>
                                </div>
                            </div>';
                        }
                    } else {
                        // Get class name for the message
                        $class_name = "";
                        $class_query = "SELECT name FROM classes WHERE classes_id = ?";
                        $stmt_class = $conn->prepare($class_query);
                        $stmt_class->bind_param("i", $id);
                        $stmt_class->execute();
                        $class_result = $stmt_class->get_result();
                        if ($class_result->num_rows > 0) {
                            $class_row = $class_result->fetch_assoc();
                            $class_name = $class_row['name'];
                        }

                        echo '
                        <div class="no-data-container">
                            <p class="no-data-message">' . "( " . $class_name . " )" . ' ক্লাসে কোন ছাত্র পাওয়া যায়নি</p>
                            <button class="add-student-btn" onclick="window.history.back()"><i class="fa-solid fa-user-plus"></i> নতুন ছাত্র ভর্তি করুন</button>
                        </div>
                        ';

                        echo '
                        <style>
                            .header, .student-count {
                                display: none;
                            }
                            .container {
                                padding-top: 5rem;
                            }
                        </style>';
                    }
                } else {
                    echo '<div class="no-data-container">
                        <p class="no-data-message">ক্লাস আইডি প্রদান করা হয়নি</p>
                        <a href="classes.php" class="add-student-btn">ক্লাস সিলেক্ট করুন</a>
                    </div>';
                }
            } else {
                echo '<div class="no-data-container">
                    <p class="no-data-message">ক্লাস নির্বাচন করুন</p>
                    <a href="classes.php" class="add-student-btn">ক্লাস সিলেক্ট করুন</a>
                </div>';
            }

            function getInitials($name)
            {
                $words = explode(" ", $name);
                $initials = "";
                foreach ($words as $w) {
                    $initials .= mb_substr($w, 0, 1);
                    if (mb_strlen($initials) >= 2)
                        break;
                }
                return $initials;
            }
            ?>
        </div>








        <!-- কনফার্মেশন মডাল -->
<div class="modal-overlay" id="confirmModal">
    <div class="modal-container">
        <div class="modal-header">
            <span>নিশ্চিত করুন</span>
            <button class="modal-close">&times;</button>
        </div>
        <div class="modal-body" id="confirmModalBody">
            আপনি কি নিশ্চিত যে "<span id="studentNameConfirm" class="student-name-confirm"></span>" কে মুছতে চান?
        </div>
        <div class="modal-footer">
            <button class="modal-btn modal-btn-cancel">বাতিল</button>
            <button class="modal-btn modal-btn-confirm">মুছুন</button>
        </div>
    </div>
</div>

<!-- সাকসেস মডাল -->
<div class="modal-overlay" id="successModal">
    <div class="modal-container">
        <div class="modal-header" style="background-color: var(--success-color);">
            <span>সফল</span>
            <button class="modal-close">&times;</button>
        </div>
        <div class="modal-body" id="successModalBody">
            <span class="success-message">ছাত্র সফলভাবে মুছে ফেলা হয়েছে</span>
        </div>
        <div class="modal-footer">
            <button class="modal-btn modal-btn-view" id="viewDeletedStudentBtn">ফেরত টাকা ‍যুক্ত করুন</button>
            <button class="modal-btn modal-btn-cancel">ঠিক আছে</button>
        </div>
    </div>
</div>
        <!-- এরর মডাল -->
        <div class="modal-overlay" id="errorModal">
            <div class="modal-container">
                <div class="modal-header" style="background-color: var(--danger-color);">
                    <span>সমস্যা</span>
                    <button class="modal-close">&times;</button>
                </div>
                <div class="modal-body" id="errorModalBody">
                    ছাত্র মুছতে সমস্যা হয়েছে
                </div>
                <div class="modal-footer">
                    <button class="modal-btn modal-btn-cancel">ঠিক আছে</button>
                </div>
            </div>
        </div>

        <!-- লোডিং মডাল -->
        <div class="modal-overlay" id="loadingModal">
            <div class="modal-container" style="text-align: center; padding: 2rem;">
                <div class="loading-spinner"></div>
                <div class="modal-body" style="margin-top: 1rem;">
                    মুছে ফেলা হচ্ছে...
                </div>
            </div>
        </div>




    </div>

    <script>
        // ডার্ক/লাইট মোড টগল
        const themeToggle = document.querySelector('.theme-toggle');
        const themeText = document.getElementById('theme-text');
        const body = document.body;

        // চেক লোকাল স্টোরেজ ফর থিম প্রেফারেন্স
        const currentTheme = localStorage.getItem('theme') || 'light';
        body.setAttribute('data-theme', currentTheme);
        themeText.textContent = currentTheme === 'dark' ? 'লাইট মোড' : 'ডার্ক মোড';

        themeToggle.addEventListener('click', () => {
            const currentTheme = body.getAttribute('data-theme');
            const newTheme = currentTheme === 'dark' ? 'light' : 'dark';

            body.setAttribute('data-theme', newTheme);
            themeText.textContent = newTheme === 'dark' ? 'লাইট মোড' : 'ডার্ক মোড';
            localStorage.setItem('theme', newTheme);
        });

        // Clear search functionality with auto-reload
        const clearSearch = document.getElementById('clear-search');
        const searchBar = document.querySelector('.search-bar');
        const searchButton = document.querySelector('.search-button');

        clearSearch.addEventListener('click', () => {
            if (searchBar.value.length > 0) {
                searchBar.value = '';

                // Show all hidden elements
                document.querySelector('.header').classList.remove('hidden');
                document.querySelector('.student-count').classList.remove('hidden');

                window.location.reload();
            }
        });

        searchBar.addEventListener('input', function () {
            // Show/hide clear button
            this.value.length > 0 ?
                clearSearch.classList.add('visible') :
                clearSearch.classList.remove('visible');

            // Auto reload when search box becomes empty
            if (this.value.length === 0 && this === document.activeElement) {
                window.location.reload();
            }
        });

        // Handle when search box loses focus
        searchBar.addEventListener('blur', function () {
            if (this.value.length === 0) {
                clearSearch.classList.remove('visible');
            }
        });

        // টোটাল স্টুডেন্ট কাউন্ট আপডেট
        document.getElementById('total-students').textContent = <?php echo $total_students; ?>;

        // সার্চ ফাংশনালিটি
        searchButton.addEventListener('click', performSearch);

        searchBar.addEventListener('keypress', (e) => {
            if (e.key === 'Enter') {
                performSearch();
            }
        });

        function performSearch() {
            const searchTerm = searchBar.value.trim();
            if (searchTerm) {
                // Show loading state
                const studentGrid = document.getElementById('student-grid');
                studentGrid.innerHTML = '<div class="loading"><div class="spinner"></div></div>';

                // AJAX request for search
                fetch('search.php?q=' + encodeURIComponent(searchTerm))
                    .then(response => response.text())
                    .then(html => {
                        studentGrid.innerHTML = html;

                        // Check if no results found
                        if (studentGrid.querySelector('.no-data-container')) {
                            document.querySelector('.header').classList.add('hidden');
                            document.querySelector('.student-count').classList.add('hidden');
                        }
                    })
                    .catch(error => {
                        console.error('Error:', error);
                        studentGrid.innerHTML = '<div class="no-data-container"><p class="no-data-message">সার্চ করতে সমস্যা হয়েছে</p></div>';
                    });
            }
        }


        // মডাল ফাংশনালিটি
        document.addEventListener('DOMContentLoaded', function () {
            // মডাল এলিমেন্ট সিলেক্ট করুন
            const confirmModal = document.getElementById('confirmModal');
            const successModal = document.getElementById('successModal');
            const errorModal = document.getElementById('errorModal');
            const loadingModal = document.getElementById('loadingModal');

            // সব মডাল ক্লোজ বাটনে ইভেন্ট যোগ করুন
            document.querySelectorAll('.modal-close, .modal-btn-cancel').forEach(btn => {
                btn.addEventListener('click', function () {
                    closeAllModals();
                });
            });

            // গ্লোবাল ভেরিয়েবল ডিলিটেড স্টুডেন্ট ডাটা স্টোর করার জন্য
        let deletedStudentData = null;
        
        // ডিলিট বাটনে ক্লিক ইভেন্ট হ্যান্ডলার
        document.querySelectorAll('.delete-button').forEach(button => {
            button.addEventListener('click', function(e) {
                e.preventDefault();
                const formNo = this.getAttribute('data-id');
                const studentCard = this.closest('.student-card');
                const studentName = studentCard.querySelector('.student-name').textContent;
                const studentClass = studentCard.querySelector('.student-class').textContent;
                const studentMadrasha = studentCard.querySelector('.student-madrasha').textContent;
                
                // ডিলিটেড স্টুডেন্ট ডাটা স্টোর করুন
                deletedStudentData = {
                    formNo: formNo,
                    name: studentName,
                    class: studentClass,
                    madrasha: studentMadrasha
                };

                // কনফার্মেশন মডাল শো করুন
                document.getElementById('studentNameConfirm').textContent = studentName;
                confirmModal.classList.add('active');
                
                // কনফার্ম বাটনে ইভেন্ট লিসেনার যোগ করুন
                document.querySelector('.modal-btn-confirm').onclick = function() {
                    confirmModal.classList.remove('active');
                    loadingModal.classList.add('active');
                    
                    // AJAX রিকুয়েস্ট পাঠান
                    fetch('delete_student.php', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/x-www-form-urlencoded',
                        },
                        body: `form_no=${formNo}`
                    })
                    .then(response => response.json())
                    .then(data => {
                        loadingModal.classList.remove('active');
                        if(data.success) {
                            // সাকসেস মডাল শো করুন
                            successModal.classList.add('active');
                            
                            // গুটু ভিও বাটনে ইভেন্ট যোগ করুন
                            document.getElementById('viewDeletedStudentBtn').onclick = function() {
                                // ফর্ম তৈরি করে সাবমিট করুন
                                const form = document.createElement('form');
                                form.method = 'POST';
                                form.action = '../../return_sector/add_return.php';
                                
                                // ইনপুট ফিল্ডস যোগ করুন
                                const addInput = (name, value) => {
                                    const input = document.createElement('input');
                                    input.type = 'hidden';
                                    input.name = name;
                                    input.value = value;
                                    form.appendChild(input);
                                };
                                
                                addInput('form_no', deletedStudentData.formNo);
                                addInput('name', deletedStudentData.name);
                                addInput('class', deletedStudentData.class);
                                addInput('madrasha', deletedStudentData.madrasha);
                                
                                document.body.appendChild(form);
                                form.submit();
                            };
                            
                            // কার্ড রিমুভ করুন
                            setTimeout(() => {
                                studentCard.remove();
                                // টোটাল স্টুডেন্ট কাউন্ট আপডেট করুন
                                const totalStudents = document.getElementById('total-students');
                                totalStudents.textContent = parseInt(totalStudents.textContent) - 1;
                            }, 1500);
                        } else {
                            // এরর মডাল শো করুন
                            document.getElementById('errorModalBody').textContent = 
                                data.message || 'ছাত্র মুছতে সমস্যা হয়েছে';
                            errorModal.classList.add('active');
                        }
                    })
                    .catch(error => {
                        loadingModal.classList.remove('active');
                        document.getElementById('errorModalBody').textContent = 
                            'ছাত্র মুছতে সমস্যা হয়েছে: ' + error.message;
                        errorModal.classList.add('active');
                        console.error('Error:', error);
                    });
                };
            });
        });

            // সব মডাল ক্লোজ করার ফাংশন
            function closeAllModals() {
                document.querySelectorAll('.modal-overlay').forEach(modal => {
                    modal.classList.remove('active');
                });
            }

            // মডালের বাইরে ক্লিক করলে ক্লোজ হবে
            document.querySelectorAll('.modal-overlay').forEach(modal => {
                modal.addEventListener('click', function (e) {
                    if (e.target === this) {
                        closeAllModals();
                    }
                });
            });
        });
    </script>

    <script src="../../js/all.min.js"></script>
</body>

</html>