<?php
include_once("../db/database/conn.php");

$db = new DBConn();
$conn = $db->getConnection();

// Check if it's an AJAX request
$is_ajax = isset($_SERVER['HTTP_X_REQUESTED_WITH']) && strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) === 'xmlhttprequest';

$email = $_POST["email"] ?? '';
$search_term = $_POST["search"] ?? '';
$search_type = $_POST["search_type"] ?? 'head';
$expense_head = $_POST["expense_head"] ?? '';
$reset_request = isset($_POST['reset']) && $_POST['reset'] === 'true';

// Expense head translations
$expense_head_translation = [
    "current_bill" => "কারেন্ট বিল",
    "building_market_cost" => "বোর্ডিং বাজার খরচ",
    "cylinder_gas" => "সিলিন্ডার গ্যাস",
    "waz_materials" => "ওয়াজের কোপন, পোষ্টার, হেমবিল, পেন্ডেল, মাইক",
    "official_expense" => "আনুষ্ঠানিক খরচ",
    "electronics_expenses" => "ইলেক্ট্রনিক্স খরচ",
    "guests_treatment" => "মেহমানদের আপ্যায়ন খরচ",
    "tabligh_jamat_treatment" => "তাবলীগ জামাতের আপ্যায়ন খরচ",
    "helth" => "ছাত্র চিকিৎসা ফি",
    "library" => "মাদ্রাসার লাইব্রেরী ম্যানেজিং খরচ"
];

// Load expense data
$sql = "SELECT id, expense_head, expense_details, expense_ammount, created_at FROM expense WHERE madrasha_email = ?";
$params = ["s", $email];

if (!$reset_request && (!empty($search_term) || ($search_type === 'head' && !empty($expense_head)))) {
    switch($search_type) {
        case 'head':
            if (!empty($expense_head)) {
                $sql .= " AND expense_head = ?";
                $params[0] .= "s";
                array_push($params, $expense_head);
            }
            break;
        case 'details':
            $sql .= " AND expense_details LIKE ?";
            $params[0] .= "s";
            array_push($params, "%$search_term%");
            break;
        case 'amount':
            $sql .= " AND expense_ammount = ?";
            $params[0] .= "d";
            array_push($params, $search_term);
            break;
        case 'date':
            $sql .= " AND DATE(created_at) = ?";
            $params[0] .= "s";
            array_push($params, $search_term);
            break;
    }
}

$stmt = $conn->prepare($sql);
if (count($params) > 1) {
    $stmt->bind_param(...$params);
} else {
    $stmt->bind_param("s", $email);
}
$stmt->execute();
$result = $stmt->get_result();

// Calculate totals
$hadiya_sql = "SELECT SUM(salary) as total_salary FROM hadiya WHERE email = ?";
$hadiya_stmt = $conn->prepare($hadiya_sql);
$hadiya_stmt->bind_param("s", $email);
$hadiya_stmt->execute();
$hadiya_result = $hadiya_stmt->get_result();
$hadiya_total = ($hadiya_result && $row = $hadiya_result->fetch_assoc()) ? ($row['total_salary'] ?? 0) : 0;

$total_salary_sql = "SELECT SUM(expense_ammount) as total FROM expense WHERE madrasha_email = ?";
$total_salary_stmt = $conn->prepare($total_salary_sql);
$total_salary_stmt->bind_param("s", $email);
$total_salary_stmt->execute();
$total_salary_row = $total_salary_stmt->get_result()->fetch_assoc();
$total_salary = $total_salary_row['total'] ?? 0;

$grand_total = $hadiya_total + $total_salary;

// Function to convert 24-hour time to 12-hour format with AM/PM in Bangla
function convertToBanglaTime($datetime) {
    $time = date("h:i A", strtotime($datetime));
    $time = str_replace("AM", "AM", $time);
    $time = str_replace("PM", "PM", $time);
    $date = date("d/m/Y", strtotime($datetime));
    return "$date, $time";
}

// AJAX response
if ($is_ajax) {
    $expenses = [];
    while ($row = $result->fetch_assoc()) {
        $expenses[] = [
            'id' => $row['id'],
            'head' => $expense_head_translation[$row['expense_head']] ?? $row['expense_head'],
            'amount' => number_format($row['expense_ammount'], 2),
            'details' => $row['expense_details'],
            'date' => convertToBanglaTime($row['created_at'])
        ];
    }
    
    header('Content-Type: application/json');
    echo json_encode([
        'success' => true,
        'expenses' => $expenses,
        'hadiya_total' => number_format($hadiya_total, 2),
        'total_salary' => number_format($total_salary, 2),
        'grand_total' => number_format($grand_total, 2),
        'count' => $result->num_rows,
        'reset' => $reset_request
    ]);
    exit;
}
?>

<!DOCTYPE html>
<html lang="bn">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>খরচের তথ্য দেখুন</title>
    <style>
        :root {
            --primary-color: #4361ee;
            --danger-color: #f72585;
            --warning-color: #f8961e;
            --success-color: #4cc9f0;
            --light-color: #f8f9fa;
            --dark-color: #212529;
            --text-color: #495057;
            --card-shadow: 0 4px 20px rgba(0, 0, 0, 0.08);
            --transition: all 0.3s cubic-bezier(0.25, 0.8, 0.25, 1);
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: 'Segoe UI', 'Nirmala UI', 'Kalpurush', sans-serif;
        }

        body {
            background-color: #f5f7fa;
            color: var(--text-color);
            line-height: 1.6;
            min-height: 100vh;
        }

        .container {
            max-width: 1200px;
            margin: 0 auto;
            padding: 2rem;
        }

        .header {
            text-align: center;
            margin-bottom: 2.5rem;
        }

        .header h1 {
            color: var(--dark-color);
            font-size: 2.2rem;
            margin-bottom: 0.5rem;
            font-weight: 700;
            background: linear-gradient(135deg, #4361ee, #3a0ca3);
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
        }

        .search-container {
            display: flex;
            flex-wrap: wrap;
            gap: 1rem;
            margin-bottom: 2.5rem;
            background: white;
            padding: 1.5rem;
            border-radius: 12px;
            box-shadow: var(--card-shadow);
        }

        .search-form {
            display: flex;
            flex-grow: 1;
            gap: 1rem;
            flex-wrap: wrap;
        }

        .search-input-group {
            flex: 1;
            min-width: 250px;
        }

        .search-input {
            width: 100%;
            padding: 0.8rem 1.2rem;
            border: 1px solid #ddd;
            border-radius: 8px;
            font-size: 1rem;
            transition: var(--transition);
        }

        .search-type-select, .expense-head-select {
            padding: 0.8rem 1.2rem;
            border: 1px solid #ddd;
            border-radius: 8px;
            font-size: 1rem;
            background: white;
            min-width: 180px;
        }

        .search-buttons {
            display: flex;
            gap: 0.5rem;
            min-width: 300px;
        }

        .search-btn {
            background: linear-gradient(135deg, var(--primary-color), #3a0ca3);
            color: white;
            border: none;
            padding: 0 1.5rem;
            border-radius: 8px;
            cursor: pointer;
            font-size: 1rem;
            font-weight: 600;
            transition: var(--transition);
            box-shadow: 0 4px 15px rgba(67, 97, 238, 0.3);
            display: flex;
            align-items: center;
            gap: 0.5rem;
        }

        .reset-btn {
            background: linear-gradient(135deg, #6c757d, #495057);
            color: white;
            border: none;
            padding: 0 1.5rem;
            border-radius: 8px;
            cursor: pointer;
            font-size: 1rem;
            font-weight: 600;
            transition: var(--transition);
            box-shadow: 0 4px 15px rgba(108, 117, 125, 0.3);
            display: flex;
            align-items: center;
            gap: 0.5rem;
        }

        .search-btn:hover {
            background: linear-gradient(135deg, #3a56e0, #2a0a8a);
            transform: translateY(-2px);
            box-shadow: 0 6px 20px rgba(67, 97, 238, 0.4);
        }

        .reset-btn:hover {
            background: linear-gradient(135deg, #5a6268, #343a40);
            transform: translateY(-2px);
            box-shadow: 0 6px 20px rgba(108, 117, 125, 0.4);
        }

        .expense-head-container {
            display: none;
            flex: 1;
            min-width: 250px;
        }

        .search-loading {
            display: none;
            margin-left: 10px;
            color: #4361ee;
        }

        .summary-cards {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
            gap: 1.5rem;
            margin-bottom: 2.5rem;
        }

        .dashboard {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
            gap: 1.5rem;
        }

        .card {
            background: white;
            border-radius: 12px;
            box-shadow: var(--card-shadow);
            overflow: hidden;
            transition: var(--transition);
        }

        .card:hover {
            transform: translateY(-5px);
            box-shadow: 0 15px 30px rgba(0, 0, 0, 0.12);
        }

        .card-header {
            background: linear-gradient(135deg, var(--danger-color), #b5179e);
            color: white;
            padding: 1.2rem 1.5rem;
            font-size: 1.2rem;
            font-weight: 600;
            position: relative;
            overflow: hidden;
        }

        .card-header.success {
            background: linear-gradient(135deg, var(--success-color), #4895ef);
        }

        .card-header.warning {
            background: linear-gradient(135deg, var(--warning-color), #f3722c);
        }

        .card-header.info {
            background: linear-gradient(135deg, #7209b7, #3a0ca3);
        }

        .card-body {
            padding: 2rem;
            text-align: center;
        }

        .total-amount {
            font-size: 2rem;
            font-weight: 700;
            color: var(--dark-color);
            margin-bottom: 0.5rem;
        }

        .total-label {
            font-size: 1rem;
            color: var(--text-color);
        }

        .expense-item {
            background: white;
            border-radius: 12px;
            padding: 1.5rem;
            margin-bottom: 1rem;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.08);
            border-left: 4px solid var(--danger-color);
            transition: var(--transition);
        }

        .expense-item:hover {
            transform: translateY(-3px);
            box-shadow: 0 6px 16px rgba(0, 0, 0, 0.12);
        }

        .expense-actions {
            display: flex;
            gap: 0.75rem;
            margin-top: 1rem;
        }

        .action-btn {
            padding: 0.6rem 1rem;
            border-radius: 8px;
            font-size: 0.9rem;
            font-weight: 500;
            display: flex;
            align-items: center;
            gap: 0.5rem;
            transition: var(--transition);
            border: none;
            cursor: pointer;
        }

        .details-btn {
            background: linear-gradient(135deg, var(--primary-color), #4895ef);
            color: white;
        }

        .delete-btn {
            background: linear-gradient(135deg, var(--danger-color), #ef233c);
            color: white;
        }

        .action-btn:hover {
            transform: translateY(-2px);
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }

        .no-data {
            text-align: center;
            padding: 2rem;
            color: #adb5bd;
            font-size: 1.1rem;
            grid-column: 1 / -1;
        }

        /* Modal Styles */
        .modal-overlay {
            position: fixed;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background: rgba(0, 0, 0, 0.7);
            display: flex;
            justify-content: center;
            align-items: center;
            z-index: 1000;
            opacity: 0;
            visibility: hidden;
            transition: all 0.3s ease;
            backdrop-filter: blur(5px);
        }

        .modal-overlay.active {
            opacity: 1;
            visibility: visible;
        }

        .modal-container {
            background: white;
            border-radius: 12px;
            width: 90%;
            max-width: 500px;
            box-shadow: 0 20px 40px rgba(0, 0, 0, 0.2);
            transform: translateY(-20px) scale(0.95);
            transition: all 0.4s cubic-bezier(0.175, 0.885, 0.32, 1.275);
            overflow: hidden;
        }

        .modal-overlay.active .modal-container {
            transform: translateY(0) scale(1);
        }

        .modal-header {
            padding: 1.5rem;
            border-bottom: 1px solid #eee;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .modal-title {
            font-size: 1.5rem;
            font-weight: 600;
            color: var(--dark-color);
            margin: 0;
        }

        .close-btn {
            background: none;
            border: none;
            font-size: 1.5rem;
            cursor: pointer;
            color: #6c757d;
            transition: var(--transition);
        }

        .close-btn:hover {
            color: var(--danger-color);
        }

        .modal-body {
            padding: 1.5rem;
        }

        .modal-footer {
            padding: 1rem 1.5rem;
            border-top: 1px solid #eee;
            display: flex;
            justify-content: flex-end;
            gap: 0.75rem;
        }

        .modal-btn {
            padding: 0.75rem 1.5rem;
            border-radius: 8px;
            font-weight: 500;
            cursor: pointer;
            transition: var(--transition);
            border: none;
        }

        .modal-btn-cancel {
            background: #f8f9fa;
            color: #495057;
        }

        .modal-btn-cancel:hover {
            background: #e9ecef;
        }

        .modal-btn-delete {
            background: linear-gradient(135deg, var(--danger-color), #ef233c);
            color: white;
        }

        .modal-btn-delete:hover {
            background: linear-gradient(135deg, #e51773, #d90429);
        }

        .detail-row {
            display: flex;
            margin-bottom: 1rem;
            padding-bottom: 1rem;
            border-bottom: 1px solid #f1f1f1;
        }

        .detail-row:last-child {
            margin-bottom: 0;
            padding-bottom: 0;
            border-bottom: none;
        }

        .detail-label {
            font-weight: 600;
            color: var(--dark-color);
            min-width: 120px;
        }

        .detail-value {
            flex: 1;
            color: var(--text-color);
        }

        /* Delete Modal Specific Styles */
        .delete-modal .modal-container {
            text-align: center;
        }

        .modal-icon {
            font-size: 3rem;
            margin: 1rem 0;
            color: var(--danger-color);
        }

        .modal-text {
            margin-bottom: 2rem;
            color: var(--text-color);
            line-height: 1.6;
        }

        @media (max-width: 768px) {
            .dashboard, .summary-cards {
                grid-template-columns: 1fr;
            }
            
            .search-container {
                flex-direction: column;
            }
            
            .search-form {
                flex-direction: column;
            }
            
            .search-input-group, 
            .search-type-select, 
            .search-btn, 
            .expense-head-select,
            .reset-btn {
                width: 100%;
            }
            
            .search-buttons {
                flex-direction: column;
                min-width: auto;
            }

            .detail-row {
                flex-direction: column;
            }

            .detail-label {
                margin-bottom: 0.5rem;
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <h1>খরচের তথ্য দেখুন</h1>
        </div>

        <div class="search-container">
            <form id="searchForm" class="search-form">
                <input type="hidden" name="email" value="<?php echo htmlspecialchars($email); ?>">
                <input type="hidden" name="reset" id="resetFlag" value="false">
                
                <div class="search-input-group" id="searchInputGroup">
                    <input type="text" name="search" class="search-input" 
                           placeholder="বিবরণ, পরিমাণ বা তারিখ অনুসন্ধান করুন..." 
                           value="<?php echo htmlspecialchars($search_term); ?>">
                </div>
                
                <div class="expense-head-container" id="expenseHeadContainer">
                    <select name="expense_head" id="expenseHead" class="expense-head-select">
                        <option value="">ব্যয় খাত নির্বাচন করুন:</option>
                        <?php foreach($expense_head_translation as $value => $label): ?>
                            <option value="<?= $value ?>" <?= $expense_head === $value ? 'selected' : '' ?>>
                                <?= $label ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                
                <select name="search_type" class="search-type-select" id="searchTypeSelect">
                    <option value="head" <?= $search_type === 'head' ? 'selected' : '' ?>>খরচের হেড অনুযায়ী</option>
                    <option value="details" <?= $search_type === 'details' ? 'selected' : '' ?>>বিবরণ অনুযায়ী</option>
                    <option value="amount" <?= $search_type === 'amount' ? 'selected' : '' ?>>পরিমাণ অনুযায়ী</option>
                    <option value="date" <?= $search_type === 'date' ? 'selected' : '' ?>>তারিখ অনুযায়ী (YYYY-MM-DD)</option>
                </select>
                
                <div class="search-buttons">
                    <button type="submit" class="search-btn" id="searchButton">
                        <span class="action-icon">🔍</span> অনুসন্ধান
                        <span class="search-loading" id="searchLoading">অপেক্ষা করুন...</span>
                    </button>
                    <button type="button" class="reset-btn" id="resetButton">
                        <span class="action-icon">🔄</span> রিসেট
                    </button>
                </div>
            </form>
        </div>

        <div class="summary-cards">
            <div class="card">
                <div class="card-header success">
                    <h3>টোটাল হাদিয়া</h3>
                </div>
                <div class="card-body">
                    <div class="total-amount" id="hadiyaTotal"><?= number_format($hadiya_total, 2) ?> টাকা</div>
                    <div class="total-label">মোট হাদিয়ার পরিমাণ</div>
                </div>
            </div>

            <div class="card">
                <div class="card-header warning">
                    <h3>বিভাগ অনুযায়ী বেতন</h3>
                </div>
                <div class="card-body">
                    <div class="total-amount" id="totalSalary"><?= number_format($total_salary, 2) ?> টাকা</div>
                    <div class="total-label">সকল বিভাগের বেতনের সমষ্টি</div>
                </div>
            </div>

            <div class="card">
                <div class="card-header info">
                    <h3>সর্বমোট হিসাব</h3>
                </div>
                <div class="card-body">
                    <div class="total-amount" id="grandTotal"><?= number_format($grand_total, 2) ?> টাকা</div>
                    <div class="total-label">হাদিয়া ও বেতনের মোট সমষ্টি</div>
                </div>
            </div>
        </div>

        <div class="dashboard" id="expenseDashboard">
            <?php if ($result->num_rows > 0): ?>
                <?php while ($row = $result->fetch_assoc()): ?>
                    <?php 
                    $expense_head_bn = $expense_head_translation[$row['expense_head']] ?? $row['expense_head'];
                    $formatted_date = convertToBanglaTime($row['created_at']);
                    ?>
                    <div class="expense-item">
                        <h3 class="expense-title"><?= htmlspecialchars($expense_head_bn) ?></h3>
                        <div class="expense-content">
                            <div class="expense-info">
                                <p class="expense-amount"><?= number_format($row['expense_ammount'], 2) ?> টাকা</p>
                                <p class="expense-date"><?= htmlspecialchars($formatted_date) ?></p>
                            </div>
                            <div class="expense-actions">
                                <button class="action-btn details-btn" data-id="<?= $row['id'] ?>"
                                    data-head="<?= htmlspecialchars($expense_head_bn) ?>"
                                    data-amount="<?= number_format($row['expense_ammount'], 2) ?>"
                                    data-details="<?= htmlspecialchars($row['expense_details']) ?>"
                                    data-date="<?= htmlspecialchars($formatted_date) ?>">
                                    <span class="action-icon">🔍</span> বিস্তারিত
                                </button>
                                <button class="action-btn delete-btn" data-id="<?= $row['id'] ?>">
                                    <span class="action-icon">🗑️</span> ডিলিট
                                </button>
                            </div>
                        </div>
                    </div>
                <?php endwhile; ?>
            <?php else: ?>
                <div class="no-data">কোনো ডাটা পাওয়া যায়নি</div>
            <?php endif; ?>
        </div>
    </div>

    <!-- Delete Confirmation Modal -->
    <div class="modal-overlay delete-modal" id="deleteModal">
        <div class="modal-container">
            <div class="modal-icon">❌</div>
            <h3 class="modal-title">আপনি কি নিশ্চিত?</h3>
            <p class="modal-text">এই খরচের তথ্য ডিলিট করা হলে তা পুনরুদ্ধার করা যাবে না।<br>আপনি কি নিশ্চিতভাবে ডিলিট করতে চান?</p>
            <form id="deleteForm" method="POST" action="delete_expense.php">
                <input type="hidden" name="id" id="deleteId">
                <input type="hidden" name="email" value="<?= htmlspecialchars($email) ?>">
                <div class="modal-footer">
                    <button type="button" class="modal-btn modal-btn-cancel" id="cancelDelete">বাতিল</button>
                    <button type="submit" class="modal-btn modal-btn-delete">ডিলিট করুন</button>
                </div>
            </form>
        </div>
    </div>

    <!-- Expense Details Modal -->
    <div class="modal-overlay details-modal" id="detailsModal">
        <div class="modal-container">
            <div class="modal-header">
                <h3 class="modal-title">খরচের বিস্তারিত</h3>
                <button class="close-btn" id="closeDetails">&times;</button>
            </div>
            <div class="modal-body">
                <div class="detail-row">
                    <span class="detail-label">খরচের হেড:</span>
                    <span class="detail-value" id="detail-head">-</span>
                </div>
                <div class="detail-row">
                    <span class="detail-label">পরিমাণ:</span>
                    <span class="detail-value" id="detail-amount">-</span>
                </div>
                <div class="detail-row">
                    <span class="detail-label">বিস্তারিত:</span>
                    <span class="detail-value" id="detail-details">-</span>
                </div>
                <div class="detail-row">
                    <span class="detail-label">তারিখ:</span>
                    <span class="detail-value" id="detail-date">-</span>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="modal-btn modal-btn-cancel" id="closeDetailsBtn">বন্ধ করুন</button>
            </div>
        </div>
    </div>

    <script>
        document.addEventListener('DOMContentLoaded', function () {
            // Elements
            const searchForm = document.getElementById('searchForm');
            const searchButton = document.getElementById('searchButton');
            const resetButton = document.getElementById('resetButton');
            const searchLoading = document.getElementById('searchLoading');
            const expenseDashboard = document.getElementById('expenseDashboard');
            const hadiyaTotal = document.getElementById('hadiyaTotal');
            const totalSalary = document.getElementById('totalSalary');
            const grandTotal = document.getElementById('grandTotal');
            const resetFlag = document.getElementById('resetFlag');
            const searchInput = document.querySelector('input[name="search"]');
            const expenseHeadSelect = document.getElementById('expenseHead');
            const searchTypeSelect = document.getElementById('searchTypeSelect');
            const searchInputGroup = document.getElementById('searchInputGroup');
            const expenseHeadContainer = document.getElementById('expenseHeadContainer');

            // Search form submission
            searchForm.addEventListener('submit', function(e) {
                e.preventDefault();
                performSearch();
            });

            // Reset button functionality
            resetButton.addEventListener('click', function() {
                resetSearch();
            });

            // Search type change handler
            searchTypeSelect.addEventListener('change', function() {
                toggleSearchFields();
            });

            // Initialize
            toggleSearchFields();

            function performSearch() {
                // Show loading indicator
                searchLoading.style.display = 'inline';
                searchButton.disabled = true;
                resetButton.disabled = true;
                
                // Prepare form data
                const formData = new FormData(searchForm);
                
                // Send AJAX request
                fetch(window.location.href, {
                    method: 'POST',
                    body: formData,
                    headers: {
                        'X-Requested-With': 'XMLHttpRequest'
                    }
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        updateDashboard(data);
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                })
                .finally(() => {
                    // Hide loading indicator
                    searchLoading.style.display = 'none';
                    searchButton.disabled = false;
                    resetButton.disabled = false;
                });
            }

            function resetSearch() {
                // Show loading indicator
                searchLoading.style.display = 'inline';
                searchButton.disabled = true;
                resetButton.disabled = true;
                
                // Clear form fields
                searchInput.value = '';
                expenseHeadSelect.value = '';
                searchTypeSelect.value = 'head';
                resetFlag.value = 'true';
                
                // Toggle fields to show head search by default
                toggleSearchFields();
                
                // Submit the form with reset flag
                performSearch();
                
                // Reset the flag after search
                resetFlag.value = 'false';
            }

            function updateDashboard(data) {
                // Update summary cards
                hadiyaTotal.textContent = data.hadiya_total + ' টাকা';
                totalSalary.textContent = data.total_salary + ' টাকা';
                grandTotal.textContent = data.grand_total + ' টাকা';
                
                // Clear existing results
                expenseDashboard.innerHTML = '';
                
                // Add new results
                if (data.count > 0) {
                    data.expenses.forEach(expense => {
                        const expenseItem = document.createElement('div');
                        expenseItem.className = 'expense-item';
                        expenseItem.innerHTML = `
                            <h3 class="expense-title">${expense.head}</h3>
                            <div class="expense-content">
                                <div class="expense-info">
                                    <p class="expense-amount">${expense.amount} টাকা</p>
                                    <p class="expense-date">${expense.date}</p>
                                </div>
                                <div class="expense-actions">
                                    <button class="action-btn details-btn" data-id="${expense.id}"
                                        data-head="${expense.head}"
                                        data-amount="${expense.amount}"
                                        data-details="${expense.details}"
                                        data-date="${expense.date}">
                                        <span class="action-icon">🔍</span> বিস্তারিত
                                    </button>
                                    <button class="action-btn delete-btn" data-id="${expense.id}">
                                        <span class="action-icon">🗑️</span> ডিলিট
                                    </button>
                                </div>
                            </div>
                        `;
                        expenseDashboard.appendChild(expenseItem);
                    });
                    
                    // Reattach event listeners to new buttons
                    attachEventListeners();
                } else {
                    const noData = document.createElement('div');
                    noData.className = 'no-data';
                    noData.textContent = 'কোনো ডাটা পাওয়া যায়নি';
                    expenseDashboard.appendChild(noData);
                }
            }

            function toggleSearchFields() {
                if (searchTypeSelect.value === 'head') {
                    searchInputGroup.style.display = 'none';
                    expenseHeadContainer.style.display = 'block';
                } else {
                    searchInputGroup.style.display = 'block';
                    expenseHeadContainer.style.display = 'none';
                    
                    if (searchTypeSelect.value === 'date') {
                        searchInput.type = 'date';
                        searchInput.placeholder = 'YYYY-MM-DD ফরম্যাটে তারিখ নির্বাচন করুন';
                    } else if (searchTypeSelect.value === 'amount') {
                        searchInput.type = 'number';
                        searchInput.placeholder = 'পরিমাণ লিখুন';
                    } else {
                        searchInput.type = 'text';
                        searchInput.placeholder = 'বিবরণ অনুসন্ধান করুন...';
                    }
                }
            }

            function attachEventListeners() {
                // Attach event listeners to details and delete buttons
                document.querySelectorAll('.details-btn').forEach(button => {
                    button.addEventListener('click', showDetailsModal);
                });
                
                document.querySelectorAll('.delete-btn').forEach(button => {
                    button.addEventListener('click', showDeleteModal);
                });
            }

            function showDetailsModal() {
                // Get all data attributes
                const head = this.getAttribute('data-head');
                const amount = this.getAttribute('data-amount');
                const details = this.getAttribute('data-details');
                const date = this.getAttribute('data-date');

                // Populate the modal with actual data
                document.getElementById('detail-head').textContent = head;
                document.getElementById('detail-amount').textContent = amount + ' টাকা';
                document.getElementById('detail-details').textContent = details || 'N/A';
                document.getElementById('detail-date').textContent = date;

                document.getElementById('detailsModal').classList.add('active');
                document.body.style.overflow = 'hidden';
            }
            
            function showDeleteModal() {
                const expenseId = this.getAttribute('data-id');
                document.getElementById('deleteId').value = expenseId;
                document.getElementById('deleteModal').classList.add('active');
                document.body.style.overflow = 'hidden';
            }

            // Initialize event listeners
            attachEventListeners();

            // Modal close functionality
            function closeAllModals() {
                document.querySelectorAll('.modal-overlay').forEach(modal => {
                    modal.classList.remove('active');
                });
                document.body.style.overflow = 'auto';
            }

            document.getElementById('cancelDelete').addEventListener('click', closeAllModals);
            document.getElementById('closeDetailsBtn').addEventListener('click', closeAllModals);
            document.getElementById('closeDetails').addEventListener('click', closeAllModals);

            document.querySelectorAll('.modal-overlay').forEach(modal => {
                modal.addEventListener('click', function(e) {
                    if (e.target === modal) {
                        closeAllModals();
                    }
                });
            });

            // Keyboard escape to close modals
            document.addEventListener('keydown', function(e) {
                if (e.key === 'Escape') {
                    closeAllModals();
                }
            });
        });
    </script>
</body>
</html>
<?php
$stmt->close();
$hadiya_stmt->close();
$total_salary_stmt->close();
$conn->close();
?>