<?php
include_once('db/database/conn.php');

$db = new DBConn();
$conn = $db->getConnection();

// Get JSON data
$data = json_decode(file_get_contents("php://input"), true);

// Sanitize inputs
$formNo = mysqli_real_escape_string($conn, $data['formNo'] ?? '');
$email = mysqli_real_escape_string($conn, $data['email'] ?? '');
$year = mysqli_real_escape_string($conn, $data['year'] ?? '');
$month = mysqli_real_escape_string($conn, $data['month'] ?? '');

// Query to get daily attendance
$query = "SELECT 
            DATE_FORMAT(attendance_date, '%d/%m/%Y') as date,
            status,
            comments
          FROM daily_attendance
          WHERE form_no = ?
          AND email = ?
          AND YEAR(attendance_date) = ?
          AND MONTH(attendance_date) = ?
          ORDER BY attendance_date";

$stmt = $conn->prepare($query);
$stmt->bind_param("ssii", $formNo, $email, $year, $month);
$stmt->execute();

$result = $stmt->get_result();
$dailyData = [];

while ($row = $result->fetch_assoc()) {
    $dailyData[] = $row;
}

echo json_encode([
    'success' => true,
    'data' => $dailyData
]);

$stmt->close();
$conn->close();
?>