<?php
// attendance_api.php

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['error' => 'Invalid request method'], JSON_UNESCAPED_UNICODE);
    exit;
}

// Database connection
include_once '../db/database/conn.php';
$db = new DBConn();
$conn = $db->getConnection();

// Get form data
$name = $_POST['name'] ?? '';
$phone = $_POST['phone'] ?? '';
$type = $_POST['type'] ?? '';
$status = $_POST['status'] ?? '';
$amount = $_POST['amount'] ?? 0;
$time = $_POST['time'] ?? '';
$email = $_POST['email'] ?? '';

// Validate required fields
if (empty($name) || empty($phone) || empty($email) || empty($time)) {
    echo json_encode(['error' => 'Required fields are missing'], JSON_UNESCAPED_UNICODE);
    exit;
}

// Map status to categories
$categories = '';
switch ($status) {
    case 'beton':
        $categories = 'বেতন';
        break;
    case 'exumfee':
        $categories = 'পরীক্ষার ফি';
        break;
    case 'bonas':
        $categories = 'বোনাস';
        break;
    default:
        $categories = 'অন্যান্য';
        break;
}

try {
    // Prepare SQL statement
    $stmt = $conn->prepare("
        INSERT INTO hadiya (name, phone, salary, categories, type, dates, email)
        VALUES (?, ?, ?, ?, ?, ?, ?)
    ");

    // Bind parameters
    $stmt->bind_param("sidssss", $name, $phone, $amount, $categories, $type, $time, $email);

    // Execute the query
    if ($stmt->execute()) {
        $response = [
            'success' => 'ডাটা জমা দেওয়া হয়েছে',
        ];
        echo json_encode($response, JSON_UNESCAPED_UNICODE);
    } else {
        $response = [
            'error' => 'ডাটা! ডাটাবেসে সংরক্ষণ করতে সমস্যা হয়েছে',
            'details' => $conn->error
        ];
        echo json_encode($response, JSON_UNESCAPED_UNICODE);
    }

    $stmt->close();
} catch (Exception $e) {
    echo json_encode(['error' => 'ত্রুটি: ' . $e->getMessage()], JSON_UNESCAPED_UNICODE);
} finally {
    $conn->close();
}