<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>বেতন লিস্ট</title>
    <link href="https://fonts.googleapis.com/css2?family=Hind+Siliguri:wght@400;500;600;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <style>
        :root {
            --primary-color: #3498db;
            --secondary-color: #2ecc71;
            --text-color: #2c3e50;
            --bg-color: #f5f7fa;
            --card-bg: #ffffff;
            --error-color: #e74c3c;
            --border-color: #ecf0f1;
        }

        [data-theme="dark"] {
            --primary-color: #3a86ff;
            --secondary-color: #8338ec;
            --text-color: #f8f9fa;
            --bg-color: #121212;
            --card-bg: #1e1e1e;
            --error-color: #ff6b6b;
            --border-color: #333333;
        }

        body {
            font-family: 'Hind Siliguri', sans-serif;
            background: var(--bg-color);
            margin: 0;
            padding: 30px;
            min-height: 100vh;
            color: var(--text-color);
            transition: all 0.3s ease;
        }

        .header {
            text-align: center;
            margin-bottom: 30px;
            position: relative;
        }

        .header h1 {
            color: var(--primary-color);
            font-weight: 700;
            margin-bottom: 10px;
            font-size: 2.2rem;
        }

        .controls {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
            flex-wrap: wrap;
            gap: 15px;
        }

        .search-container {
            position: relative;
            flex-grow: 1;
            max-width: 400px;
        }

        .search-container input {
            width: 100%;
            padding: 12px 20px 12px 45px;
            border-radius: 30px;
            border: 1px solid var(--border-color);
            background: var(--card-bg);
            color: var(--text-color);
            font-size: 16px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            transition: all 0.3s ease;
        }

        .search-container input:focus {
            outline: none;
            box-shadow: 0 0 0 3px rgba(58, 134, 255, 0.2);
            border-color: var(--primary-color);
        }

        .search-container i {
            position: absolute;
            left: 15px;
            top: 50%;
            transform: translateY(-50%);
            color: var(--primary-color);
        }

        .action-buttons {
            display: flex;
            gap: 10px;
            flex-wrap: wrap;
            align-items: center;
        }

        .summary-card {
            background: linear-gradient(135deg, var(--primary-color), var(--secondary-color));
            color: white;
            padding: 15px 25px;
            border-radius: 12px;
            box-shadow: 0 5px 15px rgba(0,0,0,0.1);
            text-align: center;
            min-width: 200px;
        }
        
        
        .summary-amount {
            font-size: 1.5rem;
            font-weight: 700;
            margin: 0;
        }

        .theme-switch {
            position: relative;
            display: inline-block;
            width: 60px;
            height: 30px;
        }

        .theme-switch input {
            opacity: 0;
            width: 0;
            height: 0;
        }

        .slider {
            position: absolute;
            cursor: pointer;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background-color: #ccc;
            transition: .4s;
            border-radius: 34px;
        }

        .slider:before {
            position: absolute;
            content: "";
            height: 22px;
            width: 22px;
            left: 4px;
            bottom: 4px;
            background-color: white;
            transition: .4s;
            border-radius: 50%;
        }

        input:checked + .slider {
            background: linear-gradient(45deg, #3a86ff, #8338ec);
        }

        input:checked + .slider:before {
            transform: translateX(30px);
        }

        .slider i {
            position: absolute;
            top: 50%;
            transform: translateY(-50%);
            font-size: 14px;
            color: white;
        }

        .fa-sun {
            left: 8px;
        }

        .fa-moon {
            right: 8px;
        }

        .dataContainer {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
            gap: 25px;
            margin-top: 20px;
        }

        .card {
            background: var(--card-bg);
            border-radius: 18px;
            padding: 25px;
            box-shadow: 0 10px 30px rgba(0, 0, 0, 0.08);
            transition: all 0.3s cubic-bezier(0.25, 0.8, 0.25, 1);
            position: relative;
            overflow: hidden;
            border: none;
        }

        .card::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            width: 5px;
            height: 100%;
            background: linear-gradient(to bottom, var(--primary-color), var(--secondary-color));
        }

        .card:hover {
            transform: translateY(-8px);
            box-shadow: 0 15px 35px rgba(0, 0, 0, 0.12);
        }

        .card p {
            margin: 12px 0;
            color: var(--text-color);
            font-size: 16px;
            line-height: 1.6;
            display: flex;
            justify-content: space-between;
        }

        .card p strong {
            color: var(--text-color);
            font-weight: 600;
            margin-right: 10px;
        }

        .card p span.value {
            color: var(--primary-color);
            font-weight: 500;
            text-align: right;
        }

        .type-badge {
            position: absolute;
            top: 20px;
            right: 20px;
            padding: 6px 12px;
            border-radius: 20px;
            font-size: 14px;
            font-weight: 600;
            text-transform: uppercase;
            letter-spacing: 0.5px;
        }

        .servant-badge {
            background: linear-gradient(45deg, #e74c3c, #f39c12);
            color: white;
        }

        .teacher-badge {
            background: linear-gradient(45deg, var(--primary-color), var(--secondary-color));
            color: white;
        }

        .no-data {
            text-align: center;
            color: var(--text-color);
            opacity: 0.7;
            font-size: 18px;
            margin-top: 50px;
            grid-column: 1 / -1;
        }

        .card-header {
            border-bottom: 1px solid var(--border-color);
            padding-bottom: 15px;
            margin-bottom: 15px;
        }

        .card-header h3 {
            color: var(--text-color);
            font-weight: 700;
            margin: 0;
            font-size: 1.4rem;
        }

        @media (max-width: 768px) {
            .dataContainer {
                grid-template-columns: 1fr;
            }
            
            body {
                padding: 15px;
            }
            
            .header h1 {
                font-size: 1.8rem;
            }

            .controls {
                flex-direction: column;
                align-items: stretch;
            }

            .search-container {
                max-width: 100%;
            }

            .summary-card {
                width: 100%;
            }
        }

        @keyframes fadeIn {
            from { opacity: 0; transform: translateY(20px); }
            to { opacity: 1; transform: translateY(0); }
        }

        .card {
            animation: fadeIn 0.5s ease-out forwards;
            opacity: 0;
        }

        .card:nth-child(1) { animation-delay: 0.1s; }
        .card:nth-child(2) { animation-delay: 0.2s; }
        .card:nth-child(3) { animation-delay: 0.3s; }
        .card:nth-child(4) { animation-delay: 0.4s; }
        .card:nth-child(5) { animation-delay: 0.5s; }
        .card:nth-child(6) { animation-delay: 0.6s; }
    </style>
</head>
<body>

<div class="header">
    <h1>বেতন বিবরণী</h1>
</div>

<div class="controls">
    <div class="search-container">
        <i class="fas fa-search"></i>
        <input type="text" id="searchInput" placeholder="যে কোন কিছু দিয়ে খুঁজুন..." autocomplete="off">
    </div>
    
    <div class="action-buttons">
        <div class="summary-card" id="totalSalaryCard">
            <p class="summary-amount">৳ ০</p>
        </div>
        
        <label class="theme-switch">
            <input type="checkbox" id="themeToggle">
            <span class="slider">
                <i class="fas fa-sun"></i>
                <i class="fas fa-moon"></i>
            </span>
        </label>
    </div>
</div>

<?php
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        $email = $_POST['email'];
    }
?>

<input type="hidden" id="email" name="email" value="<?php echo $email; ?>">

<div class="dataContainer"></div>

<script src="https://cdn.jsdelivr.net/npm/axios/dist/axios.min.js"></script>

<script>
    const email = document.getElementById("email").value;
    let allData = [];

    // Theme Toggle Functionality
    const themeToggle = document.getElementById('themeToggle');
    const prefersDarkScheme = window.matchMedia('(prefers-color-scheme: dark)');

    const currentTheme = localStorage.getItem('theme') || 
                        (prefersDarkScheme.matches ? 'dark' : 'light');
    
    if (currentTheme === 'dark') {
        document.body.setAttribute('data-theme', 'dark');
        themeToggle.checked = true;
    }

    themeToggle.addEventListener('change', function() {
        if (this.checked) {
            document.body.setAttribute('data-theme', 'dark');
            localStorage.setItem('theme', 'dark');
        } else {
            document.body.removeAttribute('data-theme');
            localStorage.setItem('theme', 'light');
        }
    });

    // Convert to 12-hour format with AM/PM
    function formatTo12Hour(dateTimeString) {
        if (!dateTimeString) return 'N/A';
        
        const date = new Date(dateTimeString);
        if (isNaN(date.getTime())) return dateTimeString;
        
        let hours = date.getHours();
        const minutes = date.getMinutes();
        const ampm = hours >= 12 ? 'PM' : 'AM';
        
        hours = hours % 12;
        hours = hours ? hours : 12;
        
        const strTime = `${hours}:${minutes.toString().padStart(2, '0')} ${ampm}`;
        return `${date.toLocaleDateString()} ${strTime}`;
    }

    // Calculate Total Salary
    function calculateTotalSalary(data) {
        let total = 0;
        const salaryFields = ['amount', 'salary', 'beton', 'payment_amount'];
        
        data.forEach(item => {
            for (const field of salaryFields) {
                if (item[field]) {
                    const salary = parseFloat(item[field]);
                    if (!isNaN(salary)) {
                        total += salary;
                        break;
                    }
                }
            }
        });
        
        return total;
    }

    // Search Functionality
    function filterCards(searchTerm) {
        const cards = document.querySelectorAll('.card');
        let hasResults = false;
        
        cards.forEach(card => {
            const textContent = card.textContent.toLowerCase();
            if (textContent.includes(searchTerm.toLowerCase())) {
                card.style.display = 'block';
                hasResults = true;
            } else {
                card.style.display = 'none';
            }
        });
        
        const noDataMsg = document.querySelector('.no-data');
        if (!hasResults && cards.length > 0) {
            if (!noDataMsg) {
                const container = document.querySelector('.dataContainer');
                container.insertAdjacentHTML('beforeend', 
                    `<p class="no-data">কোনো মিল পাওয়া যায়নি</p>`);
            }
        } else if (noDataMsg && hasResults) {
            noDataMsg.remove();
        }
    }

    document.getElementById('searchInput').addEventListener('input', function() {
        filterCards(this.value.trim());
    });

    // Display Data Function
    async function displayHadiya() {
        try {
            const response = await axios.post('display_api.php', {
                email: email 
            });

            let data = response.data;

            if (data.status === 'success' && data.data.length > 0) {
                allData = data.data;
                const container = document.querySelector('.dataContainer');
                container.innerHTML = '';

                // Calculate and show total salary
                const totalSalary = calculateTotalSalary(data.data);
                document.querySelector('#totalSalaryCard .summary-amount').textContent = 
                    `সর্বমোট ${totalSalary.toLocaleString('bn-BD')} ৳`;

                data.data.forEach((item, index) => {
                    const card = document.createElement('div');
                    card.classList.add('card');
                    
                    // Add badge based on type
                    let badge = '';
                    if (item.type === 'servant') {
                        badge = `<span class="type-badge servant-badge">খাদেম</span>`;
                    } else if (item.type === 'teacher') {
                        badge = `<span class="type-badge teacher-badge">উস্তাদ</span>`;
                    }
                    
                    // Format dates to 12-hour format
                    const formattedData = {};
                    for (const key in item) {
                        if (key.toLowerCase().includes('date') || key.toLowerCase().includes('time')) {
                            formattedData[key] = formatTo12Hour(item[key]);
                        } else {
                            formattedData[key] = item[key];
                        }
                    }
                    
                    // Create card content
                    let content = `
                        ${badge}
                        <div class="card-header">
                            <h3>${formattedData.name || 'নাম নেই'}</h3>
                        </div>
                    `;
                    
                    for (let key in formattedData) {
                        if (key !== 'email' && key !== 'type' && key !== 'name') {
                            let displayKey = key.replace(/_/g, ' ');
                            displayKey = displayKey.charAt(0).toUpperCase() + displayKey.slice(1);
                            
                            // Format salary values
                            let value = formattedData[key];
                            if (['amount', 'salary', 'beton', 'payment_amount'].includes(key)) {
                                value = `৳ ${parseFloat(value).toLocaleString('bn-BD')}`;
                            }
                            
                            content += `
                                <p>
                                    <strong>${displayKey}:</strong> 
                                    <span class="value">${value}</span>
                                </p>
                            `;
                        }
                    }

                    card.innerHTML = content;
                    container.appendChild(card);
                    
                    card.style.animationDelay = `${index * 0.1}s`;
                });

            } else {
                document.querySelector('#totalSalaryCard').style.display = 'none';
                document.querySelector('.dataContainer').innerHTML = `
                    <p class="no-data">
                        <svg xmlns="http://www.w3.org/2000/svg" width="50" height="50" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
                            <circle cx="12" cy="12" r="10"></circle>
                            <line x1="12" y1="8" x2="12" y2="12"></line>
                            <line x1="12" y1="16" x2="12.01" y2="16"></line>
                        </svg>
                        <br>
                        কোনো তথ্য পাওয়া যায়নি
                    </p>`;
            }

        } catch (error) {
            console.error('Error fetching data:', error);
            document.querySelector('#totalSalaryCard').style.display = 'none';
            document.querySelector('.dataContainer').innerHTML = `
                <p class="no-data" style="color:var(--error-color);">
                    <svg xmlns="http://www.w3.org/2000/svg" width="50" height="50" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
                        <circle cx="12" cy="12" r="10"></circle>
                        <line x1="12" y1="8" x2="12" y2="12"></line>
                        <line x1="12" y1="16" x2="12.01" y2="16"></line>
                    </svg>
                    <br>
                    তথ্য লোড করতে সমস্যা হয়েছে
                </p>`;
        }
    }

    displayHadiya();
</script>

</body>
</html>