<?php
include_once("../db/database/conn.php");
$db = new DBConn();
$conn = $db->getConnection();

// Input handling
$email = $_POST['email'] ?? '';
$table = $_POST['table'] ?? '';
$column = $_POST['column'] ?? '';
$headColumn = $_POST['income_head'] ?? null;
$searchDate = $_POST['search_date'] ?? '';

// Validate inputs
if (empty($email) || empty($table) || empty($column)) {
    echo json_encode(["error" => "Missing required parameters."]);
    exit;
}

// Build SQL query with optional date filter
$sql = "SELECT * FROM `$table` WHERE email = ?";
$params = ["s", $email];

if (!empty($searchDate)) {
    $sql .= " AND DATE(collected) = ?";
    $params[0] .= "s";
    $params[] = $searchDate;
}

$sql .= " ORDER BY collected DESC";

$stmt = $conn->prepare($sql);

// Dynamic binding based on parameters
if (count($params) > 1) {
    $stmt->bind_param(...$params);
} else {
    $stmt->bind_param($params[0], $params[1]);
}

$stmt->execute();
$result = $stmt->get_result();

// Group data by date and calculate total
$groupedData = [];
$totalAmount = 0;
while ($row = $result->fetch_assoc()) {
    $date = date('Y-m-d', strtotime($row['collected']));
    $groupedData[$date][] = $row;
    $totalAmount += floatval($row[$column] ?? 0);
}

// Prepare data for AJAX response
$response = [
    'html' => '',
    'total' => number_format($totalAmount, 2)
];

if (!empty($groupedData)) {
    ob_start();
    foreach ($groupedData as $date => $items) {
        $formattedDate = date('F j, Y', strtotime($date));
        $itemsCount = count($items);
        $dateTotal = 0;

        foreach ($items as $item) {
            $dateTotal += floatval($item[$column] ?? 0);
        }

        echo "<div class='date-group' id='date-group-" . htmlspecialchars($date) . "'>";
        echo "<div class='date-header'>";
        echo "<span class='date-title'>$formattedDate</span>";
        echo "<div class='date-info'>";
        echo "<span class='items-count'>$itemsCount items</span>";
        echo "<span class='date-amount'>Total: " . number_format($dateTotal, 2) . "</span>";
        echo "<button class='screenshot-btn' data-date='" . htmlspecialchars($date) . "' title='Save as image'>
                <svg xmlns='http://www.w3.org/2000/svg' width='16' height='16' fill='currentColor' viewBox='0 0 16 16'>
                    <path d='M1.5 1a.5.5 0 0 0-.5.5v3a.5.5 0 0 1-1 0v-3A1.5 1.5 0 0 1 1.5 0h3a.5.5 0 0 1 0 1h-3zM11 .5a.5.5 0 0 1 .5-.5h3A1.5 1.5 0 0 1 16 1.5v3a.5.5 0 0 1-1 0v-3a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 1-.5-.5zM.5 11a.5.5 0 0 1 .5.5v3a.5.5 0 0 0 .5.5h3a.5.5 0 0 1 0 1h-3A1.5 1.5 0 0 1 0 14.5v-3a.5.5 0 0 1 .5-.5zm15 0a.5.5 0 0 1 .5.5v3a1.5 1.5 0 0 1-1.5 1.5h-3a.5.5 0 0 1 0-1h3a.5.5 0 0 0 .5-.5v-3a.5.5 0 0 1 .5-.5z'/>
                    <path d='M3 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1H3zm8-9a3 3 0 1 1-6 0 3 3 0 0 1 6 0z'/>
                </svg>
              </button>";
        echo "</div>";
        echo "</div>";

        echo "<div class='table-container'>";
        echo "<table>";
        echo "<thead>
                <tr>
                    <th>ID</th>
                    
                    <th>" . htmlspecialchars($column) . "</th>";

        if ($headColumn !== null) {
            echo "<th>" . htmlspecialchars($headColumn) . "</th>";
        }
        echo "<th>দাতা/জায়গার নাম</th>";

        echo "</tr></thead><tbody>";

        foreach ($items as $row) {


            if ($table === 'admissionfee' || $table === 'boardingfee' || $table === 'monthlyfee' || $table === 'examfee') {
                $id = htmlspecialchars($row['id']);
                $amount = htmlspecialchars($row[$column] ?? 'N/A');
                $headValue = $headColumn !== null ? htmlspecialchars($row[$headColumn] ?? '') : '';

                echo "<tr>
                    <td>$id</td>
                    <td>$amount</td>";

                if ($headColumn !== null) {
                    echo "<td>$headValue</td>";
                }

                echo "</tr>";
            } else {
                $id = htmlspecialchars($row['id']);
                $amount = htmlspecialchars($row[$column] ?? 'N/A');
                $areas = htmlspecialchars($row['areas']);
                $headValue = $headColumn !== null ? htmlspecialchars($row[$headColumn] ?? '') : '';

                echo "<tr>
                    <td>$id</td>
                    <td>$amount</td>";

                if ($headColumn !== null) {
                    echo "<td>$headValue</td>";
                }
                echo "<td>$areas</td>";
                echo "</tr>";
            }
        }

        echo "</tbody></table>";
        echo "</div></div>";
    }

    // Show total records count
    $totalRecords = array_sum(array_map('count', $groupedData));
    echo "<div class='total-summary'>";
    echo "<span>Showing " . count($groupedData) . " date groups</span>";
    echo "<span>Total records: $totalRecords</span>";
    echo "</div>";

    $response['html'] = ob_get_clean();
} else {
    $noDataMessage = '<div class="no-data">No data found ';
    if (!empty($searchDate)) {
        $noDataMessage .= 'for ' . htmlspecialchars(date('F j, Y', strtotime($searchDate)));
    }
    $noDataMessage .= '.</div>';
    $response['html'] = $noDataMessage;
}

// Return JSON response for AJAX
if (isset($_POST['ajax'])) {
    header('Content-Type: application/json');
    echo json_encode($response);
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Advanced Data Search</title>
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;500;600&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/flatpickr/dist/flatpickr.min.css">
    <style>
        :root {
            --primary-color: #4361ee;
            --secondary-color: #3f37c9;
            --accent-color: #4895ef;
            --light-color: #f8f9fa;
            --dark-color: #212529;
            --success-color: #4cc9f0;
            --danger-color: #f72585;
            --warning-color: #ff9e00;
            --shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            --transition: all 0.3s ease;
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: 'Poppins', sans-serif;
            background: linear-gradient(135deg, #f5f7fa 0%, #c3cfe2 100%);
            min-height: 100vh;
            padding: 20px;
        }

        .container {
            width: 100%;
            max-width: 1000px;
            margin: 0 auto;
            background: white;
            border-radius: 16px;
            box-shadow: var(--shadow);
            overflow: hidden;
            animation: fadeIn 0.8s ease-out;
        }

        @keyframes fadeIn {
            from {
                opacity: 0;
                transform: translateY(20px);
            }

            to {
                opacity: 1;
                transform: translateY(0);
            }
        }

        .header {
            background: linear-gradient(to right, var(--primary-color), var(--secondary-color));
            color: white;
            padding: 20px;
            text-align: center;
        }

        .header h1 {
            font-weight: 600;
            font-size: 1.8rem;
            margin-bottom: 10px;
        }

        .search-container {
            padding: 20px;
            background: #f8f9fa;
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            align-items: center;
            justify-content: space-between;
            position: relative;
        }

        .search-box {
            display: flex;
            flex-grow: 1;
            max-width: 500px;
            gap: 10px;
        }

        .search-input {
            flex-grow: 1;
            padding: 12px 15px;
            border: 1px solid #ddd;
            border-radius: 8px;
            font-family: 'Poppins', sans-serif;
            font-size: 0.9rem;
            transition: var(--transition);
        }

        .search-input:focus {
            outline: none;
            border-color: var(--accent-color);
            box-shadow: 0 0 0 3px rgba(72, 149, 239, 0.2);
        }

        .search-btn {
            background-color: var(--accent-color);
            color: white;
            border: none;
            padding: 12px 20px;
            border-radius: 8px;
            cursor: pointer;
            font-family: 'Poppins', sans-serif;
            font-weight: 500;
            transition: var(--transition);
        }

        .search-btn:hover {
            background-color: var(--secondary-color);
            transform: translateY(-2px);
        }

        .reset-btn {
            background-color: #e9ecef;
            color: var(--dark-color);
            border: none;
            padding: 12px 20px;
            border-radius: 8px;
            cursor: pointer;
            font-family: 'Poppins', sans-serif;
            font-weight: 500;
            transition: var(--transition);
            margin-right: 10px;
        }

        .reset-btn:hover {
            background-color: #dee2e6;
        }

        .button-group {
            display: flex;
            gap: 10px;
        }

        .total-display {
            position: absolute;
            right: 20px;
            top: 50%;
            transform: translateY(-50%);
            background: var(--success-color);
            color: white;
            padding: 10px 20px;
            border-radius: 8px;
            font-weight: 600;
            box-shadow: var(--shadow);
            display: flex;
            align-items: center;
            gap: 8px;
        }

        .total-display span {
            font-size: 1.2rem;
        }

        .total-icon {
            font-size: 1.4rem;
        }

        .date-group {
            margin: 20px;
            border-radius: 8px;
            overflow: hidden;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            margin-bottom: 30px;
            animation: slideUp 0.5s ease-out;
        }

        @keyframes slideUp {
            from {
                opacity: 0;
                transform: translateY(20px);
            }

            to {
                opacity: 1;
                transform: translateY(0);
            }
        }

        .date-header {
            background-color: var(--accent-color);
            color: white;
            padding: 12px 20px;
            font-weight: 500;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .date-info {
            display: flex;
            gap: 15px;
            align-items: center;
        }

        .date-title {
            font-size: 1.1rem;
        }

        .items-count {
            background: white;
            color: var(--accent-color);
            padding: 3px 8px;
            border-radius: 20px;
            font-size: 0.8rem;
            font-weight: 600;
        }

        .date-amount {
            background: rgba(255, 255, 255, 0.2);
            padding: 3px 10px;
            border-radius: 20px;
            font-size: 0.9rem;
        }

        .screenshot-btn {
            background: rgba(255, 255, 255, 0.2);
            border: none;
            border-radius: 50%;
            width: 30px;
            height: 30px;
            display: flex;
            align-items: center;
            justify-content: center;
            cursor: pointer;
            transition: var(--transition);
            margin-left: 10px;
            padding: 5px;
        }

        .screenshot-btn:hover {
            background: rgba(255, 255, 255, 0.3);
            transform: scale(1.1);
        }

        .screenshot-btn svg {
            width: 16px;
            height: 16px;
            fill: white;
        }

        .table-container {
            overflow-x: auto;
        }

        table {
            width: 100%;
            border-collapse: collapse;
        }

        th,
        td {
            padding: 15px;
            text-align: left;
            border-bottom: 1px solid #e0e0e0;
        }

        th {
            background-color: #f5f7fa;
            color: var(--dark-color);
            font-weight: 500;
            text-transform: uppercase;
            font-size: 0.8rem;
            letter-spacing: 0.5px;
        }

        tr:hover {
            background-color: rgba(72, 149, 239, 0.1);
            transition: var(--transition);
        }

        .no-data {
            text-align: center;
            padding: 40px;
            color: #666;
            font-size: 1.2rem;
        }

        .total-summary {
            padding: 15px 20px;
            background: #f8f9fa;
            border-top: 1px solid #eee;
            display: flex;
            justify-content: space-between;
            font-weight: 500;
        }

        /* Loading indicator for screenshot */
        .screenshot-loading {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.5);
            display: flex;
            justify-content: center;
            align-items: center;
            z-index: 1000;
            color: white;
            font-size: 1.5rem;
            flex-direction: column;
        }

        .screenshot-loading-spinner {
            border: 5px solid #f3f3f3;
            border-top: 5px solid var(--accent-color);
            border-radius: 50%;
            width: 50px;
            height: 50px;
            animation: spin 1s linear infinite;
            margin-bottom: 15px;
        }

        @keyframes spin {
            0% {
                transform: rotate(0deg);
            }

            100% {
                transform: rotate(360deg);
            }
        }

        @media (max-width: 768px) {
            .search-container {
                flex-direction: column;
                align-items: stretch;
                padding-bottom: 70px;
            }

            .search-box {
                width: 100%;
                max-width: 100%;
            }

            .button-group {
                width: 100%;
                justify-content: flex-end;
            }

            .total-display {
                position: static;
                transform: none;
                width: 100%;
                justify-content: center;
                margin-top: 10px;
            }

            .date-header {
                flex-direction: column;
                align-items: flex-start;
                gap: 10px;
            }

            .date-info {
                width: 100%;
                justify-content: space-between;
            }

            th,
            td {
                padding: 10px 8px;
                font-size: 0.9rem;
            }
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="header">
            <h1>Advanced Data Search</h1>
            <p>Filter records by specific date</p>
        </div>

        <form id="searchForm" class="search-container">
            <input type="hidden" name="email" value="<?= htmlspecialchars($email) ?>">
            <input type="hidden" name="table" value="<?= htmlspecialchars($table) ?>">
            <input type="hidden" name="column" value="<?= htmlspecialchars($column) ?>">
            <?php if ($headColumn): ?>
                <input type="hidden" name="income_head" value="<?= htmlspecialchars($headColumn) ?>">
            <?php endif; ?>
            <input type="hidden" name="ajax" value="1">

            <div class="search-box">
                <input type="text" name="search_date" id="search_date" class="search-input"
                    placeholder="Select a date..." value="<?= htmlspecialchars($searchDate) ?>" readonly>
                <div class="button-group">
                    <?php if (!empty($searchDate)): ?>
                        <button type="button" id="resetBtn" class="reset-btn">Reset</button>
                    <?php endif; ?>
                    <button type="submit" class="search-btn">Search</button>
                </div>
            </div>

            <div class="total-display">
                <span class="total-icon">৳</span>
                <span id="totalAmount"><?= number_format($totalAmount, 2) ?></span>
            </div>
        </form>

        <div id="resultsContainer" class="main-content">
            <?= $response['html'] ?? '' ?>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/flatpickr"></script>
    <script src="https://html2canvas.hertzen.com/dist/html2canvas.min.js"></script>
    <script>
        // Initialize date picker
        flatpickr("#search_date", {
            dateFormat: "Y-m-d",
            maxDate: "today",
            allowInput: true,
            animate: true,
            disableMobile: true,
            placeholder: "Select a date..."
        });

        // Handle form submission with AJAX
        document.getElementById('searchForm').addEventListener('submit', function (e) {
            e.preventDefault();

            const formData = new FormData(this);
            const resultsContainer = document.getElementById('resultsContainer');
            const totalDisplay = document.getElementById('totalAmount');

            // Show loading state
            resultsContainer.innerHTML = '<div class="no-data">Loading...</div>';

            fetch('', {
                method: 'POST',
                body: formData
            })
                .then(response => response.json())
                .then(data => {
                    if (data.error) {
                        resultsContainer.innerHTML = `<div class="no-data">${data.error}</div>`;
                    } else {
                        resultsContainer.innerHTML = data.html;
                        totalDisplay.textContent = data.total;

                        // Show/hide reset button based on search
                        const resetBtn = document.getElementById('resetBtn');
                        if (formData.get('search_date')) {
                            if (!resetBtn) {
                                const buttonGroup = document.querySelector('.button-group');
                                const newResetBtn = document.createElement('button');
                                newResetBtn.id = 'resetBtn';
                                newResetBtn.className = 'reset-btn';
                                newResetBtn.textContent = 'Reset';
                                newResetBtn.type = 'button';
                                buttonGroup.insertBefore(newResetBtn, buttonGroup.firstChild);
                                addResetListener();
                            }
                        } else if (resetBtn) {
                            resetBtn.remove();
                        }
                    }
                })
                .catch(error => {
                    resultsContainer.innerHTML = '<div class="no-data">Error loading data</div>';
                    console.error('Error:', error);
                });
        });

        // Add reset functionality
        function addResetListener() {
            document.getElementById('resetBtn').addEventListener('click', function () {
                document.getElementById('search_date').value = '';
                document.getElementById('searchForm').dispatchEvent(new Event('submit'));
            });
        }

        // Initialize reset listener if reset button exists
        if (document.getElementById('resetBtn')) {
            addResetListener();
        }

        // Add screenshot functionality
        document.addEventListener('click', function (e) {
            if (e.target.closest('.screenshot-btn')) {
                const btn = e.target.closest('.screenshot-btn');
                const date = btn.getAttribute('data-date');
                const dateGroup = document.getElementById(`date-group-${date}`);

                // Show loading indicator
                const loadingDiv = document.createElement('div');
                loadingDiv.className = 'screenshot-loading';
                loadingDiv.innerHTML = `
                    <div class="screenshot-loading-spinner"></div>
                    <div>Preparing screenshot...</div>
                `;
                document.body.appendChild(loadingDiv);

                // Take screenshot
                html2canvas(dateGroup, {
                    scale: 2,
                    logging: false,
                    useCORS: true,
                    allowTaint: true,
                    backgroundColor: null
                }).then(canvas => {
                    // Remove loading indicator
                    document.body.removeChild(loadingDiv);

                    // Create download link
                    const link = document.createElement('a');
                    const formattedDate = date.replace(/-/g, '');
                    link.download = `transaction_${formattedDate}.png`;
                    link.href = canvas.toDataURL('image/png');
                    link.click();
                }).catch(err => {
                    document.body.removeChild(loadingDiv);
                    alert('Failed to generate screenshot: ' + err.message);
                });
            }
        });
    </script>
</body>

</html>