<?php
include_once("../db/database/conn.php");
$db = new DBConn();
$conn = $db->getConnection();

// Array to map income categories to Bengali names
$income_head_translation = [
    "waz_collection" => "ওয়াজের কালেকশন",
    "student_monthly_salary" => "ছাত্রদের মাসিক বেতন",
    "boarding_fee" => "বোর্ডিং ফি",
    "exam_fee" => "পরীক্ষা ফি",
    "admission_fee" => "ভর্তি ফি",
    "donation1" => "অনোদান",
    "donation2" => "দান",
    "zakat" => "যাকাত",
    "fitra" => "ফিতরা"
];

if (isset($_POST['email'])) {
    $email = $_POST['email'];

    // Handle summary data request
    if (isset($_POST['action']) && $_POST['action'] === 'summary') {
        // Today's total
        $stmt = $conn->prepare("SELECT SUM(income_ammount) as total FROM incomes WHERE email = ? AND DATE(collected) = CURDATE()");
        $stmt->bind_param("s", $email);
        $stmt->execute();
        $result = $stmt->get_result();
        $today_total = $result->fetch_assoc()['total'] ?? 0;

        // Monthly total
        $stmt = $conn->prepare("SELECT SUM(income_ammount) as total FROM incomes WHERE email = ? AND MONTH(collected) = MONTH(CURDATE()) AND YEAR(collected) = YEAR(CURDATE())");
        $stmt->bind_param("s", $email);
        $stmt->execute();
        $result = $stmt->get_result();
        $month_total = $result->fetch_assoc()['total'] ?? 0;

        // Average daily income (this month)
        $stmt = $conn->prepare("SELECT AVG(daily_total) as avg_daily FROM (
            SELECT DATE(collected) as day, SUM(income_ammount) as daily_total 
            FROM incomes 
            WHERE email = ? AND MONTH(collected) = MONTH(CURDATE()) AND YEAR(collected) = YEAR(CURDATE())
            GROUP BY DATE(collected)
        ) as daily_totals");
        $stmt->bind_param("s", $email);
        $stmt->execute();
        $result = $stmt->get_result();
        $avg_daily = $result->fetch_assoc()['avg_daily'] ?? 0;

        // Chart data (last 7 days)
        $chart_labels = [];
        $chart_data = [];
        $date = new DateTime();
        
        for ($i = 6; $i >= 0; $i--) {
            $date->modify("-{$i} day");
            $day = $date->format('Y-m-d');
            $day_name = $date->format('D');
            
            $stmt = $conn->prepare("SELECT SUM(income_ammount) as total FROM incomes WHERE email = ? AND DATE(collected) = ?");
            $stmt->bind_param("ss", $email, $day);
            $stmt->execute();
            $result = $stmt->get_result();
            $total = $result->fetch_assoc()['total'] ?? 0;
            
            $chart_labels[] = $day_name;
            $chart_data[] = (float)$total;
            $date->modify("+{$i} day");
        }

        $response = [
            'today_total' => number_format($today_total, 2),
            'month_total' => number_format($month_total, 2),
            'avg_daily' => number_format($avg_daily, 2),
            'chart_data' => [
                'labels' => $chart_labels,
                'data' => $chart_data
            ]
        ];

        echo json_encode($response);
        exit;
    }

    // Handle date range requests
    if (isset($_POST['range'])) {
        $range = $_POST['range'];
        $query = "";
        
        switch ($range) {
            case 'today':
                $query = "SELECT income_head, income_ammount, collected FROM incomes WHERE email = ? AND DATE(collected) = CURDATE()";
                break;
            case 'week':
                $query = "SELECT income_head, income_ammount, collected FROM incomes WHERE email = ? AND YEARWEEK(collected, 1) = YEARWEEK(CURDATE(), 1)";
                break;
            case 'month':
                $query = "SELECT income_head, income_ammount, collected FROM incomes WHERE email = ? AND MONTH(collected) = MONTH(CURDATE()) AND YEAR(collected) = YEAR(CURDATE())";
                break;
            case 'year':
                $query = "SELECT income_head, income_ammount, collected FROM incomes WHERE email = ? AND YEAR(collected) = YEAR(CURDATE())";
                break;
        }

        if (!empty($query)) {
            $stmt = $conn->prepare($query);
            $stmt->bind_param("s", $email);
            $stmt->execute();
            $result = $stmt->get_result();

            if ($result->num_rows > 0) {
                while ($row = $result->fetch_assoc()) {
                    $income_head_bn = $income_head_translation[$row['income_head']] ?? $row['income_head'];
                    echo '<div class="income-item">';
                    echo '<div>';
                    echo '<div class="income-category">' . htmlspecialchars($income_head_bn) . '</div>';
                    echo '<div class="income-date">' . htmlspecialchars($row['collected']) . '</div>';
                    echo '</div>';
                    echo '<div class="income-amount">৳' . htmlspecialchars($row['income_ammount']) . '</div>';
                    echo '</div>';
                }
            } else {
                echo '<div class="no-results">কোনো ডাটা পাওয়া যায়নি</div>';
            }
        }
        exit;
    }

    // Search by Date
    if (isset($_POST['date'])) {
        $selectedDate = $_POST['date'];

        $stmt = $conn->prepare("SELECT income_head, income_ammount, collected FROM incomes WHERE email = ? AND DATE(collected) = ?");
        $stmt->bind_param("ss", $email, $selectedDate);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            while ($row = $result->fetch_assoc()) {
                $income_head_bn = $income_head_translation[$row['income_head']] ?? $row['income_head'];
                echo '<div class="income-item">';
                echo '<div>';
                echo '<div class="income-category">' . htmlspecialchars($income_head_bn) . '</div>';
                echo '<div class="income-date">' . htmlspecialchars($row['collected']) . '</div>';
                echo '</div>';
                echo '<div class="income-amount">৳' . htmlspecialchars($row['income_ammount']) . '</div>';
                echo '</div>';
            }
        } else {
            echo '<div class="no-results">কোনো ডাটা পাওয়া যায়নি</div>';
        }
    }

    // Search by Category
    if (isset($_POST['category'])) {
        $category = $_POST['category'];

        $stmt = $conn->prepare("SELECT income_head, income_ammount, collected FROM incomes WHERE email = ? AND income_head = ?");
        $stmt->bind_param("ss", $email, $category);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            while ($row = $result->fetch_assoc()) {
                $income_head_bn = $income_head_translation[$row['income_head']] ?? $row['income_head'];
                echo '<div class="income-item">';
                echo '<div>';
                echo '<div class="income-category">' . htmlspecialchars($income_head_bn) . '</div>';
                echo '<div class="income-date">' . htmlspecialchars($row['collected']) . '</div>';
                echo '</div>';
                echo '<div class="income-amount">৳' . htmlspecialchars($row['income_ammount']) . '</div>';
                echo '</div>';
            }
        } else {
            echo '<div class="no-results">কোনো ডাটা পাওয়া যায়নি</div>';
        }
    }
}
?>