-- Active: 1739365328253@@127.0.0.1@3306@madrasha
CREATE DATABASE IF NOT EXISTS madrasha;

USE madrasha;



-- create madrashas table 

CREATE TABLE IF NOT EXISTS madrashas (
    madrashas_id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(255) NOT NULL,
    email VARCHAR(255) NOT NULL UNIQUE,
    phone VARCHAR(25) NOT NULL UNIQUE,
    password VARCHAR(50) NOT NULL UNIQUE,
    con_password VARCHAR(50) NOT NULL UNIQUE,
    address VARCHAR(255) NOT NULL,
    image VARCHAR(255) NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP


    
);






-- create classes table 

CREATE TABLE IF NOT EXISTS classes (
    classes_id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(200) NOT NULL,

    madrasha_email VARCHAR(255) NOT NULL,
    
    FOREIGN KEY (madrasha_email) REFERENCES madrashas(email) ON DELETE CASCADE ON UPDATE CASCADE

);









CREATE TABLE IF NOT EXISTS booklist (
    id INT AUTO_INCREMENT PRIMARY KEY,
    subject_name VARCHAR(255) NOT NULL,
    madrasha_email VARCHAR(255) NOT NULL,
    class_id INT NOT NULL,
    class_name VARCHAR(255) NOT NULL,

    CONSTRAINT fk_madrasha_email FOREIGN KEY (madrasha_email) REFERENCES madrashas(email) ON DELETE CASCADE ON UPDATE CASCADE,
    CONSTRAINT fk_class_id FOREIGN KEY (class_id) REFERENCES classes(classes_id) ON DELETE CASCADE ON UPDATE CASCADE
);




## ****************************************************************
## ****************************************************************



CREATE TABLE exam_details (
    id INT AUTO_INCREMENT PRIMARY KEY,
    class_name VARCHAR(100),
    month_year VARCHAR(20),
    exam_name VARCHAR(100),
    student_name VARCHAR(100),


    form_no VARCHAR(10) NOT NULL,
    class_id INT NOT NULL,
    madrasha_email VARCHAR(255) NOT NULL,

    FOREIGN KEY (class_id) REFERENCES classes(classes_id) ON DELETE CASCADE,
    FOREIGN KEY (form_no) REFERENCES selfstudents(form_no) ON DELETE CASCADE,
    FOREIGN KEY (madrasha_email) REFERENCES madrashas(email) ON DELETE CASCADE

);



CREATE TABLE subjects (
    id INT AUTO_INCREMENT PRIMARY KEY,
    exam_id INT,
    subject_name VARCHAR(100),
    subject_marks VARCHAR(10),
    FOREIGN KEY (exam_id) REFERENCES exam_details(id) ON DELETE CASCADE
);






-------------------------------------------------------------------------

CREATE TABLE exam_results (
    id INT AUTO_INCREMENT PRIMARY KEY,
    madrasha_email VARCHAR(100),
    class_id INT,
    class_name VARCHAR(50),
    exam_name VARCHAR(100),
    exam_date DATE,
    form_no VARCHAR(50),
    student_name VARCHAR(100),
    subject VARCHAR(100),
    marks INT,

    FOREIGN KEY(madrasha_email) REFERENCES madrashas(email) ON DELETE CASCADE

);



-------------------------------------------------------------------------



## ****************************************************************
## ****************************************************************

-- create studen table 1

CREATE TABLE selfstudents (
    student_id INT AUTO_INCREMENT PRIMARY KEY,
    academic_year VARCHAR(10) NOT NULL,
    class_name VARCHAR(150) NOT NULL,
    admission_date DATE NOT NULL,
    hijri_admission_date DATE NOT NULL,
    hijri_joined_year INT NOT NULL,
    hijri_joined_month INT NOT NULL,
    joined_year_english INT NOT NULL,
    joined_month_english INT NOT NULL,
    student_name VARCHAR(255) NOT NULL,
    age INT NOT NULL,
    birth_date DATE NOT NULL,
    father_name VARCHAR(255) NOT NULL,
    father_profession VARCHAR(255) NOT NULL,
    permanent_address TEXT NOT NULL,
    post TEXT NOT NULL,
    upazila VARCHAR(255) NOT NULL,
    district VARCHAR(255) NOT NULL,
    current_address TEXT NOT NULL,
    guardian_name VARCHAR(255) NOT NULL,
    guardian_relation VARCHAR(100) NOT NULL,

    form_no VARCHAR(10) NOT NULL UNIQUE,

    class_id INT NOT NULL,
    madrasha_email VARCHAR(255) NOT NULL,

    FOREIGN KEY (class_id) REFERENCES classes(classes_id) ON DELETE CASCADE ON UPDATE CASCADE,
    FOREIGN KEY (madrasha_email) REFERENCES madrashas(email) ON DELETE CASCADE ON UPDATE CASCADE


);



ALTER TABLE selfstudents ADD COLUMN is_active BOOLEAN DEFAULT TRUE;
ALTER TABLE selfstudents ADD COLUMN last_displayed_ramadan_year INT;



-- create studen table 2 #previas admissions

CREATE TABLE admissions (
    id INT AUTO_INCREMENT PRIMARY KEY,
    previous_school VARCHAR(255),
    previous_class VARCHAR(50),
    current_school VARCHAR(255),
    current_class VARCHAR(50),

    form_no VARCHAR(10)  NOT NULL,

    FOREIGN KEY (form_no) REFERENCES selfstudents(form_no) ON DELETE CASCADE ON UPDATE CASCADE


);



-- create studen table 3 #office_admissions

CREATE TABLE officeadmissions (
    id INT AUTO_INCREMENT PRIMARY KEY,
    annual_exam_result INT NOT NULL,
    admission_exam_result INT NOT NULL,
    examiner_name VARCHAR(255),
    opinion TEXT,
    head_name VARCHAR(255),
    approval VARCHAR(255),
    director_name VARCHAR(255),
    director_approval VARCHAR(255),

    form_no VARCHAR(10) NOT NULL,

    FOREIGN KEY (form_no) REFERENCES selfstudents(form_no) ON DELETE CASCADE ON UPDATE CASCADE

);






CREATE TABLE admissionfee (
    id INT AUTO_INCREMENT PRIMARY KEY,
    admission_fee DOUBLE(10, 2) NOT NULL,
    collected TIMESTAMP DEFAULT CURRENT_TIMESTAMP,

    form_no VARCHAR(10) NOT NULL,

    email VARCHAR(255) NOT NULL,

    FOREIGN KEY (email) REFERENCES madrashas(email) ON DELETE CASCADE ON UPDATE CASCADE,

    FOREIGN KEY (form_no) REFERENCES selfstudents(form_no) ON DELETE CASCADE ON UPDATE CASCADE -- deletable

);




CREATE TABLE boardingfee (
    id INT AUTO_INCREMENT PRIMARY KEY,
    boarding_fee DOUBLE(10, 2),
    collected TIMESTAMP DEFAULT CURRENT_TIMESTAMP,

    form_no VARCHAR(10) NOT NULL,

    email VARCHAR(255) NOT NULL,

    FOREIGN KEY (email) REFERENCES madrashas(email) ON DELETE CASCADE ON UPDATE CASCADE,

    FOREIGN KEY (form_no) REFERENCES selfstudents(form_no) ON DELETE CASCADE ON UPDATE CASCADE -- deletable
);




CREATE TABLE monthlyfee (
    id INT AUTO_INCREMENT PRIMARY KEY,
    monthly_fee DOUBLE(10, 2),
    collected TIMESTAMP DEFAULT CURRENT_TIMESTAMP,

    form_no VARCHAR(10) NOT NULL,

    email VARCHAR(255) NOT NULL,

    FOREIGN KEY (email) REFERENCES madrashas(email) ON DELETE CASCADE ON UPDATE CASCADE,

    FOREIGN KEY (form_no) REFERENCES selfstudents(form_no) ON DELETE CASCADE ON UPDATE CASCADE -- deletable
);




CREATE TABLE examfee (
    id INT AUTO_INCREMENT PRIMARY KEY,
    exam_fee DOUBLE(10, 2),
    collected TIMESTAMP DEFAULT CURRENT_TIMESTAMP,

    form_no VARCHAR(10) NOT NULL,

    email VARCHAR(255) NOT NULL,

    FOREIGN KEY (email) REFERENCES madrashas(email) ON DELETE CASCADE ON UPDATE CASCADE,

    FOREIGN KEY (form_no) REFERENCES selfstudents(form_no) ON DELETE CASCADE ON UPDATE CASCADE -- deletable
);




-- SHOW TABLES LIKE 'examfee';
-- DESCRIBE examfee;


--  আয় ও ব্যয় 

CREATE TABLE incomes (
    id INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    income_head VARCHAR(50) NOT NULL,
    areas VARCHAR(100),
    income_ammount INT NOT NULL,
    collected DATE,

    email VARCHAR(255) NOT NULL,
   
    FOREIGN KEY (email) REFERENCES madrashas(email) ON DELETE CASCADE ON UPDATE CASCADE
);







CREATE TABLE expense (
    id INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    expense_head VARCHAR(50) NOT NULL,
    expense_details TEXT,
    expense_ammount DOUBLE(10, 2) NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,

    madrasha_email VARCHAR(255) NOT NULL,
    
    FOREIGN KEY (madrasha_email) REFERENCES madrashas(email) ON DELETE CASCADE ON UPDATE CASCADE


);








CREATE TABLE returnmony (
    id INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    return_head VARCHAR(50) NOT NULL,
    return_ammount INT NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,

    madrasha_email VARCHAR(255) NOT NULL,
   
    FOREIGN KEY (madrasha_email) REFERENCES madrashas(email) ON DELETE CASCADE ON UPDATE CASCADE
);



-- শিক্ষক নিয়োগ

CREATE TABLE teacher (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(255) NOT NULL,
    phone VARCHAR(20) NOT NULL UNIQUE,
    experience TEXT NOT NULL,
    qualification TEXT NOT NULL,
    class_names TEXT NOT NULL,
    head_name VARCHAR(255) NOT NULL,
    head_approval VARCHAR(255) NOT NULL,
    director_name VARCHAR(255) NOT NULL,
    director_approval VARCHAR(255) NOT NULL,
    dates TIMESTAMP DEFAULT CURRENT_TIMESTAMP,


    madrasha_email VARCHAR(255) NOT NULL,
    
    FOREIGN KEY (madrasha_email) REFERENCES madrashas(email) ON DELETE CASCADE ON UPDATE CASCADE


);










CREATE TABLE servants (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(255) NOT NULL,
    phone VARCHAR(20) NOT NULL UNIQUE,
    experience TEXT NOT NULL,
    head_name VARCHAR(255) NOT NULL,
    head_approval VARCHAR(255) NOT NULL,
    director_name VARCHAR(255) NOT NULL,
    director_approval VARCHAR(255) NOT NULL,
    dates TIMESTAMP DEFAULT CURRENT_TIMESTAMP,


    madrasha_email VARCHAR(255) NOT NULL,
    
    FOREIGN KEY (madrasha_email) REFERENCES madrashas(email) ON DELETE CASCADE ON UPDATE CASCADE


);



