<?php
// delete_transaction.php
include_once('../db/database/conn.php');

header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode(['success' => false, 'message' => 'Invalid request method']);
    exit;
}

$data = json_decode(file_get_contents('php://input'), true);
$transactionIds = $data['ids'] ?? [];

if (empty($transactionIds)) {
    echo json_encode(['success' => false, 'message' => 'No transactions selected']);
    exit;
}

$db = new DBConn();
$conn = $db->getConnection();

try {
    // Create a string of comma-separated placeholders
    $placeholders = implode(',', array_fill(0, count($transactionIds), '?'));
    
    $stmt = $conn->prepare("DELETE FROM payments WHERE id IN ($placeholders)");
    
    // Bind parameters dynamically
    $types = str_repeat('i', count($transactionIds));
    $stmt->bind_param($types, ...$transactionIds);
    
    $stmt->execute();
    
    if ($stmt->affected_rows > 0) {
        echo json_encode(['success' => true, 'message' => 'Transactions deleted successfully']);
    } else {
        echo json_encode(['success' => false, 'message' => 'No transactions were deleted']);
    }
} catch (Exception $e) {
    echo json_encode(['success' => false, 'message' => 'Error: ' . $e->getMessage()]);
} finally {
    $conn->close();
}
?>