<?php
$email = $_POST['email'] ?? '';

include_once('../db/database/conn.php');

// Create database connection
$db = new DBConn();
$conn = $db->getConnection();

// Fetch summary data grouped by form_no
$summaryData = [];
$formDetails = [];

if (!empty($email)) {
    // Get summary data (form_no, email, total amount, count)
    $summaryQuery = $conn->prepare("
        SELECT form_no, email, SUM(amount) as total_amount, COUNT(*) as transaction_count 
        FROM payments 
        WHERE email = ? 
        GROUP BY form_no
        ORDER BY MAX(created_at) DESC
    ");
    $summaryQuery->bind_param("s", $email);
    $summaryQuery->execute();
    $summaryResult = $summaryQuery->get_result();

    while ($row = $summaryResult->fetch_assoc()) {
        $summaryData[] = $row;
        $formDetails[$row['form_no']] = []; // Initialize for details
    }

    $summaryQuery->close();

    // Get all details for each form_no
    if (!empty($formDetails)) {
        $detailsQuery = $conn->prepare("
            SELECT * FROM payments 
            WHERE email = ? AND form_no = ?
            ORDER BY created_at DESC
        ");

        foreach ($formDetails as $formNo => $_) {
            $detailsQuery->bind_param("ss", $email, $formNo);
            $detailsQuery->execute();
            $detailsResult = $detailsQuery->get_result();

            while ($row = $detailsResult->fetch_assoc()) {
                $formDetails[$formNo][] = $row;
            }
        }

        $detailsQuery->close();
    }
}

$conn->close();
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Payment History</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <style>
        :root {
            --primary: #6366f1;
            --primary-dark: #4f46e5;
            --danger: #ef4444;
            --success: #10b981;
            --warning: #f59e0b;
            --gray-100: #f3f4f6;
            --gray-200: #e5e7eb;
            --gray-400: #9ca3af;
            --gray-600: #4b5563;
            --gray-800: #1f2937;
            --shadow-sm: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
            --shadow-md: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
            --shadow-lg: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
            --transition: all 0.2s cubic-bezier(0.4, 0, 0.2, 1);
        }

        body {
            font-family: 'Inter', -apple-system, BlinkMacSystemFont, sans-serif;
            background-color: #f9fafb;
            color: var(--gray-800);
            line-height: 1.5;
        }

        .container {
            max-width: 1200px;
            margin: 0 auto;
            padding: 2rem;
        }

        h1 {
            color: var(--primary-color);
            text-align: center;
            margin-bottom: 30px;
            font-weight: 600;
            font-size: 2.2rem;
        }



        .cards-container {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(320px, 1fr));
            gap: 25px;
            margin-top: 30px;
        }

        /* Summary Cards */
        .summary-card {
            background: white;
            border-radius: 0.75rem;
            padding: 1.5rem;
            box-shadow: var(--shadow-sm);
            transition: var(--transition);
            border-left: 4px solid var(--primary);
            cursor: pointer;
        }

        .summary-card:hover {
            transform: translateY(-2px);
            box-shadow: var(--shadow-md);
        }

        .summary-card::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            width: 5px;
            height: 100%;
            background: var(--primary-color);
        }

        .card-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 15px;
        }

        .form-no {
            font-weight: 700;
            color: var(--dark-color);
            font-size: 1.4rem;
            letter-spacing: 0.5px;
        }

        .transaction-count {
            background-color: var(--accent-color);
            color: white;
            padding: 4px 10px;
            border-radius: 20px;
            font-size: 0.8rem;
            font-weight: 600;
        }

        .card-body {
            margin-bottom: 15px;
        }

        .card-row {
            margin-bottom: 10px;
        }

        .card-label {
            color: #6c757d;
            font-size: 0.9rem;
            display: block;
            margin-bottom: 3px;
        }

        .card-value {
            font-weight: 500;
            word-break: break-all;
        }

        .email {
            color: var(--primary-color);
        }

        .total-amount {
            font-size: 1.8rem;
            font-weight: 700;
            color: #28a745;
            margin: 15px 0;
        }

        .card-footer {
            display: flex;
            justify-content: space-between;
            align-items: center;
            color: #6c757d;
            font-size: 0.85rem;
            padding-top: 10px;
            border-top: 1px solid #e9ecef;
        }

        /* Modal Styles */
        .modal {
            display: none;
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.7);
            z-index: 1000;
            /* প্রধান মডালের z-index */
            overflow-y: auto;
            opacity: 0;
            transition: opacity 0.3s;
        }

        .modal.show {
            display: flex;
            justify-content: center;
            align-items: flex-start;
            opacity: 1;
        }

        .modal-content {
            background: white;
            border-radius: 12px;
            width: 90%;
            max-width: 1000px;
            margin: 50px auto;
            box-shadow: 0 10px 30px rgba(0, 0, 0, 0.2);
            transform: translateY(-50px);
            transition: transform 0.3s;
            overflow: hidden;
        }

        .modal.show .modal-content {
            transform: translateY(0);
        }

        .modal-header {
            padding: 20px 25px;
            background: var(--primary-color);
            color: white;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .modal-title {
            font-size: 1.5rem;
            font-weight: 600;
            margin: 0;
        }

        .close-btn {
            background: none;
            border: none;
            color: black;
            font-size: 1.5rem;
            cursor: pointer;
            transition: transform 0.2s;
        }

        .close-btn:hover {
            transform: rotate(90deg);
        }

        .modal-body {
            padding: 25px;
            max-height: 70vh;
            overflow-y: auto;
        }

        /* Transactions Grid */
        .transactions-grid {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
            gap: 1.25rem;
            margin-top: 1.5rem;
        }

        /* Modern Transaction Card */
        .transaction-card {
            position: relative;
            background: white;
            border-radius: 0.75rem;
            overflow: hidden;
            box-shadow: var(--shadow-sm);
            transition: var(--transition);
            border: 1px solid var(--gray-200);
        }

        .transaction-card:hover {
            transform: translateY(-2px);
            box-shadow: var(--shadow-md);
            border-color: var(--primary);
        }

        .transaction-card.selected {
            border: 1px solid var(--primary);
            box-shadow: 0 0 0 2px rgba(99, 102, 241, 0.2);
        }



        /* Checkbox Design */
        .checkbox-container {
            position: absolute;
            top: 0.75rem;
            right: 0.75rem;
            z-index: 10;
        }

        .checkbox-input {
            position: absolute;
            opacity: 0;
            width: 0;
            height: 0;
        }

        .checkbox-design {
            display: flex;
            align-items: center;
            justify-content: center;
            width: 1.25rem;
            height: 1.25rem;
            border: 2px solid var(--gray-400);
            border-radius: 0.375rem;
            background: white;
            transition: var(--transition);
            cursor: pointer;
        }

        .checkbox-input:checked~.checkbox-design {
            background: var(--primary);
            border-color: var(--primary);
        }

        .checkbox-input:checked~.checkbox-design::after {
            content: '\f00c';
            font-family: 'Font Awesome 6 Free';
            font-weight: 900;
            color: white;
            font-size: 0.65rem;
        }

        .checkbox-input:focus~.checkbox-design {
            box-shadow: 0 0 0 3px rgba(99, 102, 241, 0.3);
        }



        /* Card Content */
        .card-content {
            padding: 1.25rem;
            position: relative;
        }

        .transaction-id {
            font-size: 0.875rem;
            color: var(--gray-600);
            margin-bottom: 0.25rem;
        }

        .transaction-amount {
            font-size: 1.5rem;
            font-weight: 700;
            color: var(--success);
            margin: 0.5rem 0;
        }

        .transaction-meta {
            display: flex;
            justify-content: space-between;
            font-size: 0.875rem;
            color: var(--gray-600);
            margin-top: 1rem;
            padding-top: 1rem;
            border-top: 1px solid var(--gray-100);
        }

        .transaction-date {
            display: flex;
            align-items: center;
            gap: 0.25rem;
        }

        .transaction-status {
            display: inline-flex;
            align-items: center;
            padding: 0.25rem 0.5rem;
            border-radius: 9999px;
            font-size: 0.75rem;
            font-weight: 500;
            background: var(--gray-100);
            color: var(--gray-800);
        }

        .status-success {
            background: #ecfdf5;
            color: var(--success);
        }



        .transaction-header {
            display: flex;
            justify-content: space-between;
            margin-bottom: 10px;
        }

        .transaction-id {
            font-weight: 600;
            color: var(--dark-color);
        }

        .transaction-date {
            color: #6c757d;
            font-size: 0.9rem;
        }

        .transaction-amount {
            font-size: 1.3rem;
            font-weight: 700;
            color: #28a745;
            margin: 10px 0;
        }

        .custom-checkbox {
            position: absolute;
            right: 15px;
            top: 15px;
            width: 20px;
            height: 20px;
            appearance: none;
            -webkit-appearance: none;
            background-color: white;
            border: 2px solid #ccc;
            border-radius: 4px;
            cursor: pointer;
            transition: all 0.2s;
        }

        .custom-checkbox:checked {
            background-color: var(--primary-color);
            border-color: var(--primary-color);
        }

        .custom-checkbox:checked::after {
            content: '\f00c';
            font-family: 'Font Awesome 6 Free';
            font-weight: 900;
            color: white;
            font-size: 12px;
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
        }

        .modal-footer {
            padding: 15px 25px;
            background: #f8f9fa;
            display: flex;
            justify-content: space-between;
            align-items: center;
            border-top: 1px solid #e9ecef;
        }

        .total-summary {
            font-size: 1.2rem;
            font-weight: 600;
        }

        /* Delete Button */
        .delete-selected {
            display: none;
            align-items: center;
            gap: 0.5rem;
            padding: 0.5rem 1rem;
            background: white;
            color: var(--danger);
            border: 1px solid var(--danger);
            border-radius: 0.5rem;
            font-weight: 500;
            transition: var(--transition);
        }

        .delete-selected:hover {
            background: var(--danger);
            color: white;
        }

        .delete-selected.show {
            display: inline-flex;
        }

        /* Delete Confirmation Modal */
        /* Confirm Modal Styles */
        .confirm-modal {
            position: fixed;
            inset: 0;
            background: rgba(0, 0, 0, 0.5);
            display: flex;
            justify-content: center;
            align-items: center;
            z-index: 2001;
            /* নিশ্চিত করুন এটি প্রধান মডালের চেয়ে বেশি */
            opacity: 0;
            pointer-events: none;
            transition: var(--transition);
        }

        .confirm-modal.show {
            opacity: 1;
            pointer-events: auto;
        }

        .confirm-content {
            background: white;
            border-radius: 1rem;
            width: 90%;
            max-width: 400px;
            padding: 2rem;
            box-shadow: var(--shadow-lg);
            transform: translateY(10px);
            transition: var(--transition);
        }

        .confirm-modal.show .confirm-content {
            transform: translateY(0);
        }

        .confirm-icon {
            display: flex;
            justify-content: center;
            margin-bottom: 1.5rem;
        }

        .confirm-icon i {
            font-size: 3rem;
            color: var(--danger);
        }

        .confirm-buttons {
            display: flex;
            gap: 1rem;
            margin-top: 2rem;
        }

        .confirm-btn {
            flex: 1;
            padding: 0.75rem;
            border-radius: 0.5rem;
            font-weight: 500;
            transition: var(--transition);
        }

        .confirm-delete {
            background: var(--danger);
            color: white;
            border: none;
        }

        .confirm-delete:hover {
            background: #dc2626;
        }

        .cancel-delete {
            background: white;
            color: var(--gray-800);
            border: 1px solid var(--gray-200);
        }

        .cancel-delete:hover {
            background: var(--gray-100);
        }

        /* Responsive */
        @media (max-width: 1024px) {
            .transactions-grid {
                grid-template-columns: repeat(2, 1fr);
            }
        }

        @media (max-width: 640px) {
            .transactions-grid {
                grid-template-columns: 1fr;
            }
        }

        .no-data {
            text-align: center;
            padding: 50px 20px;
            background: #ffffff;
            border-radius: 12px;
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.05);
            max-width: 700px;
            margin: 0 auto;
        }

        .no-data-icon {
            font-size: 60px;
            color: #adb5bd;
            margin-bottom: 20px;
        }

        .no-data h3 {
            color: var(--dark-color);
            margin-bottom: 10px;
        }

        .no-data p {
            color: #6c757d;
            font-size: 1.1rem;
        }

        @media (max-width: 992px) {
            .transactions-grid {
                grid-template-columns: repeat(2, 1fr);
            }
        }

        @media (max-width: 768px) {
            .cards-container {
                grid-template-columns: 1fr;
            }

            .transactions-grid {
                grid-template-columns: 1fr;
            }


        }
    </style>
</head>

<body>
    <div class="container">
        <h1><i class="fas fa-credit-card"></i> Payment History</h1>


        <?php if (!empty($email)): ?>
            <?php if (!empty($summaryData)): ?>
                <div class="cards-container">
                    <?php foreach ($summaryData as $summary): ?>
                        <div class="summary-card" onclick="openModal('<?php echo $summary['form_no']; ?>')">
                            <div class="card-header">
                                <div class="form-no"><?php echo htmlspecialchars($summary['form_no']); ?></div>
                                <div class="transaction-count"><?php echo $summary['transaction_count']; ?> transactions</div>
                            </div>
                            <div class="card-body">
                                <div class="card-row">
                                    <span class="card-label">Email</span>
                                    <span class="card-value email"><?php echo htmlspecialchars($summary['email']); ?></span>
                                </div>
                                <div class="total-amount">$<?php echo number_format($summary['total_amount'], 2); ?></div>
                            </div>
                            <div class="card-footer">
                                <span>Last transaction</span>
                                <span><?php
                                $lastTransaction = $formDetails[$summary['form_no']][0];
                                echo date('M j, Y', strtotime($lastTransaction['created_at']));
                                ?></span>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php else: ?>
                <div class="no-data">
                    <div class="no-data-icon"><i class="far fa-folder-open"></i></div>
                    <h3>No payment records found</h3>
                    <p>We couldn't find any payments for <?php echo htmlspecialchars($email); ?></p>
                </div>
            <?php endif; ?>
        <?php else: ?>
            <div class="no-data">
                <div class="no-data-icon"><i class="fas fa-search"></i></div>
                <h3>Search Payment History</h3>
                <p>Please enter your email address to view your payment records</p>
            </div>
        <?php endif; ?>
    </div>


    <?php if (!empty($email)): ?>
        <?php if (!empty($summaryData)): ?>
            <div class="cards-container">
                <!-- [Summary cards remain the same] -->
            </div>

            <!-- Modal for transaction details -->
            <?php foreach ($formDetails as $formNo => $transactions): ?>
                <div id="modal-<?php echo $formNo; ?>" class="modal">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h3 class="modal-title">Transactions for <?php echo $formNo; ?></h3>
                            <button class="close-btn" onclick="closeModal('<?php echo $formNo; ?>')">&times;</button>
                        </div>
                        <div class="modal-body">
                            <div class="transactions-grid">
                                <?php foreach ($transactions as $transaction): ?>
                                    <div class="transaction-card" data-id="<?php echo $transaction['id']; ?>">
                                        <label class="checkbox-container">
                                            <input type="checkbox" class="checkbox-input" id="check-<?php echo $transaction['id']; ?>"
                                                data-id="<?php echo $transaction['id']; ?>">
                                            <span class="checkbox-design"></span>
                                        </label>

                                        <div class="card-content">
                                            <div class="transaction-id">Transaction #<?php echo $transaction['id']; ?></div>
                                            <div class="transaction-amount">$<?php echo number_format($transaction['amount'], 2); ?>
                                            </div>

                                            <div class="transaction-meta">
                                                <span class="transaction-date">
                                                    <i class="far fa-calendar-alt"></i>
                                                    <?php echo date('M j, Y', strtotime($transaction['created_at'])); ?>
                                                </span>
                                                <span class="transaction-status status-success">
                                                    <i class="fas fa-check-circle"></i> Completed
                                                </span>
                                            </div>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                        <div class="modal-footer">
                            <div class="total-summary">
                                Total: $<?php
                                $total = array_sum(array_column($transactions, 'amount'));
                                echo number_format($total, 2);
                                ?> (<?php echo count($transactions); ?> transactions)
                            </div>
                            <button class="delete-selected" onclick="showDeleteConfirm('<?php echo $formNo; ?>')">
                                <i class="fas fa-trash"></i> Delete Selected
                            </button>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
    <?php endif; ?>
    </div>

    <!-- Delete Confirmation Modal -->
    <div class="confirm-modal" id="confirm-modal">
        <div class="confirm-content">
            <div class="confirm-icon">
                <i class="fas fa-exclamation-circle"></i>
            </div>
            <h3 style="text-align: center; margin-bottom: 0.5rem;">Delete Transactions</h3>
            <p style="text-align: center; color: var(--gray-600);">
                Are you sure you want to delete the selected transactions? This action cannot be undone.
            </p>
            <div class="confirm-buttons">
                <button class="confirm-btn cancel-delete" onclick="hideDeleteConfirm()">Cancel</button>
                <button class="confirm-btn confirm-delete" onclick="deleteSelectedTransactions()">Delete</button>
            </div>
        </div>
    </div>

    <script>
        let selectedTransactions = [];
        let currentFormNo = '';

        function openModal(formNo) {
            currentFormNo = formNo;
            const modal = document.getElementById(`modal-${formNo}`);
            modal.classList.add('show');
            document.body.style.overflow = 'hidden';
            resetSelection();
        }

        function closeModal(formNo) {
            const modal = document.getElementById(`modal-${formNo}`);
            modal.classList.remove('show');
            document.body.style.overflow = 'auto';
            resetSelection();
        }

        // Close modal when clicking outside
        window.addEventListener('click', (e) => {
            if (e.target.classList.contains('modal')) {
                const modals = document.querySelectorAll('.modal');
                modals.forEach(modal => modal.classList.remove('show'));
                document.body.style.overflow = 'auto';
                resetSelection();
            }
        });

        // Handle checkbox selection - UPDATED TO MATCH YOUR HTML
        document.addEventListener('change', function (e) {
            if (e.target.classList.contains('checkbox-input')) {  // Changed from custom-checkbox to checkbox-input
                const card = e.target.closest('.transaction-card');
                const transactionId = e.target.getAttribute('data-id');
                const deleteBtn = document.querySelector(`#modal-${currentFormNo} .delete-selected`);

                if (e.target.checked) {
                    card.classList.add('selected');
                    selectedTransactions.push(transactionId);
                } else {
                    card.classList.remove('selected');
                    selectedTransactions = selectedTransactions.filter(id => id !== transactionId);
                }

                deleteBtn.classList.toggle('show', selectedTransactions.length > 0);
            }
        });

        function resetSelection() {
            selectedTransactions = [];
            const checkboxes = document.querySelectorAll('.checkbox-input');  // Changed from custom-checkbox to checkbox-input
            const deleteBtns = document.querySelectorAll('.delete-selected');

            checkboxes.forEach(checkbox => {
                checkbox.checked = false;
                checkbox.closest('.transaction-card')?.classList.remove('selected');
            });

            deleteBtns.forEach(btn => {
                btn.classList.remove('show');
            });
        }

        function showDeleteConfirm(formNo) {
            if (selectedTransactions.length === 0) return;

            // প্রথমে বর্তমান মডালকে সাময়িকভাবে লুকান
            document.getElementById(`modal-${currentFormNo}`).style.opacity = '0';

            // তারপর কনফার্ম মডাল শো করুন
            document.getElementById('confirm-modal').classList.add('show');
        }

        function hideDeleteConfirm() {
            document.getElementById('confirm-modal').classList.remove('show');

            // কনফার্ম মডাল বন্ধ হলে প্রধান মডালকে আবার দেখান
            document.getElementById(`modal-${currentFormNo}`).style.opacity = '1';
        }

        function deleteSelectedTransactions() {
            if (selectedTransactions.length === 0) {
                hideDeleteConfirm();
                return;
            }

            // Show loading state
            const deleteBtn = document.querySelector('.confirm-delete');
            const originalText = deleteBtn.innerHTML;
            deleteBtn.innerHTML = '<i class="fas fa-spinner fa-spin"></i> Deleting...';
            deleteBtn.disabled = true;

            fetch('delete_transaction.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    ids: selectedTransactions
                })
            })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        // Remove deleted transactions from UI
                        selectedTransactions.forEach(id => {
                            const card = document.querySelector(`.transaction-card[data-id="${id}"]`);
                            if (card) {
                                card.style.transform = 'scale(0.9)';
                                card.style.opacity = '0';
                                setTimeout(() => card.remove(), 300);
                            }
                        });

                        // Update summary counts
                        updateSummaryAfterDeletion(selectedTransactions.length);

                        // Show success message with SweetAlert or similar
                        Swal.fire({
                            icon: 'success',
                            title: 'Success!',
                            text: data.message,
                            timer: 2000,
                            showConfirmButton: false
                        });
                    } else {
                        Swal.fire({
                            icon: 'error',
                            title: 'Error',
                            text: data.message
                        });
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    Swal.fire({
                        icon: 'error',
                        title: 'Error',
                        text: 'An error occurred while deleting transactions'
                    });
                })
                .finally(() => {
                    hideDeleteConfirm();
                    resetSelection();
                    deleteBtn.innerHTML = originalText;
                    deleteBtn.disabled = false;
                });
        }

        function updateSummaryAfterDeletion(deletedCount) {
            const summaryCard = document.querySelector(`.summary-card[onclick*="${currentFormNo}"]`);
            if (summaryCard) {
                // Update transaction count
                const countElement = summaryCard.querySelector('.transaction-count');
                if (countElement) {
                    const currentCount = parseInt(countElement.textContent.split(' ')[0]);
                    const newCount = currentCount - deletedCount;
                    countElement.textContent = `${newCount} transactions`;

                    if (newCount === 0) {
                        summaryCard.style.transform = 'scale(0.95)';
                        summaryCard.style.opacity = '0';
                        setTimeout(() => summaryCard.remove(), 300);
                    }
                }

                // Update total amount (you might need to recalculate this from server)
                const amountElement = summaryCard.querySelector('.total-amount');
                // This would ideally come from server response
                // amountElement.textContent = `$${newTotal.toFixed(2)}`;
            }

            // Update modal footer summary
            const modalFooter = document.querySelector(`#modal-${currentFormNo} .total-summary`);
            if (modalFooter) {
                const remainingCards = document.querySelectorAll(`#modal-${currentFormNo} .transaction-card`);
                const remainingAmount = Array.from(remainingCards).reduce((total, card) => {
                    const amountText = card.querySelector('.transaction-amount').textContent;
                    const amount = parseFloat(amountText.replace('$', ''));
                    return total + amount;
                }, 0);

                modalFooter.innerHTML = `Total: $${remainingAmount.toFixed(2)} (${remainingCards.length} transactions)`;
            }
        }


    </script>
</body>

</html>