<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Exam Results Dashboard</title>
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        :root {
            --primary-color: #4361ee;
            --secondary-color: #3f37c9;
            --accent-color: #4cc9f0;
            --success-color: #4ad66d;
            --danger-color: #f72585;
            --light-color: #f8f9fa;
            --dark-color: #212529;
            --gray-color: #6c757d;
            --border-radius: 8px;
            --box-shadow: 0 10px 30px rgba(0, 0, 0, 0.1);
            --transition: all 0.3s ease;
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: 'Poppins', sans-serif;
            background-color: #f5f7fa;
            color: var(--dark-color);
            line-height: 1.6;
            padding: 20px;
        }

        .container {
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px;
        }

        .header {
            text-align: center;
            margin-bottom: 40px;
        }

        .header h1 {
            font-size: 2.5rem;
            color: var(--primary-color);
            margin-bottom: 10px;
            font-weight: 700;
        }

        .header p {
            color: var(--gray-color);
            font-size: 1.1rem;
        }

        /* Class Accordion Styles */
        .class-accordion {
            margin-bottom: 20px;
            border-radius: var(--border-radius);
            overflow: hidden;
            box-shadow: var(--box-shadow);
        }

        .class-header {
            background: linear-gradient(135deg, var(--primary-color), var(--secondary-color));
            color: white;
            padding: 20px;
            cursor: pointer;
            display: flex;
            justify-content: space-between;
            align-items: center;
            transition: var(--transition);
        }

        .class-header:hover {
            background: linear-gradient(135deg, var(--secondary-color), var(--primary-color));
        }

        .class-header h2 {
            font-size: 1.5rem;
            font-weight: 600;
            margin: 0;
            display: flex;
            align-items: center;
            gap: 10px;
        }

        .class-header .toggle-icon {
            transition: var(--transition);
        }

        .class-header.active .toggle-icon {
            transform: rotate(180deg);
        }

        .class-content {
            background: white;
            max-height: 0;
            overflow: hidden;
            transition: max-height 0.3s ease-out;
        }

        .class-content-inner {
            padding: 0 20px;
        }

        /* Exam Section Styles */
        .exam-section {
            margin: 25px 0;
            border-left: 4px solid var(--accent-color);
            padding-left: 15px;
        }

        .exam-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 15px;
        }

        .exam-title {
            font-size: 1.3rem;
            color: var(--secondary-color);
            font-weight: 600;
        }

        .exam-meta {
            display: flex;
            gap: 15px;
        }

        .meta-item {
            background: #e9ecef;
            padding: 5px 12px;
            border-radius: 20px;
            font-size: 0.9rem;
            display: flex;
            align-items: center;
        }

        .meta-item i {
            margin-right: 5px;
            font-size: 0.8rem;
            color: var(--gray-color);
        }

        /* Table Styles */
        table {
            width: 100%;
            border-collapse: separate;
            border-spacing: 0;
            margin-bottom: 25px;
            overflow: hidden;
            border-radius: var(--border-radius);
            box-shadow: 0 2px 15px rgba(0, 0, 0, 0.05);
        }

        th, td {
            padding: 15px;
            text-align: center;
            border-bottom: 1px solid #e9ecef;
        }

        th {
            background-color: #f8f9fa;
            color: var(--dark-color);
            font-weight: 600;
            text-transform: uppercase;
            font-size: 0.85rem;
            letter-spacing: 0.5px;
            position: sticky;
            top: 0;
        }

        tr:hover {
            background-color: #f8f9fa;
        }

        tr:last-child td {
            border-bottom: none;
        }

        .subject-header {
            background-color: var(--primary-color);
            color: white;
        }

        .total-column {
            font-weight: 600;
            background-color: #f1f3f5;
        }

        .rank-column {
            font-weight: 700;
            color: var(--primary-color);
        }

        /* Action Buttons */
        .action-buttons {
            display: flex;
            justify-content: flex-end;
            gap: 15px;
            margin: 20px 0;
        }

        .btn {
            padding: 10px 25px;
            border-radius: var(--border-radius);
            font-weight: 500;
            cursor: pointer;
            transition: var(--transition);
            border: none;
            display: inline-flex;
            align-items: center;
            justify-content: center;
        }

        .btn i {
            margin-right: 8px;
        }

        .btn-print {
            background-color: var(--gray-color);
            color: white;
        }

        .btn-print:hover {
            background-color: #5a6268;
            transform: translateY(-2px);
        }

        /* Empty State */
        .no-results {
            text-align: center;
            padding: 50px;
            color: var(--gray-color);
        }

        .no-results i {
            font-size: 3rem;
            margin-bottom: 20px;
            color: #dee2e6;
        }

        .no-results h3 {
            font-weight: 500;
            margin-bottom: 10px;
        }

        /* Responsive styles */
        @media (max-width: 768px) {
            .exam-header {
                flex-direction: column;
                align-items: flex-start;
                gap: 10px;
            }
            
            .exam-meta {
                width: 100%;
                flex-wrap: wrap;
            }
            
            table {
                display: block;
                overflow-x: auto;
            }
            
            th, td {
                min-width: 120px;
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <h1>Exam Results Dashboard</h1>
            <p>Comprehensive view of student performance</p>
        </div>

        <?php if ($_SERVER['REQUEST_METHOD'] === 'POST'): ?>
            <input type="hidden" id="madrashaEmail" value="<?php echo $_POST['email']; ?>" readonly>

            <div id="results"></div>

            <script>
                fetch("display_api.php", {
                    method: "POST",
                    headers: {
                        "Content-Type": "application/x-www-form-urlencoded"
                    },
                    body: new URLSearchParams({ email: document.getElementById("madrashaEmail").value })
                })
                .then(response => response.json())
                .then(data => {
                    const resultsDiv = document.getElementById("results");

                    if (data.length === 0) {
                        resultsDiv.innerHTML = `
                            <div class="no-results">
                                <i class="fas fa-clipboard-list"></i>
                                <h3>No Results Found</h3>
                                <p>There are no exam results available for the selected criteria.</p>
                            </div>
                        `;
                        return;
                    }

                    // Group data by class
                    const classes = {};
                    data.forEach(classData => {
                        if (!classes[classData.class_name]) {
                            classes[classData.class_name] = [];
                        }
                        classes[classData.class_name].push(classData);
                    });

                    // Create accordion for each class
                    for (const className in classes) {
                        const classResults = classes[className];
                        let classHtml = `
                            <div class="class-accordion">
                                <div class="class-header">
                                    <h2>
                                        <i class="fas fa-graduation-cap"></i>
                                        ${className}
                                    </h2>
                                    <span class="toggle-icon"><i class="fas fa-chevron-down"></i></span>
                                </div>
                                <div class="class-content">
                                    <div class="class-content-inner">
                        `;

                        // Add exam sections for this class
                        classResults.forEach(classData => {
                            classHtml += `
                                <div class="exam-section">
                                    <div class="exam-header">
                                        <div class="exam-title">${classData.exam_name}</div>
                                        <div class="exam-meta">
                                            <span class="meta-item"><i class="fas fa-calendar-alt"></i> ${classData.exam_date}</span>
                                        </div>
                                    </div>
                                    <div class="table-responsive">
                                        <table>
                                            <thead>
                                                <tr>
                                                    <th>Form No</th>
                                                    <th>Student Name</th>
                            `;

                            let subjects = new Set();
                            classData.students.forEach(student => {
                                Object.keys(student.subjects).forEach(subject => subjects.add(subject));
                            });

                            subjects.forEach(subject => {
                                classHtml += `<th class="subject-header">${subject}</th>`;
                            });

                            classHtml += `
                                                    <th class="total-column">Total</th>
                                                    <th class="total-column">Obtained</th>
                                                    <th class="rank-column">Rank</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                            `;

                            classData.students.forEach(student => {
                                classHtml += `
                                    <tr>
                                        <td>${student.form_no}</td>
                                        <td style="text-align: left;">${student.student_name}</td>
                                `;

                                subjects.forEach(subject => {
                                    classHtml += `<td>${student.subjects[subject] || "-"}</td>`;
                                });

                                classHtml += `
                                        <td>${student.total}</td>
                                        <td>${student.obtained}</td>
                                        <td>${student.rank}</td>
                                    </tr>
                                `;
                            });

                            classHtml += `
                                            </tbody>
                                        </table>
                                    </div>
                                    <div class="action-buttons">
                                        <button class="btn btn-print" onclick="window.print()">
                                            <i class="fas fa-print"></i> Print Results
                                        </button>
                                    </div>
                                </div>
                            `;
                        });

                        classHtml += `
                                    </div>
                                </div>
                            </div>
                        `;
                        resultsDiv.innerHTML += classHtml;
                    }

                    // Initialize accordion functionality
                    const classHeaders = document.querySelectorAll('.class-header');
                    classHeaders.forEach(header => {
                        header.addEventListener('click', () => {
                            header.classList.toggle('active');
                            const content = header.nextElementSibling;
                            if (content.style.maxHeight) {
                                content.style.maxHeight = null;
                            } else {
                                content.style.maxHeight = content.scrollHeight + "px";
                            }
                        });
                    });
                })
                .catch(error => {
                    document.getElementById("results").innerHTML = `
                        <div class="no-results">
                            <i class="fas fa-exclamation-triangle"></i>
                            <h3>Error Loading Results</h3>
                            <p>There was an error fetching the exam results. Please try again later.</p>
                        </div>
                    `;
                    console.error('Error:', error);
                });
            </script>
        <?php endif; ?>
    </div>
</body>
</html>