<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Fetch Subjects</title>
    
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 20px;
        }
        input, button {
            margin: 5px 0;
            padding: 8px;
            font-size: 16px;
        }
        button {
            cursor: pointer;
        }
        ul {
            list-style-type: none;
            padding: 0;
        }
        li {
            background: #f4f4f4;
            margin: 5px 0;
            padding: 10px;
            border-radius: 5px;
        }

        /* Custom Alert Box */
        .custom-alert {
            position: fixed;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%) scale(0.5);
            background: rgba(255, 69, 0, 0.9);
            color: white;
            padding: 15px 25px;
            border-radius: 10px;
            text-align: center;
            font-size: 18px;
            font-weight: bold;
            opacity: 0;
            transition: transform 0.3s ease-out, opacity 0.3s ease-out;
            z-index: 1000;
        }
        .custom-alert.show {
            opacity: 1;
            transform: translate(-50%, -50%) scale(1);
        }
    </style>
</head>
<body>

    <h2>Fetch Subject Names</h2>

    <label for="email">Madrasha Email:</label>
    <input type="email" id="email" placeholder="Enter Madrasha Email" required>

    <label for="classID">Class ID:</label>
    <input type="number" id="classID" placeholder="Enter Class ID" required>

    <label for="className">Class Name:</label>
    <input type="text" id="className" placeholder="Enter Class Name" required>

    <button onclick="fetchSubjects()">Get Subjects</button>

    <h3>Subjects:</h3>
    <ul id="subjectList"></ul>

    <!-- Custom Alert Box -->
    <div id="customAlert" class="custom-alert"></div>

    <script>
        function showCustomAlert(message) {
            let alertBox = document.getElementById("customAlert");
            alertBox.textContent = message;
            alertBox.classList.add("show");

            setTimeout(() => {
                alertBox.classList.remove("show");
            }, 2000); // 2 seconds
        }

        function fetchSubjects() {
            let email = document.getElementById("email").value;
            let classID = document.getElementById("classID").value;
            let className = document.getElementById("className").value;

            if (!email || !classID || !className) {
                showCustomAlert("Please fill all fields!");
                return;
            }

            let requestData = {
                madrashaEmail: email,
                classID: parseInt(classID),
                className: className
            };

            fetch("search_subjects_api.php", {
                method: "POST",
                headers: {
                    "Content-Type": "application/json"
                },
                body: JSON.stringify(requestData)
            })
            .then(response => response.json())
            .then(data => {
                let subjectList = document.getElementById("subjectList");
                subjectList.innerHTML = ""; // Clear previous data

                if (data.success) {
                    data.subjects.forEach(subject => {
                        let li = document.createElement("li");
                        li.textContent = subject;
                        subjectList.appendChild(li);
                    });
                } else {
                    showCustomAlert(data.message);
                }
            })
            .catch(error => {
                console.error("Error:", error);
                showCustomAlert("Something went wrong!");
            });
        }
    </script>

</body>
</html>
