<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title>Attendance Report</title>

    <!-- Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Hind+Siliguri:wght@300;400;500;600;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">

    <!-- Libraries -->
    <script src="https://cdn.jsdelivr.net/npm/axios/dist/axios.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/xlsx/0.18.5/xlsx.full.min.js"></script>

    <style>
        /* Base Styles */
        :root {
            --primary: #4f46e5;
            --primary-dark: #4338ca;
            --primary-light: #6366f1;
            --success: #10b981;
            --danger: #ef4444;
            --warning: #f59e0b;
            --info: #8b5cf6;
            --light: #f8fafc;
            --dark: #1e293b;
            --gray: #64748b;
            --light-gray: #e2e8f0;
            --white: #ffffff;
            --shadow-sm: 0 1px 2px 0 rgba(0, 0, 0, 0.05);
            --shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
            --shadow-md: 0 10px 15px -3px rgba(0, 0, 0, 0.1), 0 4px 6px -2px rgba(0, 0, 0, 0.05);
            --shadow-lg: 0 20px 25px -5px rgba(0, 0, 0, 0.1), 0 10px 10px -5px rgba(0, 0, 0, 0.04);
            --rounded-sm: 0.25rem;
            --rounded: 0.5rem;
            --rounded-md: 0.75rem;
            --rounded-lg: 1rem;
            --transition: all 0.3s cubic-bezier(0.4, 0, 0.2, 1);
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: 'Hind Siliguri', sans-serif;
        }

        body {
            background-color: var(--light);
            color: var(--dark);
            line-height: 1.6;
            padding: 20px;
        }

        h2 {
            color: var(--dark);
            margin-bottom: 1.5rem;
            font-weight: 600;
            text-align: center;
            font-size: 1.75rem;
            position: relative;
            padding-bottom: 0.5rem;
        }

        h2::after {
            content: '';
            position: absolute;
            bottom: 0;
            left: 50%;
            transform: translateX(-50%);
            width: 80px;
            height: 3px;
            background: var(--primary);
            border-radius: 3px;
        }

        /* Search Container */
        .search-container {
            max-width: 600px;
            margin: 0 auto 2rem;
            position: relative;
        }

        .search-button {
            display: flex;
            align-items: center;
            justify-content: center;
            gap: 0.5rem;
            padding: 0.75rem 1.5rem;
            background-color: var(--primary);
            color: var(--white);
            border: none;
            border-radius: var(--rounded);
            cursor: pointer;
            font-size: 1rem;
            font-weight: 500;
            transition: var(--transition);
            width: 100%;
            box-shadow: var(--shadow);
        }

        .search-button:hover {
            background-color: var(--primary-dark);
            transform: translateY(-2px);
            box-shadow: var(--shadow-md);
        }

        .tooltip {
            display: none;
            position: absolute;
            background-color: var(--white);
            width: 100%;
            box-shadow: var(--shadow-lg);
            padding: 1.5rem;
            z-index: 100;
            border-radius: var(--rounded-md);
            top: 100%;
            left: 0;
            margin-top: 0.75rem;
            animation: fadeIn 0.3s ease-out;
        }

        @keyframes fadeIn {
            from { opacity: 0; transform: translateY(-10px); }
            to { opacity: 1; transform: translateY(0); }
        }

        .input-group {
            margin-bottom: 1.25rem;
        }

        .input-group label {
            display: block;
            margin-bottom: 0.5rem;
            font-weight: 500;
            color: var(--dark);
            font-size: 0.95rem;
        }

        input {
            padding: 0.75rem 1rem;
            width: 100%;
            border: 1px solid var(--light-gray);
            border-radius: var(--rounded-sm);
            font-size: 0.95rem;
            transition: var(--transition);
        }

        input:focus {
            outline: none;
            border-color: var(--primary);
            box-shadow: 0 0 0 3px rgba(79, 70, 229, 0.1);
        }

        .tooltip-button {
            display: flex;
            align-items: center;
            justify-content: center;
            gap: 0.5rem;
            padding: 0.75rem;
            background-color: var(--primary);
            color: var(--white);
            border: none;
            border-radius: var(--rounded-sm);
            cursor: pointer;
            font-size: 1rem;
            font-weight: 500;
            transition: var(--transition);
            width: 100%;
        }

        .tooltip-button:hover {
            background-color: var(--primary-dark);
        }

        /* Card Styles */
        .card-container {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
            gap: 1.5rem;
            margin-top: 2rem;
        }

        .card {
            background-color: var(--white);
            border-radius: var(--rounded-md);
            box-shadow: var(--shadow);
            padding: 1.5rem;
            cursor: pointer;
            transition: var(--transition);
            position: relative;
            overflow: hidden;
            border: 1px solid var(--light-gray);
        }

        .card::before {
            content: '';
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 4px;
            background: linear-gradient(90deg, var(--primary), var(--info));
        }

        .card-title {
            font-size: 1.25rem;
            font-weight: 600;
            margin-bottom: 1.25rem;
            color: var(--dark);
            padding-bottom: 0.75rem;
            text-align: center;
            position: relative;
        }

        .card-title::after {
            content: '';
            position: absolute;
            bottom: 0;
            left: 50%;
            transform: translateX(-50%);
            width: 50px;
            height: 2px;
            background: var(--light-gray);
        }

        .card:hover {
            transform: translateY(-5px);
            box-shadow: var(--shadow-lg);
        }

        .card-stats {
            display: grid;
            grid-template-columns: repeat(2, 1fr);
            gap: 0.75rem;
            margin-bottom: 1rem;
        }

        .stat-item {
            text-align: center;
            padding: 0.75rem;
            background-color: var(--light);
            border-radius: var(--rounded-sm);
            transition: var(--transition);
        }

        .stat-item:hover {
            transform: translateY(-3px);
            box-shadow: var(--shadow-sm);
        }

        .stat-value {
            font-size: 1.5rem;
            font-weight: 700;
            margin-bottom: 0.25rem;
        }

        .present .stat-value { color: var(--success); }
        .absent .stat-value { color: var(--danger); }
        .leave .stat-value { color: var(--warning); }
        .sick .stat-value { color: var(--info); }

        .percentage-value {
            font-size: 0.85rem;
            color: var(--gray);
            margin-top: 0.25rem;
        }

        .stat-label {
            font-size: 0.85rem;
            color: var(--gray);
            font-weight: 500;
        }

        .card-footer {
            margin-top: 1rem;
            font-size: 0.85rem;
            color: var(--gray);
            text-align: center;
            font-style: italic;
        }

        .chart-container {
            position: relative;
            height: 200px;
            margin-bottom: 1rem;
        }

        /* Results Container */
        .results-container {
            max-width: 1200px;
            margin: 2rem auto;
            padding: 1.5rem;
            background-color: var(--white);
            border-radius: var(--rounded-md);
            box-shadow: var(--shadow);
        }

        .year-search-container {
            display: flex;
            gap: 0.75rem;
            margin-bottom: 1.5rem;
            position: sticky;
            top: 0;
            background-color: var(--white);
            padding: 1rem 0;
            z-index: 10;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
        }

        .year-search-input {
            flex-grow: 1;
            padding: 0.75rem 1rem;
            border: 1px solid var(--light-gray);
            border-radius: var(--rounded-sm);
            font-size: 0.95rem;
            transition: var(--transition);
        }

        .year-search-input:focus {
            outline: none;
            border-color: var(--primary);
            box-shadow: 0 0 0 3px rgba(79, 70, 229, 0.1);
        }

        .year-search-button {
            padding: 0 1.25rem;
            background-color: var(--primary);
            color: var(--white);
            border: none;
            border-radius: var(--rounded-sm);
            cursor: pointer;
            font-size: 0.95rem;
            font-weight: 500;
            transition: var(--transition);
            display: flex;
            align-items: center;
            justify-content: center;
        }

        .year-search-button:hover {
            background-color: var(--primary-dark);
        }

        .no-results {
            text-align: center;
            padding: 2rem;
            color: var(--gray);
            font-size: 1rem;
        }

        .year-filter-reset {
            padding: 0 1rem;
            background-color: var(--light);
            color: var(--gray);
            border: none;
            border-radius: var(--rounded-sm);
            cursor: pointer;
            font-size: 0.95rem;
            font-weight: 500;
            transition: var(--transition);
            display: flex;
            align-items: center;
            justify-content: center;
        }

        .year-filter-reset:hover {
            background-color: var(--light-gray);
        }

        .search-icon {
            margin-right: 0.5rem;
        }

        /* Modal Styles */
        .modal {
            display: none;
            position: fixed;
            z-index: 1000;
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            overflow: auto;
            background-color: rgba(15, 23, 42, 0.7);
            backdrop-filter: blur(5px);
            animation: fadeIn 0.3s;
        }

        .modal-content {
            background-color: var(--white);
            margin: 5% auto;
            padding: 2rem;
            border: none;
            width: 90%;
            max-width: 1000px;
            border-radius: var(--rounded-lg);
            box-shadow: var(--shadow-lg);
            max-height: 85vh;
            overflow-y: auto;
            animation: slideUp 0.4s ease;
        }

        @keyframes slideUp {
            from { transform: translateY(50px); opacity: 0; }
            to { transform: translateY(0); opacity: 1; }
        }

        .close {
            color: var(--gray);
            float: right;
            font-size: 1.75rem;
            font-weight: bold;
            cursor: pointer;
            transition: var(--transition);
        }

        .close:hover {
            color: var(--dark);
            transform: rotate(90deg);
        }

        /* Table Styles */
        table {
            width: 100%;
            border-collapse: separate;
            border-spacing: 0;
            margin-top: 1.5rem;
            font-size: 0.95rem;
        }

        th {
            background-color: var(--primary);
            color: var(--white);
            font-weight: 500;
            padding: 0.75rem 1rem;
            text-align: center;
            position: sticky;
            top: 0;
        }

        td {
            padding: 0.75rem 1rem;
            text-align: center;
            border-bottom: 1px solid var(--light-gray);
        }

        tr:nth-child(even) {
            background-color: rgba(248, 250, 252, 0.5);
        }

        tr:hover {
            background-color: var(--light);
        }

        .action-btn {
            display: flex;
            align-items: center;
            justify-content: center;
            gap: 0.5rem;
            padding: 0.5rem 1rem;
            background-color: var(--primary);
            color: var(--white);
            border: none;
            border-radius: var(--rounded-sm);
            cursor: pointer;
            font-size: 0.85rem;
            font-weight: 500;
            transition: var(--transition);
        }

        .action-btn:hover {
            background-color: var(--primary-dark);
            transform: translateY(-2px);
        }

        /* Daily Details Modal */
        .daily-modal {
            display: none;
            position: fixed;
            z-index: 1100;
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            overflow: auto;
            background-color: rgba(15, 23, 42, 0.8);
            backdrop-filter: blur(5px);
        }

        .daily-modal-content {
            background-color: var(--white);
            margin: 3% auto;
            padding: 2rem;
            border: none;
            width: 90%;
            max-width: 800px;
            border-radius: var(--rounded-lg);
            box-shadow: var(--shadow-lg);
            max-height: 90vh;
            overflow-y: auto;
            animation: scaleIn 0.3s ease;
        }

        @keyframes scaleIn {
            from { transform: scale(0.95); opacity: 0; }
            to { transform: scale(1); opacity: 1; }
        }

        .daily-modal-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 1.5rem;
            padding-bottom: 1rem;
            border-bottom: 1px solid var(--light-gray);
        }

        .daily-modal-title {
            font-size: 1.5rem;
            font-weight: 600;
            color: var(--dark);
        }

        .daily-close {
            color: var(--gray);
            font-size: 1.75rem;
            font-weight: bold;
            cursor: pointer;
            transition: var(--transition);
        }

        .daily-close:hover {
            color: var(--dark);
            transform: rotate(90deg);
        }

        .daily-table th {
            background-color: var(--primary);
            color: var(--white);
            padding: 0.75rem;
        }

        .daily-table td {
            padding: 0.75rem;
            border-bottom: 1px solid var(--light-gray);
        }

        .present { color: var(--success); font-weight: 600; }
        .absent { color: var(--danger); font-weight: 600; }
        .leave { color: var(--warning); font-weight: 600; }
        .sick { color: var(--info); font-weight: 600; }

        .info-container {
            background-color: var(--light);
            padding: 1.5rem;
            border-radius: var(--rounded);
            margin-bottom: 1.5rem;
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(200px, 1fr));
            gap: 1rem;
        }

        .info-item {
            margin-bottom: 0;
        }

        .info-label {
            font-weight: 600;
            color: var(--dark);
            display: block;
            margin-bottom: 0.25rem;
            font-size: 0.9rem;
        }

        .info-value {
            color: var(--gray);
            font-size: 0.95rem;
        }

        .modal-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 1.5rem;
            padding-bottom: 1rem;
            border-bottom: 1px solid var(--light-gray);
        }

        .modal-title {
            font-size: 1.5rem;
            font-weight: 600;
            color: var(--dark);
            flex-grow: 1;
            text-align: center;
        }

        .modal-actions {
            display: flex;
            align-items: center;
            min-width: 100px;
        }

        .back-button {
            display: flex;
            align-items: center;
            gap: 0.5rem;
            padding: 0.5rem 1rem;
            background-color: var(--primary);
            color: var(--white);
            border: none;
            border-radius: var(--rounded-sm);
            cursor: pointer;
            font-size: 0.9rem;
            font-weight: 500;
            transition: var(--transition);
        }

        .back-button:hover {
            background-color: var(--primary-dark);
        }

        .report-container {
            background-color: var(--light);
            padding: 1.5rem;
            border-radius: var(--rounded);
            margin-top: 1.5rem;
        }

        .report-title {
            font-size: 1.25rem;
            font-weight: 600;
            color: var(--dark);
            margin-bottom: 1rem;
            text-align: center;
        }

        .report-data {
            font-family: 'Hind Siliguri', monospace;
            white-space: pre-wrap;
            background-color: var(--white);
            padding: 1rem;
            border-radius: var(--rounded-sm);
            overflow-x: auto;
        }

        /* Alert Modal Styles */
        .alert-modal {
            display: none;
            position: fixed;
            z-index: 2000;
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            overflow: auto;
            background-color: rgba(15, 23, 42, 0.7);
            backdrop-filter: blur(5px);
            animation: fadeIn 0.3s;
        }

        .alert-modal-content {
            background-color: var(--white);
            margin: 8% auto;
            padding: 2rem;
            border: none;
            width: 90%;
            max-width: 400px;
            border-radius: var(--rounded-lg);
            box-shadow: var(--shadow-lg);
            animation: slideDown 0.3s ease;
            text-align: center;
        }

        @keyframes slideDown {
            from { transform: translateY(-50px); opacity: 0; }
            to { transform: translateY(0); opacity: 1; }
        }

        .alert-icon {
            font-size: 3rem;
            margin-bottom: 1rem;
        }

        .alert-success .alert-icon { color: var(--success); }
        .alert-error .alert-icon { color: var(--danger); }
        .alert-warning .alert-icon { color: var(--warning); }
        .alert-info .alert-icon { color: var(--info); }

        .alert-title {
            font-size: 1.5rem;
            font-weight: 600;
            margin-bottom: 1rem;
            color: var(--dark);
        }

        .alert-message {
            font-size: 1rem;
            color: var(--gray);
            margin-bottom: 1.5rem;
            line-height: 1.5;
        }

        .alert-button {
            display: inline-flex;
            align-items: center;
            justify-content: center;
            gap: 0.5rem;
            padding: 0.75rem 1.5rem;
            background-color: var(--primary);
            color: var(--white);
            border: none;
            border-radius: var(--rounded-sm);
            cursor: pointer;
            font-size: 1rem;
            font-weight: 500;
            transition: var(--transition);
            font-family: 'Hind Siliguri', sans-serif;
            min-width: 120px;
        }

        .alert-button:hover {
            background-color: var(--primary-dark);
            transform: translateY(-2px);
        }

        .alert-success .alert-button { background-color: var(--success); }
        .alert-error .alert-button { background-color: var(--danger); }
        .alert-warning .alert-button { background-color: var(--warning); }
        .alert-info .alert-button { background-color: var(--info); }

        .alert-success .alert-button:hover { background-color: #0e9f6e; }
        .alert-error .alert-button:hover { background-color: #dc2626; }
        .alert-warning .alert-button:hover { background-color: #e27809; }
        .alert-info .alert-button:hover { background-color: #7c3aed; }

        /* Responsive Design */
        @media (max-width: 768px) {
            .modal-content,
            .daily-modal-content {
                width: 95%;
                padding: 1.5rem;
                margin: 10% auto;
            }

            .card-container {
                grid-template-columns: 1fr;
            }

            .info-container {
                grid-template-columns: 1fr;
            }

            table, .daily-table {
                font-size: 0.85rem;
            }

            th, td {
                padding: 0.5rem;
            }

            .year-search-container {
                flex-direction: column;
            }

            .year-search-button,
            .year-filter-reset {
                width: 100%;
                padding: 0.75rem;
            }
        }

        /* Loading Spinner */
        .spinner {
            animation: spin 1s linear infinite;
            display: inline-block;
        }

        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }

        /* Status Badges */
        .status-badge {
            display: inline-block;
            padding: 0.25rem 0.5rem;
            border-radius: 50px;
            font-size: 0.75rem;
            font-weight: 500;
        }

        .badge-present {
            background-color: rgba(16, 185, 129, 0.1);
            color: var(--success);
        }

        .badge-absent {
            background-color: rgba(239, 68, 68, 0.1);
            color: var(--danger);
        }

        .badge-leave {
            background-color: rgba(245, 158, 11, 0.1);
            color: var(--warning);
        }

        .badge-sick {
            background-color: rgba(139, 92, 246, 0.1);
            color: var(--info);
        }
    </style>
</head>

<body>

    <h2>ছাত্র উপস্থিতি রিপোর্ট</h2>

    <div class="search-container">
        <button class="search-button" onclick="toggleTooltip()">
            <i class="fas fa-search"></i> সার্চ করুন
        </button>
        <div id="searchTooltip" class="tooltip">
            <div class="input-group">
                <label for="formNo">ফর্ম নম্বর</label>
                <input type="text" id="formNo" placeholder="ফর্ম নম্বর লিখুন" />
            </div>
            <button class="tooltip-button" onclick="getAttendance()">
                <i class="fas fa-search"></i> ডাটা দেখুন
            </button>
        </div>
    </div>

    <!-- Results Container (replaces the cardModal) -->
    <div id="resultsContainer" class="results-container" style="display: none;">
        <!-- Year Search Container -->
        <div class="year-search-container">
            <input type="text" id="yearSearchInput" class="year-search-input" placeholder="বছর দিয়ে খুঁজুন (যেমন: 2023)" />
            <button id="yearSearchButton" class="year-search-button" onclick="filterCardsByYear()">
                <i class="fas fa-search search-icon"></i> খুঁজুন
            </button>
            <button id="yearFilterReset" class="year-filter-reset" onclick="resetYearFilter()" style="display: none;">
                <i class="fas fa-times search-icon"></i> রিসেট
            </button>
        </div>

        <div id="card-section" class="card-container"></div>
        <div id="noResults" class="no-results" style="display: none;">কোনো ফলাফল পাওয়া যায়নি</div>
    </div>

    <!-- Monthly Details Modal -->
    <div id="detailModal" class="modal">
        <div class="modal-content">
            <div class="modal-header">
                <div class="modal-actions">
                    <button class="back-button" onclick="backToResults()">
                        <i class="fas fa-arrow-left"></i> ব্যাক
                    </button>
                </div>
                <div class="modal-title">মাসিক উপস্থিতি রিপোর্ট</div>
                <div class="modal-actions">
                    <span class="close" onclick="closeDetailModal()">&times;</span>
                </div>
            </div>

            <div id="data-section"></div>
        </div>
    </div>

    <!-- Daily Details Modal -->
    <div id="dailyModal" class="daily-modal">
        <div class="daily-modal-content">
            <div class="daily-modal-header">
                <h2 class="daily-modal-title">উপস্থিতি বিস্তারিত</h2>
                <span class="daily-close" onclick="closeDailyModal()">&times;</span>
            </div>

            <!-- Information Container -->
            <div class="info-container" id="info-container">
                <!-- Information will be added dynamically -->
            </div>

            <div class="report-container">
                <div id="report" class="report-data"></div>
            </div>
        </div>
    </div>

    <!-- Alert Modal -->
    <div id="alertModal" class="alert-modal">
        <div class="alert-modal-content" id="alertModalContent">
            <div class="alert-icon">
                <i class="fas fa-check-circle"></i>
            </div>
            <h3 class="alert-title" id="alertTitle">Success</h3>
            <p class="alert-message" id="alertMessage">Operation completed successfully.</p>
            <button class="alert-button" onclick="closeAlertModal()">
                <i class="fas fa-check"></i> OK
            </button>
        </div>
    </div>

    <script>
        // Global variables
        let allAttendanceData = [];
        let yearlySummaryData = {};
        let dailyAttendanceData = {};
        let charts = {}; // To store chart instances

        // Toggle search tooltip
        function toggleTooltip() {
            const tooltip = document.getElementById('searchTooltip');
            tooltip.style.display = tooltip.style.display === 'block' ? 'none' : 'block';
        }

        // Modal functions
        function openDetailModal(year) {
            const dataSection = document.getElementById('data-section');
            dataSection.innerHTML = '';

            const yearData = allAttendanceData.filter(item => item.year == year);

            if (yearData.length > 0) {
                createMonthlyTable(yearData);
            } else {
                dataSection.innerHTML = '<div class="message">কোনো তথ্য পাওয়া যায়নি।</div>';
            }

            document.getElementById('detailModal').style.display = "block";
            document.body.style.overflow = "hidden";
        }

        function backToResults() {
            document.getElementById('detailModal').style.display = "none";
            document.body.style.overflow = "auto";
        }

        function closeDetailModal() {
            document.getElementById('detailModal').style.display = "none";
            document.body.style.overflow = "auto";
        }

        function openDailyModal(monthData) {
            const infoContainer = document.getElementById('info-container');
            let form_no = monthData.form_no;
            let email = monthData.email;
            let year = monthData.year;
            let month = monthData.month;
            let month_name = monthData.month_name;
            let full_date = `${year}-${String(month).padStart(2, '0')}`;

            monthlyReport(full_date, form_no, email);

            infoContainer.innerHTML = `
                <div class="info-item">
                    <span class="info-label">ফর্ম নম্বর:</span>
                    <span class="info-value">${form_no}</span>
                </div>
                <div class="info-item">
                    <span class="info-label">ইমেইল:</span>
                    <span class="info-value">${email || 'N/A'}</span>
                </div>
                <div class="info-item">
                    <span class="info-label">সময়কাল:</span>
                    <span class="info-value">${full_date}</span>
                </div>
                <div class="info-item">
                    <span class="info-label">মাস:</span>
                    <span class="info-value">${month_name}</span>
                </div>
            `;

            document.getElementById('dailyModal').style.display = "block";
            document.body.style.overflow = "hidden";
        }

        function closeDailyModal() {
            document.getElementById('dailyModal').style.display = "none";
            document.body.style.overflow = "auto";
        }

        function monthlyReport(yearmonth, form_no, email) {
            const reportDiv = document.getElementById('report');
            reportDiv.innerHTML = '<p><i class="fas fa-spinner spinner"></i> লোড হচ্ছে...</p>';

            axios.post('z_api.php', {
                    month: yearmonth,
                    form_no: form_no,
                    email: email
                })
                .then(function(response) {
                    const res = response.data;
                    if (res.status) {
                        let output = `<div class="report-title">${res.month} মাসের রিপোর্ট</div><pre>`;
                        const data = res.data;
                        for (const status in data) {
    const item = data[status];
    console.log(item.dates);
    
    const formattedDates = item.dates.map(dateStr => {
        const date = new Date(dateStr);
        const day = date.getDate();
        const month = date.toLocaleString('default', { month: 'long' });
        const year = date.getFullYear();
        // শুধু day-কে span দিয়ে হাইলাইট
        return `<span style="background-color: yellow; padding: 2px 4px; border-radius: 4px;">${day}</span> ${month} ${year}`;
    }).join(', ');

    output += `<span class="${getStatusClass(status)}">${status}: ${item.count} (${formattedDates})</span>\n`;
    output += "----------------------\n";
}

                        output += '</pre>';
                        reportDiv.innerHTML = output;
                    } else {
                        reportDiv.innerHTML = `<p style="color: var(--danger);">${res.message}</p>`;
                    }
                })
                .catch(function(error) {
                    console.error(error);
                    reportDiv.innerHTML = '<p style="color: var(--danger);">কোনো সমস্যা হয়েছে। অনুগ্রহ করে পরে আবার চেষ্টা করুন।</p>';
                });
        }

        function getStatusClass(status) {
            switch(status.toLowerCase()) {
                case 'present': return 'present';
                case 'absent': return 'absent';
                case 'leave': return 'leave';
                case 'sick': return 'sick';
                default: return '';
            }
        }

        function createMonthlyTable(data) {
            const dataSection = document.getElementById('data-section');
            let table = `
            <table>
                <thead>
                    <tr>
                        <th>মাস</th>
                        <th>উপস্থিত</th>
                        <th>অনুপস্থিত</th>
                        <th>রুখসত</th>
                        <th>বিমার</th>
                        <th>একশন</th>
                    </tr>
                </thead>
                <tbody>`;

            data.forEach(item => {
                table += `
                <tr>
                    <td>${item.month_name}</td>
                    <td class="present">${item.total_present}</td>
                    <td class="absent">${item.total_absent}</td>
                    <td class="leave">${item.total_leave}</td>
                    <td class="sick">${item.total_sick}</td>
                    <td>
                        <button class="action-btn" onclick="openDailyModal({
                            form_no: '${item.form_no}',
                            email: '${item.email || ''}',
                            year: ${item.year},
                            month: ${getMonthNumber(item.month_name)},
                            month_name: '${item.month_name}'
                        })">
                            <i class="fas fa-calendar-day"></i> বিস্তারিত
                        </button>
                    </td>
                </tr>`;
            });

            table += `</tbody></table>`;
            dataSection.innerHTML = table;
        }

        function getMonthNumber(monthName) {
            const months = {
                'জানুয়ারি': 1,
                'ফেব্রুয়ারি': 2,
                'মার্চ': 3,
                'এপ্রিল': 4,
                'মে': 5,
                'জুন': 6,
                'জুলাই': 7,
                'আগস্ট': 8,
                'সেপ্টেম্বর': 9,
                'অক্টোবর': 10,
                'নভেম্বর': 11,
                'ডিসেম্বর': 12
            };
            return months[monthName] || 1;
        }

        // Main function to get attendance data
        function getAttendance() {
            const formNo = document.getElementById('formNo').value.trim();

            if (!formNo) {
                showAlert('ইনপুট প্রয়োজন', 'দয়া করে ফর্ম নম্বর লিখুন', 'warning');
                return;
            }

            const searchBtn = document.querySelector('.tooltip-button');
            searchBtn.innerHTML = '<i class="fas fa-spinner spinner"></i> লোড হচ্ছে...';
            searchBtn.disabled = true;

            axios.post('tracker.php', {
                    formNo: formNo
                })
                .then(function(response) {
                    const result = response.data;
                    allAttendanceData = result.data || [];
                    yearlySummaryData = {};

                    const cardSection = document.getElementById('card-section');
                    cardSection.innerHTML = '';

                    if (allAttendanceData.length > 0) {
                        // Group data by year
                        allAttendanceData.forEach(item => {
                            if (!yearlySummaryData[item.year]) {
                                yearlySummaryData[item.year] = {
                                    year: item.year,
                                    total_present: 0,
                                    total_absent: 0,
                                    total_leave: 0,
                                    total_sick: 0,
                                    months: []
                                };
                            }

                            yearlySummaryData[item.year].total_present += parseInt(item.total_present) || 0;
                            yearlySummaryData[item.year].total_absent += parseInt(item.total_absent) || 0;
                            yearlySummaryData[item.year].total_leave += parseInt(item.total_leave) || 0;
                            yearlySummaryData[item.year].total_sick += parseInt(item.total_sick) || 0;
                            yearlySummaryData[item.year].months.push(item);
                        });

                        // Create cards for each year
                        Object.values(yearlySummaryData).sort((a, b) => b.year - a.year).forEach(yearData => {
                            const card = document.createElement('div');
                            card.className = 'card';
                            card.id = `card-${yearData.year}`;

                            // Calculate percentages
                            const total = yearData.total_present + yearData.total_absent + yearData.total_leave + yearData.total_sick;
                            const presentPercent = total > 0 ? Math.round((yearData.total_present / total) * 100) : 0;
                            const absentPercent = total > 0 ? Math.round((yearData.total_absent / total) * 100) : 0;
                            const leavePercent = total > 0 ? Math.round((yearData.total_leave / total) * 100) : 0;
                            const sickPercent = total > 0 ? Math.round((yearData.total_sick / total) * 100) : 0;

                            card.innerHTML = `
                            <div class="card-title">${yearData.year} সালের রিপোর্ট</div>
                            <div class="chart-container">
                                <canvas id="chart-${yearData.year}"></canvas>
                            </div>
                            <div class="card-stats">
                                <div class="stat-item present">
                                    <div class="stat-value">${yearData.total_present}</div>
                                    <div class="percentage-value">${presentPercent}%</div>
                                    <div class="stat-label">উপস্থিত</div>
                                </div>
                                <div class="stat-item absent">
                                    <div class="stat-value">${yearData.total_absent}</div>
                                    <div class="percentage-value">${absentPercent}%</div>
                                    <div class="stat-label">অনুপস্থিত</div>
                                </div>
                                <div class="stat-item leave">
                                    <div class="stat-value">${yearData.total_leave}</div>
                                    <div class="percentage-value">${leavePercent}%</div>
                                    <div class="stat-label">রুখসত</div>
                                </div>
                                <div class="stat-item sick">
                                    <div class="stat-value">${yearData.total_sick}</div>
                                    <div class="percentage-value">${sickPercent}%</div>
                                    <div class="stat-label">বিমার</div>
                                </div>
                            </div>
                            
                            <div class="card-footer">
                                বিস্তারিত দেখতে কার্ডে ক্লিক করুন
                            </div>
                        `;

                            card.onclick = () => {
                                openDetailModal(yearData.year);
                            };

                            cardSection.appendChild(card);

                            // Create chart after the card is added to DOM
                            setTimeout(() => {
                                createChart(yearData.year, yearData);
                            }, 100);
                        });

                        document.getElementById('searchTooltip').style.display = 'none';
                        document.getElementById('resultsContainer').style.display = 'block';
                    } else {
                        showAlert('কোনো তথ্য নেই', 'প্রদানকৃত ফর্ম নম্বরের জন্য কোনো তথ্য পাওয়া যায়নি', 'info');
                        document.getElementById('resultsContainer').style.display = 'none';
                    }
                })
                .catch(function(error) {
                    console.error(error);
                    showAlert('ত্রুটি', 'ডেটা আনতে সমস্যা হয়েছে। অনুগ্রহ করে পরে আবার চেষ্টা করুন', 'error');
                    document.getElementById('resultsContainer').style.display = 'none';
                })
                .finally(function() {
                    const searchBtn = document.querySelector('.tooltip-button');
                    searchBtn.innerHTML = '<i class="fas fa-search"></i> ডাটা দেখুন';
                    searchBtn.disabled = false;
                });
        }

        // Create chart for a year
        function createChart(year, data) {
            const ctx = document.getElementById(`chart-${year}`).getContext('2d');

            // Destroy previous chart if exists
            if (charts[year]) {
                charts[year].destroy();
            }

            const total = data.total_present + data.total_absent + data.total_leave + data.total_sick;

            charts[year] = new Chart(ctx, {
                type: 'doughnut',
                data: {
                    labels: ['উপস্থিত', 'অনুপস্থিত', 'রুখসত', 'বিমার'],
                    datasets: [{
                        data: [
                            data.total_present,
                            data.total_absent,
                            data.total_leave,
                            data.total_sick
                        ],
                        backgroundColor: [
                            'rgba(16, 185, 129, 0.8)',
                            'rgba(239, 68, 68, 0.8)',
                            'rgba(245, 158, 11, 0.8)',
                            'rgba(139, 92, 246, 0.8)'
                        ],
                        borderColor: [
                            'rgba(16, 185, 129, 1)',
                            'rgba(239, 68, 68, 1)',
                            'rgba(245, 158, 11, 1)',
                            'rgba(139, 92, 246, 1)'
                        ],
                        borderWidth: 1
                    }]
                },
                options: {
                    responsive: true,
                    maintainAspectRatio: false,
                    plugins: {
                        legend: {
                            position: 'bottom',
                            labels: {
                                boxWidth: 12,
                                padding: 20,
                                font: {
                                    family: 'Hind Siliguri',
                                    size: 12
                                }
                            }
                        },
                        tooltip: {
                            callbacks: {
                                label: function(context) {
                                    const value = context.raw;
                                    const percentage = total > 0 ? Math.round((value / total) * 100) : 0;
                                    return `${context.label}: ${value} (${percentage}%)`;
                                }
                            },
                            bodyFont: {
                                family: 'Hind Siliguri'
                            }
                        }
                    },
                    cutout: '70%'
                }
            });
        }

        // Close modals when clicking outside
        window.onclick = function(event) {
            if (event.target == document.getElementById('detailModal')) {
                closeDetailModal();
            }
            if (event.target == document.getElementById('dailyModal')) {
                closeDailyModal();
            }
            if (event.target == document.getElementById('alertModal')) {
                closeAlertModal();
            }
        }

        // Close tooltip when clicking outside
        document.addEventListener('click', function(event) {
            const tooltip = document.getElementById('searchTooltip');
            const searchButton = document.querySelector('.search-container .search-button');

            if (!tooltip.contains(event.target) && event.target !== searchButton) {
                tooltip.style.display = 'none';
            }
        });

        // Handle Enter key in search inputs
        document.getElementById('formNo').addEventListener('keypress', function(e) {
            if (e.key === 'Enter') {
                getAttendance();
            }
        });

        // Add these new functions for year filtering
        function filterCardsByYear() {
            const searchTerm = document.getElementById('yearSearchInput').value.trim();
            const cards = document.querySelectorAll('.card');
            const noResults = document.getElementById('noResults');
            const resetButton = document.getElementById('yearFilterReset');
            let hasResults = false;

            if (!searchTerm) {
                resetYearFilter();
                return;
            }

            cards.forEach(card => {
                const year = card.querySelector('.card-title').textContent.match(/\d+/)[0];
                if (year.includes(searchTerm)) {
                    card.style.display = 'block';
                    hasResults = true;
                } else {
                    card.style.display = 'none';
                }
            });

            noResults.style.display = hasResults ? 'none' : 'block';
            resetButton.style.display = 'block';
        }

        function resetYearFilter() {
            document.getElementById('yearSearchInput').value = '';
            document.querySelectorAll('.card').forEach(card => {
                card.style.display = 'block';
            });
            document.getElementById('noResults').style.display = 'none';
            document.getElementById('yearFilterReset').style.display = 'none';
        }

        // Handle Enter key in year search input
        document.getElementById('yearSearchInput').addEventListener('keypress', function(e) {
            if (e.key === 'Enter') {
                filterCardsByYear();
            }
        });

        // Alert Modal Functions
        function showAlert(title, message, type = 'success') {
            const modal = document.getElementById('alertModal');
            const content = document.getElementById('alertModalContent');
            const icon = content.querySelector('.alert-icon i');
            const titleEl = document.getElementById('alertTitle');
            const messageEl = document.getElementById('alertMessage');
            
            // Set content
            titleEl.textContent = title;
            messageEl.textContent = message;
            
            // Set type (success, error, warning, info)
            content.className = 'alert-modal-content alert-' + type;
            
            // Set appropriate icon
            switch(type) {
                case 'success':
                    icon.className = 'fas fa-check-circle';
                    break;
                case 'error':
                    icon.className = 'fas fa-times-circle';
                    break;
                case 'warning':
                    icon.className = 'fas fa-exclamation-triangle';
                    break;
                case 'info':
                    icon.className = 'fas fa-info-circle';
                    break;
            }
            
            modal.style.display = 'block';
            document.body.style.overflow = 'hidden';
        }

        function closeAlertModal() {
            document.getElementById('alertModal').style.display = 'none';
            document.body.style.overflow = 'auto';
        }
    </script>
</body>
</html>