document.addEventListener("DOMContentLoaded", function () {
    fetch("get_exam_results.php")
        .then(response => response.json())
        .then(data => displayResults(data))
        .catch(error => console.error("Error fetching data:", error));
});

function displayResults(examData) {
    let resultsDiv = document.getElementById("results");

    if (examData.length === 0) {
        resultsDiv.innerHTML = "<p>No exam details found.</p>";
        return;
    }

    examData.forEach(exam => {
        let tableHTML = `
            <h2>Class: ${exam.class_name} (ID: ${exam.class_id}) | Month-Year: ${exam.month_year} | Exam: ${exam.exam_name}</h2>
            <table border="1">
                <tr>
                    <th>Student Name</th>
                    ${exam.subjects.map(sub => `<th>${sub}</th>`).join("")}
                    <th>Obtained Marks</th>
                    <th>Total Marks</th>
                    <th>Rank</th>
                </tr>
        `;

        let students = exam.students;
        students.sort((a, b) => b.obtained_marks - a.obtained_marks);

        students.forEach((student, index) => {
            let rankText = getRankText(index + 1);

            tableHTML += `
                <tr>
                    <td>${student.student_name}</td>
                    ${exam.subjects.map(sub => `<td>${student.marks[sub] || "00"}</td>`).join("")}
                    <td>${student.obtained_marks}</td>
                    <td>${student.total_marks}</td>
                    <td class="${rankText.class}">${rankText.text}</td>
                </tr>
            `;
        });

        tableHTML += "</table><br>";
        resultsDiv.innerHTML += tableHTML;
    });
}

function getRankText(rank) {
    switch (rank) {
        case 1: return { class: "rank-first", text: "First" };
        case 2: return { class: "rank-second", text: "Second" };
        case 3: return { class: "rank-third", text: "Third" };
        default: return { class: "", text: rank + "th" };
    }
}
