<?php

include_once('db/database/conn.php');

$db = new DBConn();
$conn = $db->getConnection();

// JSON data receive
$data = json_decode(file_get_contents("php://input"), true);

$formNo = $data['formNo'] ?? '';


// Validate and sanitize
$formNo = mysqli_real_escape_string($conn, $formNo);


// Build the query with dynamic conditions
$query = "SELECT form_no,
    email,
    YEAR(created_at) AS year,
    MONTHNAME(created_at) AS month_name,
    SUM(attendance_status = 'উপস্থিত') AS total_present,
    SUM(attendance_status = 'অনুপস্থিত') AS total_absent,
    SUM(attendance_status = 'রুখসত') AS total_leave,
    SUM(attendance_status = 'বিমার') AS total_sick
FROM student_attendance
WHERE 1=1";

$params = [];
$types = '';

// Add conditions based on provided inputs
if (!empty($formNo)) {
    $query .= " AND form_no = ?";
    $params[] = $formNo;
    $types .= 's';
}


$query .= " GROUP BY form_no, email, YEAR(created_at), MONTH(created_at)
            ORDER BY year, MONTH(created_at)";

$stmt = $conn->prepare($query);

// Bind parameters dynamically
if (!empty($params)) {
    $stmt->bind_param($types, ...$params);
}

$stmt->execute();

$result = $stmt->get_result();

$data = [];

if ($result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        // বাংলা মাসের নামের জন্য ইংরেজি -> বাংলা রূপান্তর
        $englishToBanglaMonth = [
            "January" => "জানুয়ারি",
            "February" => "ফেব্রুয়ারি",
            "March" => "মার্চ",
            "April" => "এপ্রিল",
            "May" => "মে",
            "June" => "জুন",
            "July" => "জুলাই",
            "August" => "আগস্ট",
            "September" => "সেপ্টেম্বর",
            "October" => "অক্টোবর",
            "November" => "নভেম্বর",
            "December" => "ডিসেম্বর"
        ];

        $row['month_name'] = $englishToBanglaMonth[$row['month_name']] ?? $row['month_name'];
        $data[] = $row;
    }
    echo json_encode(["data" => $data]);
} else {
    echo json_encode(["message" => "Data not found"]);
}

$stmt->close();
$conn->close();
