<?php

// Headers
header('Content-Type: application/json');

require_once 'db/database/conn.php';

$db = new DBConn();
$conn = $db->getConnection();

// JSON থেকে ডাটা নিন
$data = json_decode(file_get_contents("php://input"), true);

$month = isset($data['month']) ? $data['month'] : null;
$form_no = isset($data['form_no']) ? $data['form_no'] : null;

if (!$month || !$form_no) {
    echo json_encode(['status' => false, 'message' => 'Month and Form No are required']);
    exit;
}

// Query
$sql = "
SELECT 
    DATE(created_at) as attendance_date,
    attendance_status
FROM 
    student_attendance
WHERE 
    DATE_FORMAT(created_at, '%Y-%m') = ?
    AND form_no = ?
ORDER BY 
    attendance_date ASC
";

$stmt = $conn->prepare($sql);
$stmt->bind_param("ss", $month, $form_no); // দুইটা string parameter: month, form_no
$stmt->execute();
$result = $stmt->get_result();

$attendanceData = [];

// ডেটা প্রসেসিং
while ($row = $result->fetch_assoc()) {
    $date = $row['attendance_date'];
    $status = $row['attendance_status'];

    if (!isset($attendanceData[$status])) {
        $attendanceData[$status] = [
            'count' => 0,
            'dates' => []
        ];
    }

    $attendanceData[$status]['count']++;
    $attendanceData[$status]['dates'][] = $date;
}

// Response
echo json_encode([
    'status' => true,
    'month' => $month,
    'data' => $attendanceData
]);

$conn->close();
